{
 "cells": [
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "# MMEngine 快速上手\n",
    "\n",
    "参考：[MMEngine 快速上手](https://mmengine.readthedocs.io/zh-cn/latest/get_started/15_minutes.html)"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "## 构建模型\n",
    "\n",
    "首先，需要构建 MMEngine 模型，约定这个模型应当继承 {class}`~mmengine.model.BaseModel`，并且其 `forward` 方法除了接受来自数据集的若干参数外，还需要接受额外的参数 `mode`：对于训练，需要 `mode` 接受字符串 `\"loss\"`，并返回包含 `\"loss\"` 字段的字典；对于验证，需要 `mode` 接受字符串 `\"predict\"`，并返回同时包含预测信息和真实信息的结果。"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 1,
   "metadata": {},
   "outputs": [],
   "source": [
    "import set_env"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 2,
   "metadata": {},
   "outputs": [
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "/media/pc/data/lxw/envs/anaconda3x/envs/xxx/lib/python3.12/site-packages/mmengine/optim/optimizer/zero_optimizer.py:11: DeprecationWarning: `TorchScript` support for functional optimizers is deprecated and will be removed in a future PyTorch release. Consider using the `torch.compile` optimizer instead.\n",
      "  from torch.distributed.optim import \\\n"
     ]
    }
   ],
   "source": [
    "import torch.nn.functional as F\n",
    "import torch\n",
    "from torch import nn\n",
    "import torchvision\n",
    "from mmengine.model import BaseModel\n",
    "\n",
    "class MMResNet50(BaseModel):\n",
    "    def __init__(self, data_preprocessor: dict|nn.Module|None = None,\n",
    "                 init_cfg: dict|None = None):\n",
    "        super().__init__(data_preprocessor=data_preprocessor, init_cfg=init_cfg)\n",
    "        self.resnet = torchvision.models.resnet50()\n",
    "\n",
    "    def forward(self, inputs: torch.Tensor,\n",
    "                data_samples: list|list = None,\n",
    "                mode: str = 'tensor') -> dict[str, torch.Tensor] | list:\n",
    "        x = self.resnet(inputs)\n",
    "        if mode == 'loss':\n",
    "            return {'loss': F.cross_entropy(x, data_samples)}\n",
    "        elif mode == 'predict':\n",
    "            return x, data_samples\n",
    "        else:\n",
    "            return x"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "## 构建数据集和数据加载器\n",
    "\n",
    "其次，需要构建训练和验证所需要的数据集 ({class}`~torch.utils.data.Dataset`)和数据加载器 ({class}`~torch.utils.data.DataLoader`)。 对于基础的训练和验证功能，可以直接使用符合 PyTorch 标准的数据加载器和数据集。"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 3,
   "metadata": {},
   "outputs": [],
   "source": [
    "from pathlib import Path\n",
    "\n",
    "temp_dir = Path(\".temp\")\n",
    "temp_dir.mkdir(exist_ok=True) # 创建缓存目录"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 4,
   "metadata": {},
   "outputs": [
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "Files already downloaded and verified\n",
      "Files already downloaded and verified\n"
     ]
    }
   ],
   "source": [
    "import torchvision.transforms as transforms\n",
    "from torch.utils.data import DataLoader\n",
    "\n",
    "norm_cfg = dict(mean=[0.491, 0.482, 0.447], std=[0.202, 0.199, 0.201])\n",
    "train_dataloader = DataLoader(\n",
    "    batch_size=32,\n",
    "    shuffle=True,\n",
    "    dataset=torchvision.datasets.CIFAR10(\n",
    "        temp_dir/'data/cifar10',\n",
    "        train=True,\n",
    "        download=True,\n",
    "        transform=transforms.Compose([\n",
    "            transforms.RandomCrop(32, padding=4),\n",
    "            transforms.RandomHorizontalFlip(),\n",
    "            transforms.ToTensor(),\n",
    "            transforms.Normalize(**norm_cfg)\n",
    "        ]))\n",
    ")\n",
    "val_dataloader = DataLoader(\n",
    "    batch_size=32,\n",
    "    shuffle=False,\n",
    "    dataset=torchvision.datasets.CIFAR10(\n",
    "        temp_dir/'data/cifar10',\n",
    "        train=False,\n",
    "        download=True,\n",
    "        transform=transforms.Compose([\n",
    "            transforms.ToTensor(),\n",
    "            transforms.Normalize(**norm_cfg)\n",
    "        ]))\n",
    ")"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "## 构建评测指标\n",
    "\n",
    "为了进行验证和测试，需要定义模型推理结果的评测指标。\n",
    "\n",
    "约定评测指标需要继承 {class}`~mmengine.evaluator.BaseMetric`，并实现 `process` 和 `compute_metrics` 方法。其中 `process` 方法接受数据集的输出和模型 `mode=\"predict\"` 时的输出，此时的数据为单个批次的数据，对这一批次的数据进行处理后，保存信息至 `self.results` 属性。而 `compute_metrics` 接受 `results` 参数，这一参数的输入为 `process` 中保存的所有信息（如果是分布式环境，`results` 中为已收集的，包括各个进程 `process` 保存信息的结果），利用这些信息计算并返回保存有评测指标结果的字典"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 5,
   "metadata": {},
   "outputs": [],
   "source": [
    "from typing import Any, Sequence\n",
    "from mmengine.evaluator import BaseMetric\n",
    "\n",
    "\n",
    "class Accuracy(BaseMetric):\n",
    "    def process(self, data_batch: Any, data_samples: Sequence[dict])->None:\n",
    "        \"\"\"\n",
    "        处理一批数据样本及其预测结果。处理后的结果应存储在`self.results`中，这将在所有批次处理完毕后用于计算指标。\n",
    "\n",
    "        Args:\n",
    "            data_batch: 从数据加载器获取的一批数据。\n",
    "            data_samples: 模型输出的一批结果。\n",
    "        \"\"\"\n",
    "        score, gt = data_samples\n",
    "        # 将一个批次的中间结果保存至 `self.results`\n",
    "        self.results.append({\n",
    "            'batch_size': len(gt),\n",
    "            'correct': (score.argmax(dim=1) == gt).sum().cpu(),\n",
    "        })\n",
    "\n",
    "    def compute_metrics(self, results):\n",
    "        total_correct = sum(item['correct'] for item in results)\n",
    "        total_size = sum(item['batch_size'] for item in results)\n",
    "        # 返回保存有评测指标结果的字典，其中键为指标名称\n",
    "        return dict(accuracy=100 * total_correct / total_size)"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "## 构建执行器并执行任务\n",
    "\n",
    "最后，利用构建好的模型，数据加载器，评测指标构建执行器 ({class}`~mmengine.runner.Runner`)，同时在其中配置 优化器、工作路径、训练与验证配置等选项，即可通过调用执行器的 {meth}`~mmengine.runner.Runner.train` 方法启动训练："
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 6,
   "metadata": {
    "tags": [
     "hide-output"
    ]
   },
   "outputs": [
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "11/22 16:43:51 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - \n",
      "------------------------------------------------------------\n",
      "System environment:\n",
      "    sys.platform: linux\n",
      "    Python: 3.12.2 | packaged by conda-forge | (main, Feb 16 2024, 20:50:58) [GCC 12.3.0]\n",
      "    CUDA available: True\n",
      "    MUSA available: False\n",
      "    numpy_random_seed: 1560666916\n",
      "    GPU 0: NVIDIA GeForce RTX 3090\n",
      "    GPU 1: NVIDIA GeForce RTX 2080 Ti\n",
      "    CUDA_HOME: /media/pc/data/lxw/envs/anaconda3x/envs/xxx\n",
      "    NVCC: Cuda compilation tools, release 12.6, V12.6.20\n",
      "    GCC: gcc (conda-forge gcc 12.4.0-0) 12.4.0\n",
      "    PyTorch: 2.5.0\n",
      "    PyTorch compiling details: PyTorch built with:\n",
      "  - GCC 9.3\n",
      "  - C++ Version: 201703\n",
      "  - Intel(R) oneAPI Math Kernel Library Version 2023.1-Product Build 20230303 for Intel(R) 64 architecture applications\n",
      "  - Intel(R) MKL-DNN v3.5.3 (Git Hash 66f0cb9eb66affd2da3bf5f8d897376f04aae6af)\n",
      "  - OpenMP 201511 (a.k.a. OpenMP 4.5)\n",
      "  - LAPACK is enabled (usually provided by MKL)\n",
      "  - NNPACK is enabled\n",
      "  - CPU capability usage: AVX2\n",
      "  - CUDA Runtime 12.3\n",
      "  - Built with CUDA Runtime 12.4\n",
      "  - NVCC architecture flags: -gencode;arch=compute_50,code=sm_50;-gencode;arch=compute_60,code=sm_60;-gencode;arch=compute_61,code=sm_61;-gencode;arch=compute_70,code=sm_70;-gencode;arch=compute_75,code=sm_75;-gencode;arch=compute_80,code=sm_80;-gencode;arch=compute_86,code=sm_86;-gencode;arch=compute_90,code=sm_90\n",
      "  - CuDNN 90.1\n",
      "  - Magma 2.6.1\n",
      "  - Build settings: BLAS_INFO=mkl, BUILD_TYPE=Release, CUDA_VERSION=12.4, CUDNN_VERSION=9.1.0, CXX_COMPILER=/opt/rh/devtoolset-9/root/usr/bin/c++, CXX_FLAGS= -D_GLIBCXX_USE_CXX11_ABI=0 -fabi-version=11 -fvisibility-inlines-hidden -DUSE_PTHREADPOOL -DNDEBUG -DUSE_KINETO -DLIBKINETO_NOROCTRACER -DLIBKINETO_NOXPUPTI=ON -DUSE_FBGEMM -DUSE_PYTORCH_QNNPACK -DUSE_XNNPACK -DSYMBOLICATE_MOBILE_DEBUG_HANDLE -O2 -fPIC -Wall -Wextra -Werror=return-type -Werror=non-virtual-dtor -Werror=bool-operation -Wnarrowing -Wno-missing-field-initializers -Wno-type-limits -Wno-array-bounds -Wno-unknown-pragmas -Wno-unused-parameter -Wno-strict-overflow -Wno-strict-aliasing -Wno-stringop-overflow -Wsuggest-override -Wno-psabi -Wno-error=old-style-cast -Wno-missing-braces -fdiagnostics-color=always -faligned-new -Wno-unused-but-set-variable -Wno-maybe-uninitialized -fno-math-errno -fno-trapping-math -Werror=format -Wno-stringop-overflow, LAPACK_INFO=mkl, PERF_WITH_AVX=1, PERF_WITH_AVX2=1, TORCH_VERSION=2.5.0, USE_CUDA=ON, USE_CUDNN=ON, USE_CUSPARSELT=1, USE_EXCEPTION_PTR=1, USE_GFLAGS=OFF, USE_GLOG=OFF, USE_GLOO=ON, USE_MKL=ON, USE_MKLDNN=ON, USE_MPI=OFF, USE_NCCL=ON, USE_NNPACK=ON, USE_OPENMP=ON, USE_ROCM=OFF, USE_ROCM_KERNEL_ASSERT=OFF, \n",
      "\n",
      "    TorchVision: 0.20.0\n",
      "    OpenCV: 4.10.0\n",
      "    MMEngine: 0.10.5\n",
      "\n",
      "Runtime environment:\n",
      "    dist_cfg: {'backend': 'nccl'}\n",
      "    seed: 1560666916\n",
      "    Distributed launcher: none\n",
      "    Distributed training: False\n",
      "    GPU number: 1\n",
      "------------------------------------------------------------\n",
      "\n",
      "11/22 16:43:51 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Distributed training is not used, all SyncBatchNorm (SyncBN) layers in the model will be automatically reverted to BatchNormXd layers if they are used.\n",
      "11/22 16:43:51 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Hooks will be executed in the following order:\n",
      "before_run:\n",
      "(VERY_HIGH   ) RuntimeInfoHook                    \n",
      "(BELOW_NORMAL) LoggerHook                         \n",
      " -------------------- \n",
      "before_train:\n",
      "(VERY_HIGH   ) RuntimeInfoHook                    \n",
      "(NORMAL      ) IterTimerHook                      \n",
      "(VERY_LOW    ) CheckpointHook                     \n",
      " -------------------- \n",
      "before_train_epoch:\n",
      "(VERY_HIGH   ) RuntimeInfoHook                    \n",
      "(NORMAL      ) IterTimerHook                      \n",
      "(NORMAL      ) DistSamplerSeedHook                \n",
      " -------------------- \n",
      "before_train_iter:\n",
      "(VERY_HIGH   ) RuntimeInfoHook                    \n",
      "(NORMAL      ) IterTimerHook                      \n",
      " -------------------- \n",
      "after_train_iter:\n",
      "(VERY_HIGH   ) RuntimeInfoHook                    \n",
      "(NORMAL      ) IterTimerHook                      \n",
      "(BELOW_NORMAL) LoggerHook                         \n",
      "(LOW         ) ParamSchedulerHook                 \n",
      "(VERY_LOW    ) CheckpointHook                     \n",
      " -------------------- \n",
      "after_train_epoch:\n",
      "(NORMAL      ) IterTimerHook                      \n",
      "(LOW         ) ParamSchedulerHook                 \n",
      "(VERY_LOW    ) CheckpointHook                     \n",
      " -------------------- \n",
      "before_val:\n",
      "(VERY_HIGH   ) RuntimeInfoHook                    \n",
      " -------------------- \n",
      "before_val_epoch:\n",
      "(NORMAL      ) IterTimerHook                      \n",
      " -------------------- \n",
      "before_val_iter:\n",
      "(NORMAL      ) IterTimerHook                      \n",
      " -------------------- \n",
      "after_val_iter:\n",
      "(NORMAL      ) IterTimerHook                      \n",
      "(BELOW_NORMAL) LoggerHook                         \n",
      " -------------------- \n",
      "after_val_epoch:\n",
      "(VERY_HIGH   ) RuntimeInfoHook                    \n",
      "(NORMAL      ) IterTimerHook                      \n",
      "(BELOW_NORMAL) LoggerHook                         \n",
      "(LOW         ) ParamSchedulerHook                 \n",
      "(VERY_LOW    ) CheckpointHook                     \n",
      " -------------------- \n",
      "after_val:\n",
      "(VERY_HIGH   ) RuntimeInfoHook                    \n",
      " -------------------- \n",
      "after_train:\n",
      "(VERY_HIGH   ) RuntimeInfoHook                    \n",
      "(VERY_LOW    ) CheckpointHook                     \n",
      " -------------------- \n",
      "before_test:\n",
      "(VERY_HIGH   ) RuntimeInfoHook                    \n",
      " -------------------- \n",
      "before_test_epoch:\n",
      "(NORMAL      ) IterTimerHook                      \n",
      " -------------------- \n",
      "before_test_iter:\n",
      "(NORMAL      ) IterTimerHook                      \n",
      " -------------------- \n",
      "after_test_iter:\n",
      "(NORMAL      ) IterTimerHook                      \n",
      "(BELOW_NORMAL) LoggerHook                         \n",
      " -------------------- \n",
      "after_test_epoch:\n",
      "(VERY_HIGH   ) RuntimeInfoHook                    \n",
      "(NORMAL      ) IterTimerHook                      \n",
      "(BELOW_NORMAL) LoggerHook                         \n",
      " -------------------- \n",
      "after_test:\n",
      "(VERY_HIGH   ) RuntimeInfoHook                    \n",
      " -------------------- \n",
      "after_run:\n",
      "(BELOW_NORMAL) LoggerHook                         \n",
      " -------------------- \n",
      "11/22 16:43:51 - mmengine - \u001b[5m\u001b[4m\u001b[33mWARNING\u001b[0m - Dataset CIFAR10 has no metainfo. ``dataset_meta`` in visualizer will be None.\n",
      "11/22 16:43:51 - mmengine - \u001b[5m\u001b[4m\u001b[33mWARNING\u001b[0m - The prefix is not set in metric class Accuracy.\n",
      "11/22 16:43:51 - mmengine - \u001b[5m\u001b[4m\u001b[33mWARNING\u001b[0m - Dataset CIFAR10 has no metainfo. ``dataset_meta`` in evaluator, metric and visualizer will be None.\n",
      "11/22 16:43:52 - mmengine - \u001b[5m\u001b[4m\u001b[33mWARNING\u001b[0m - \"FileClient\" will be deprecated in future. Please use io functions in https://mmengine.readthedocs.io/en/latest/api/fileio.html#file-io\n",
      "11/22 16:43:52 - mmengine - \u001b[5m\u001b[4m\u001b[33mWARNING\u001b[0m - \"HardDiskBackend\" is the alias of \"LocalBackend\" and the former will be deprecated in future.\n",
      "11/22 16:43:52 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Checkpoints will be saved to /media/pc/data/lxw/ai/torch-book/doc/tools/mmengine/.temp/work_dir.\n",
      "11/22 16:43:59 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][  10/1563]  lr: 1.0000e-03  eta: 1:39:16  time: 0.7632  data_time: 0.0715  memory: 382  loss: 5.2001\n",
      "11/22 16:44:00 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][  20/1563]  lr: 1.0000e-03  eta: 0:53:29  time: 0.0603  data_time: 0.0164  memory: 382  loss: 2.7405\n",
      "11/22 16:44:01 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][  30/1563]  lr: 1.0000e-03  eta: 0:38:11  time: 0.0597  data_time: 0.0165  memory: 382  loss: 2.6204\n",
      "11/22 16:44:01 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][  40/1563]  lr: 1.0000e-03  eta: 0:30:28  time: 0.0576  data_time: 0.0159  memory: 382  loss: 2.6943\n",
      "11/22 16:44:02 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][  50/1563]  lr: 1.0000e-03  eta: 0:25:56  time: 0.0614  data_time: 0.0164  memory: 382  loss: 2.5952\n",
      "11/22 16:44:02 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][  60/1563]  lr: 1.0000e-03  eta: 0:22:53  time: 0.0606  data_time: 0.0162  memory: 382  loss: 2.6457\n",
      "11/22 16:44:03 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][  70/1563]  lr: 1.0000e-03  eta: 0:20:43  time: 0.0613  data_time: 0.0164  memory: 382  loss: 2.5014\n",
      "11/22 16:44:04 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][  80/1563]  lr: 1.0000e-03  eta: 0:19:05  time: 0.0602  data_time: 0.0161  memory: 382  loss: 2.6964\n",
      "11/22 16:44:04 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][  90/1563]  lr: 1.0000e-03  eta: 0:17:48  time: 0.0609  data_time: 0.0161  memory: 382  loss: 2.5502\n",
      "11/22 16:44:05 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 100/1563]  lr: 1.0000e-03  eta: 0:16:47  time: 0.0601  data_time: 0.0161  memory: 382  loss: 2.7025\n",
      "11/22 16:44:05 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 110/1563]  lr: 1.0000e-03  eta: 0:15:56  time: 0.0596  data_time: 0.0159  memory: 382  loss: 2.6884\n",
      "11/22 16:44:06 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 120/1563]  lr: 1.0000e-03  eta: 0:15:13  time: 0.0598  data_time: 0.0162  memory: 382  loss: 2.4517\n",
      "11/22 16:44:07 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 130/1563]  lr: 1.0000e-03  eta: 0:14:37  time: 0.0594  data_time: 0.0159  memory: 382  loss: 2.4550\n",
      "11/22 16:44:07 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 140/1563]  lr: 1.0000e-03  eta: 0:14:07  time: 0.0614  data_time: 0.0162  memory: 382  loss: 2.6048\n",
      "11/22 16:44:08 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 150/1563]  lr: 1.0000e-03  eta: 0:13:39  time: 0.0584  data_time: 0.0159  memory: 382  loss: 2.5119\n",
      "11/22 16:44:08 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 160/1563]  lr: 1.0000e-03  eta: 0:13:15  time: 0.0591  data_time: 0.0158  memory: 382  loss: 2.6287\n",
      "11/22 16:44:09 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 170/1563]  lr: 1.0000e-03  eta: 0:12:54  time: 0.0591  data_time: 0.0159  memory: 382  loss: 2.5352\n",
      "11/22 16:44:09 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 180/1563]  lr: 1.0000e-03  eta: 0:12:35  time: 0.0595  data_time: 0.0158  memory: 382  loss: 2.3148\n",
      "11/22 16:44:10 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 190/1563]  lr: 1.0000e-03  eta: 0:12:19  time: 0.0610  data_time: 0.0161  memory: 382  loss: 2.4886\n",
      "11/22 16:44:11 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 200/1563]  lr: 1.0000e-03  eta: 0:12:04  time: 0.0604  data_time: 0.0161  memory: 382  loss: 2.6004\n",
      "11/22 16:44:11 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 210/1563]  lr: 1.0000e-03  eta: 0:11:51  time: 0.0608  data_time: 0.0163  memory: 382  loss: 2.4654\n",
      "11/22 16:44:12 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 220/1563]  lr: 1.0000e-03  eta: 0:11:38  time: 0.0609  data_time: 0.0161  memory: 382  loss: 2.4486\n",
      "11/22 16:44:13 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 230/1563]  lr: 1.0000e-03  eta: 0:11:29  time: 0.0652  data_time: 0.0185  memory: 382  loss: 2.4717\n",
      "11/22 16:44:13 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 240/1563]  lr: 1.0000e-03  eta: 0:11:16  time: 0.0543  data_time: 0.0162  memory: 382  loss: 2.8184\n",
      "11/22 16:44:14 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 250/1563]  lr: 1.0000e-03  eta: 0:11:05  time: 0.0545  data_time: 0.0147  memory: 382  loss: 2.5532\n",
      "11/22 16:44:14 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 260/1563]  lr: 1.0000e-03  eta: 0:10:55  time: 0.0567  data_time: 0.0151  memory: 382  loss: 2.5035\n",
      "11/22 16:44:15 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 270/1563]  lr: 1.0000e-03  eta: 0:10:46  time: 0.0573  data_time: 0.0150  memory: 382  loss: 2.4546\n",
      "11/22 16:44:15 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 280/1563]  lr: 1.0000e-03  eta: 0:10:35  time: 0.0502  data_time: 0.0148  memory: 382  loss: 2.4746\n",
      "11/22 16:44:16 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 290/1563]  lr: 1.0000e-03  eta: 0:10:27  time: 0.0538  data_time: 0.0146  memory: 382  loss: 2.4412\n",
      "11/22 16:44:16 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 300/1563]  lr: 1.0000e-03  eta: 0:10:19  time: 0.0551  data_time: 0.0147  memory: 382  loss: 2.8462\n",
      "11/22 16:44:17 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 310/1563]  lr: 1.0000e-03  eta: 0:10:13  time: 0.0617  data_time: 0.0172  memory: 382  loss: 2.6183\n",
      "11/22 16:44:18 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 320/1563]  lr: 1.0000e-03  eta: 0:10:11  time: 0.0776  data_time: 0.0266  memory: 382  loss: 2.5153\n",
      "11/22 16:44:18 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 330/1563]  lr: 1.0000e-03  eta: 0:10:07  time: 0.0658  data_time: 0.0222  memory: 382  loss: 2.6309\n",
      "11/22 16:44:19 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 340/1563]  lr: 1.0000e-03  eta: 0:09:59  time: 0.0520  data_time: 0.0147  memory: 382  loss: 2.4788\n",
      "11/22 16:44:20 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 350/1563]  lr: 1.0000e-03  eta: 0:09:53  time: 0.0540  data_time: 0.0143  memory: 382  loss: 2.3778\n",
      "11/22 16:44:20 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 360/1563]  lr: 1.0000e-03  eta: 0:09:47  time: 0.0544  data_time: 0.0143  memory: 382  loss: 2.3699\n",
      "11/22 16:44:21 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 370/1563]  lr: 1.0000e-03  eta: 0:09:41  time: 0.0534  data_time: 0.0142  memory: 382  loss: 2.3043\n",
      "11/22 16:44:21 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 380/1563]  lr: 1.0000e-03  eta: 0:09:35  time: 0.0530  data_time: 0.0141  memory: 382  loss: 2.2693\n",
      "11/22 16:44:22 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 390/1563]  lr: 1.0000e-03  eta: 0:09:30  time: 0.0537  data_time: 0.0140  memory: 382  loss: 2.2301\n",
      "11/22 16:44:22 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 400/1563]  lr: 1.0000e-03  eta: 0:09:25  time: 0.0529  data_time: 0.0139  memory: 382  loss: 2.2824\n",
      "11/22 16:44:23 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 410/1563]  lr: 1.0000e-03  eta: 0:09:20  time: 0.0529  data_time: 0.0140  memory: 382  loss: 2.2469\n",
      "11/22 16:44:23 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 420/1563]  lr: 1.0000e-03  eta: 0:09:15  time: 0.0525  data_time: 0.0140  memory: 382  loss: 2.2944\n",
      "11/22 16:44:24 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 430/1563]  lr: 1.0000e-03  eta: 0:09:11  time: 0.0527  data_time: 0.0139  memory: 382  loss: 2.2259\n",
      "11/22 16:44:24 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 440/1563]  lr: 1.0000e-03  eta: 0:09:06  time: 0.0526  data_time: 0.0140  memory: 382  loss: 2.3950\n",
      "11/22 16:44:25 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 450/1563]  lr: 1.0000e-03  eta: 0:09:02  time: 0.0526  data_time: 0.0138  memory: 382  loss: 2.2780\n",
      "11/22 16:44:25 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 460/1563]  lr: 1.0000e-03  eta: 0:08:58  time: 0.0522  data_time: 0.0141  memory: 382  loss: 2.2708\n",
      "11/22 16:44:26 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 470/1563]  lr: 1.0000e-03  eta: 0:08:54  time: 0.0523  data_time: 0.0136  memory: 382  loss: 2.2801\n",
      "11/22 16:44:26 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 480/1563]  lr: 1.0000e-03  eta: 0:08:50  time: 0.0528  data_time: 0.0140  memory: 382  loss: 2.2182\n",
      "11/22 16:44:27 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 490/1563]  lr: 1.0000e-03  eta: 0:08:46  time: 0.0523  data_time: 0.0137  memory: 382  loss: 2.3097\n",
      "11/22 16:44:27 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 500/1563]  lr: 1.0000e-03  eta: 0:08:43  time: 0.0525  data_time: 0.0138  memory: 382  loss: 2.2631\n",
      "11/22 16:44:28 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 510/1563]  lr: 1.0000e-03  eta: 0:08:40  time: 0.0550  data_time: 0.0144  memory: 382  loss: 2.4475\n",
      "11/22 16:44:29 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 520/1563]  lr: 1.0000e-03  eta: 0:08:37  time: 0.0557  data_time: 0.0144  memory: 382  loss: 2.2028\n",
      "11/22 16:44:29 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 530/1563]  lr: 1.0000e-03  eta: 0:08:34  time: 0.0569  data_time: 0.0148  memory: 382  loss: 2.2588\n",
      "11/22 16:44:30 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 540/1563]  lr: 1.0000e-03  eta: 0:08:31  time: 0.0563  data_time: 0.0147  memory: 382  loss: 2.2757\n",
      "11/22 16:44:30 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 550/1563]  lr: 1.0000e-03  eta: 0:08:29  time: 0.0594  data_time: 0.0191  memory: 382  loss: 2.2082\n",
      "11/22 16:44:31 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 560/1563]  lr: 1.0000e-03  eta: 0:08:26  time: 0.0524  data_time: 0.0153  memory: 382  loss: 2.3530\n",
      "11/22 16:44:31 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 570/1563]  lr: 1.0000e-03  eta: 0:08:24  time: 0.0554  data_time: 0.0147  memory: 382  loss: 2.2255\n",
      "11/22 16:44:32 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 580/1563]  lr: 1.0000e-03  eta: 0:08:21  time: 0.0570  data_time: 0.0150  memory: 382  loss: 2.3278\n",
      "11/22 16:44:32 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 590/1563]  lr: 1.0000e-03  eta: 0:08:19  time: 0.0574  data_time: 0.0149  memory: 382  loss: 2.3414\n",
      "11/22 16:44:33 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 600/1563]  lr: 1.0000e-03  eta: 0:08:17  time: 0.0572  data_time: 0.0148  memory: 382  loss: 2.3389\n",
      "11/22 16:44:34 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 610/1563]  lr: 1.0000e-03  eta: 0:08:15  time: 0.0572  data_time: 0.0149  memory: 382  loss: 2.1401\n",
      "11/22 16:44:34 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 620/1563]  lr: 1.0000e-03  eta: 0:08:13  time: 0.0572  data_time: 0.0149  memory: 382  loss: 2.2828\n",
      "11/22 16:44:35 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 630/1563]  lr: 1.0000e-03  eta: 0:08:13  time: 0.0776  data_time: 0.0256  memory: 382  loss: 2.1000\n",
      "11/22 16:44:36 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 640/1563]  lr: 1.0000e-03  eta: 0:08:14  time: 0.0787  data_time: 0.0267  memory: 382  loss: 2.1133\n",
      "11/22 16:44:37 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 650/1563]  lr: 1.0000e-03  eta: 0:08:14  time: 0.0742  data_time: 0.0253  memory: 382  loss: 2.1463\n",
      "11/22 16:44:37 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 660/1563]  lr: 1.0000e-03  eta: 0:08:13  time: 0.0722  data_time: 0.0253  memory: 382  loss: 2.0891\n",
      "11/22 16:44:38 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 670/1563]  lr: 1.0000e-03  eta: 0:08:11  time: 0.0494  data_time: 0.0142  memory: 382  loss: 2.1502\n",
      "11/22 16:44:38 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 680/1563]  lr: 1.0000e-03  eta: 0:08:08  time: 0.0542  data_time: 0.0142  memory: 382  loss: 2.1161\n",
      "11/22 16:44:39 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 690/1563]  lr: 1.0000e-03  eta: 0:08:06  time: 0.0554  data_time: 0.0144  memory: 382  loss: 2.0932\n",
      "11/22 16:44:40 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 700/1563]  lr: 1.0000e-03  eta: 0:08:06  time: 0.0682  data_time: 0.0216  memory: 382  loss: 2.1566\n",
      "11/22 16:44:40 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 710/1563]  lr: 1.0000e-03  eta: 0:08:06  time: 0.0751  data_time: 0.0259  memory: 382  loss: 2.2086\n",
      "11/22 16:44:41 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 720/1563]  lr: 1.0000e-03  eta: 0:08:06  time: 0.0754  data_time: 0.0260  memory: 382  loss: 2.0933\n",
      "11/22 16:44:42 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 730/1563]  lr: 1.0000e-03  eta: 0:08:06  time: 0.0747  data_time: 0.0259  memory: 382  loss: 2.2761\n",
      "11/22 16:44:43 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 740/1563]  lr: 1.0000e-03  eta: 0:08:05  time: 0.0754  data_time: 0.0260  memory: 382  loss: 2.0696\n",
      "11/22 16:44:43 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 750/1563]  lr: 1.0000e-03  eta: 0:08:05  time: 0.0755  data_time: 0.0261  memory: 382  loss: 2.1613\n",
      "11/22 16:44:44 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 760/1563]  lr: 1.0000e-03  eta: 0:08:04  time: 0.0561  data_time: 0.0185  memory: 382  loss: 2.1743\n",
      "11/22 16:44:44 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 770/1563]  lr: 1.0000e-03  eta: 0:08:01  time: 0.0478  data_time: 0.0137  memory: 382  loss: 2.1002\n",
      "11/22 16:44:45 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 780/1563]  lr: 1.0000e-03  eta: 0:07:59  time: 0.0522  data_time: 0.0139  memory: 382  loss: 2.1998\n",
      "11/22 16:44:45 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 790/1563]  lr: 1.0000e-03  eta: 0:07:57  time: 0.0538  data_time: 0.0143  memory: 382  loss: 2.1168\n",
      "11/22 16:44:46 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 800/1563]  lr: 1.0000e-03  eta: 0:07:55  time: 0.0539  data_time: 0.0144  memory: 382  loss: 2.2058\n",
      "11/22 16:44:46 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 810/1563]  lr: 1.0000e-03  eta: 0:07:53  time: 0.0536  data_time: 0.0142  memory: 382  loss: 2.2244\n",
      "11/22 16:44:47 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 820/1563]  lr: 1.0000e-03  eta: 0:07:51  time: 0.0521  data_time: 0.0137  memory: 382  loss: 2.2053\n",
      "11/22 16:44:47 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 830/1563]  lr: 1.0000e-03  eta: 0:07:49  time: 0.0527  data_time: 0.0140  memory: 382  loss: 2.1958\n",
      "11/22 16:44:48 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 840/1563]  lr: 1.0000e-03  eta: 0:07:47  time: 0.0526  data_time: 0.0140  memory: 382  loss: 2.2440\n",
      "11/22 16:44:49 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 850/1563]  lr: 1.0000e-03  eta: 0:07:46  time: 0.0545  data_time: 0.0141  memory: 382  loss: 2.2917\n",
      "11/22 16:44:49 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 860/1563]  lr: 1.0000e-03  eta: 0:07:44  time: 0.0526  data_time: 0.0142  memory: 382  loss: 2.1799\n",
      "11/22 16:44:50 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 870/1563]  lr: 1.0000e-03  eta: 0:07:42  time: 0.0520  data_time: 0.0137  memory: 382  loss: 2.1603\n",
      "11/22 16:44:50 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 880/1563]  lr: 1.0000e-03  eta: 0:07:40  time: 0.0525  data_time: 0.0138  memory: 382  loss: 2.1370\n",
      "11/22 16:44:51 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 890/1563]  lr: 1.0000e-03  eta: 0:07:38  time: 0.0522  data_time: 0.0136  memory: 382  loss: 2.0750\n",
      "11/22 16:44:51 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 900/1563]  lr: 1.0000e-03  eta: 0:07:37  time: 0.0528  data_time: 0.0138  memory: 382  loss: 2.1426\n",
      "11/22 16:44:52 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 910/1563]  lr: 1.0000e-03  eta: 0:07:35  time: 0.0538  data_time: 0.0145  memory: 382  loss: 2.0531\n",
      "11/22 16:44:52 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 920/1563]  lr: 1.0000e-03  eta: 0:07:34  time: 0.0653  data_time: 0.0208  memory: 382  loss: 2.1486\n",
      "11/22 16:44:53 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 930/1563]  lr: 1.0000e-03  eta: 0:07:34  time: 0.0758  data_time: 0.0259  memory: 382  loss: 2.0900\n",
      "11/22 16:44:54 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 940/1563]  lr: 1.0000e-03  eta: 0:07:34  time: 0.0740  data_time: 0.0257  memory: 382  loss: 2.1378\n",
      "11/22 16:44:54 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 950/1563]  lr: 1.0000e-03  eta: 0:07:32  time: 0.0476  data_time: 0.0135  memory: 382  loss: 2.0934\n",
      "11/22 16:44:55 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 960/1563]  lr: 1.0000e-03  eta: 0:07:31  time: 0.0512  data_time: 0.0134  memory: 382  loss: 2.1247\n",
      "11/22 16:44:55 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 970/1563]  lr: 1.0000e-03  eta: 0:07:29  time: 0.0514  data_time: 0.0133  memory: 382  loss: 1.9091\n",
      "11/22 16:44:56 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 980/1563]  lr: 1.0000e-03  eta: 0:07:27  time: 0.0523  data_time: 0.0138  memory: 382  loss: 2.0327\n",
      "11/22 16:44:56 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][ 990/1563]  lr: 1.0000e-03  eta: 0:07:26  time: 0.0516  data_time: 0.0135  memory: 382  loss: 2.0589\n",
      "11/22 16:44:57 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Exp name: 20241122_164350\n",
      "11/22 16:44:57 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][1000/1563]  lr: 1.0000e-03  eta: 0:07:24  time: 0.0517  data_time: 0.0134  memory: 382  loss: 2.0987\n",
      "11/22 16:44:57 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][1010/1563]  lr: 1.0000e-03  eta: 0:07:23  time: 0.0518  data_time: 0.0136  memory: 382  loss: 2.1372\n",
      "11/22 16:44:58 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][1020/1563]  lr: 1.0000e-03  eta: 0:07:21  time: 0.0542  data_time: 0.0143  memory: 382  loss: 2.0680\n",
      "11/22 16:44:59 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][1030/1563]  lr: 1.0000e-03  eta: 0:07:20  time: 0.0537  data_time: 0.0142  memory: 382  loss: 2.0451\n",
      "11/22 16:44:59 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][1040/1563]  lr: 1.0000e-03  eta: 0:07:18  time: 0.0526  data_time: 0.0140  memory: 382  loss: 1.9602\n",
      "11/22 16:45:00 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][1050/1563]  lr: 1.0000e-03  eta: 0:07:17  time: 0.0518  data_time: 0.0134  memory: 382  loss: 2.1273\n",
      "11/22 16:45:00 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][1060/1563]  lr: 1.0000e-03  eta: 0:07:15  time: 0.0517  data_time: 0.0136  memory: 382  loss: 2.0634\n",
      "11/22 16:45:01 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][1070/1563]  lr: 1.0000e-03  eta: 0:07:14  time: 0.0522  data_time: 0.0137  memory: 382  loss: 2.0051\n",
      "11/22 16:45:01 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][1080/1563]  lr: 1.0000e-03  eta: 0:07:13  time: 0.0519  data_time: 0.0137  memory: 382  loss: 2.0453\n",
      "11/22 16:45:02 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][1090/1563]  lr: 1.0000e-03  eta: 0:07:11  time: 0.0517  data_time: 0.0136  memory: 382  loss: 2.0371\n",
      "11/22 16:45:02 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][1100/1563]  lr: 1.0000e-03  eta: 0:07:10  time: 0.0518  data_time: 0.0135  memory: 382  loss: 2.0868\n",
      "11/22 16:45:03 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][1110/1563]  lr: 1.0000e-03  eta: 0:07:08  time: 0.0517  data_time: 0.0136  memory: 382  loss: 2.0355\n",
      "11/22 16:45:03 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][1120/1563]  lr: 1.0000e-03  eta: 0:07:07  time: 0.0520  data_time: 0.0136  memory: 382  loss: 2.0876\n",
      "11/22 16:45:04 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][1130/1563]  lr: 1.0000e-03  eta: 0:07:06  time: 0.0516  data_time: 0.0134  memory: 382  loss: 1.9616\n",
      "11/22 16:45:04 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][1140/1563]  lr: 1.0000e-03  eta: 0:07:04  time: 0.0518  data_time: 0.0135  memory: 382  loss: 2.1710\n",
      "11/22 16:45:05 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][1150/1563]  lr: 1.0000e-03  eta: 0:07:03  time: 0.0516  data_time: 0.0134  memory: 382  loss: 2.0644\n",
      "11/22 16:45:05 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][1160/1563]  lr: 1.0000e-03  eta: 0:07:02  time: 0.0520  data_time: 0.0136  memory: 382  loss: 2.0819\n",
      "11/22 16:45:06 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][1170/1563]  lr: 1.0000e-03  eta: 0:07:00  time: 0.0518  data_time: 0.0136  memory: 382  loss: 2.1671\n",
      "11/22 16:45:06 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][1180/1563]  lr: 1.0000e-03  eta: 0:06:59  time: 0.0524  data_time: 0.0139  memory: 382  loss: 2.1896\n",
      "11/22 16:45:07 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][1190/1563]  lr: 1.0000e-03  eta: 0:06:58  time: 0.0517  data_time: 0.0134  memory: 382  loss: 2.0388\n",
      "11/22 16:45:07 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][1200/1563]  lr: 1.0000e-03  eta: 0:06:57  time: 0.0522  data_time: 0.0137  memory: 382  loss: 2.0957\n",
      "11/22 16:45:08 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][1210/1563]  lr: 1.0000e-03  eta: 0:06:55  time: 0.0519  data_time: 0.0135  memory: 382  loss: 2.0627\n",
      "11/22 16:45:08 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][1220/1563]  lr: 1.0000e-03  eta: 0:06:54  time: 0.0519  data_time: 0.0134  memory: 382  loss: 2.0116\n",
      "11/22 16:45:09 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][1230/1563]  lr: 1.0000e-03  eta: 0:06:53  time: 0.0520  data_time: 0.0136  memory: 382  loss: 2.0208\n",
      "11/22 16:45:09 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][1240/1563]  lr: 1.0000e-03  eta: 0:06:52  time: 0.0534  data_time: 0.0140  memory: 382  loss: 1.9053\n",
      "11/22 16:45:10 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][1250/1563]  lr: 1.0000e-03  eta: 0:06:51  time: 0.0547  data_time: 0.0144  memory: 382  loss: 2.0169\n",
      "11/22 16:45:11 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][1260/1563]  lr: 1.0000e-03  eta: 0:06:50  time: 0.0545  data_time: 0.0145  memory: 382  loss: 1.9237\n",
      "11/22 16:45:11 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][1270/1563]  lr: 1.0000e-03  eta: 0:06:49  time: 0.0546  data_time: 0.0144  memory: 382  loss: 2.1535\n",
      "11/22 16:45:12 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][1280/1563]  lr: 1.0000e-03  eta: 0:06:48  time: 0.0557  data_time: 0.0143  memory: 382  loss: 1.9716\n",
      "11/22 16:45:12 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][1290/1563]  lr: 1.0000e-03  eta: 0:06:47  time: 0.0562  data_time: 0.0145  memory: 382  loss: 2.0045\n",
      "11/22 16:45:13 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][1300/1563]  lr: 1.0000e-03  eta: 0:06:46  time: 0.0558  data_time: 0.0144  memory: 382  loss: 2.0869\n",
      "11/22 16:45:13 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][1310/1563]  lr: 1.0000e-03  eta: 0:06:45  time: 0.0557  data_time: 0.0143  memory: 382  loss: 1.9966\n",
      "11/22 16:45:14 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][1320/1563]  lr: 1.0000e-03  eta: 0:06:44  time: 0.0550  data_time: 0.0140  memory: 382  loss: 1.9463\n",
      "11/22 16:45:14 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][1330/1563]  lr: 1.0000e-03  eta: 0:06:43  time: 0.0530  data_time: 0.0137  memory: 382  loss: 1.8883\n",
      "11/22 16:45:15 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][1340/1563]  lr: 1.0000e-03  eta: 0:06:42  time: 0.0515  data_time: 0.0134  memory: 382  loss: 2.0122\n",
      "11/22 16:45:15 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][1350/1563]  lr: 1.0000e-03  eta: 0:06:41  time: 0.0517  data_time: 0.0137  memory: 382  loss: 1.9305\n",
      "11/22 16:45:16 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][1360/1563]  lr: 1.0000e-03  eta: 0:06:39  time: 0.0520  data_time: 0.0137  memory: 382  loss: 1.9142\n",
      "11/22 16:45:16 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][1370/1563]  lr: 1.0000e-03  eta: 0:06:38  time: 0.0537  data_time: 0.0138  memory: 382  loss: 1.9884\n",
      "11/22 16:45:17 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][1380/1563]  lr: 1.0000e-03  eta: 0:06:37  time: 0.0536  data_time: 0.0137  memory: 382  loss: 1.8882\n",
      "11/22 16:45:18 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][1390/1563]  lr: 1.0000e-03  eta: 0:06:36  time: 0.0528  data_time: 0.0135  memory: 382  loss: 2.0320\n",
      "11/22 16:45:18 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][1400/1563]  lr: 1.0000e-03  eta: 0:06:35  time: 0.0513  data_time: 0.0134  memory: 382  loss: 2.0217\n",
      "11/22 16:45:19 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][1410/1563]  lr: 1.0000e-03  eta: 0:06:34  time: 0.0519  data_time: 0.0136  memory: 382  loss: 1.9956\n",
      "11/22 16:45:19 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][1420/1563]  lr: 1.0000e-03  eta: 0:06:33  time: 0.0518  data_time: 0.0134  memory: 382  loss: 2.0142\n",
      "11/22 16:45:20 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][1430/1563]  lr: 1.0000e-03  eta: 0:06:32  time: 0.0516  data_time: 0.0135  memory: 382  loss: 1.9738\n",
      "11/22 16:45:20 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][1440/1563]  lr: 1.0000e-03  eta: 0:06:31  time: 0.0521  data_time: 0.0136  memory: 382  loss: 2.0285\n",
      "11/22 16:45:21 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][1450/1563]  lr: 1.0000e-03  eta: 0:06:30  time: 0.0514  data_time: 0.0134  memory: 382  loss: 2.0299\n",
      "11/22 16:45:21 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][1460/1563]  lr: 1.0000e-03  eta: 0:06:29  time: 0.0516  data_time: 0.0134  memory: 382  loss: 1.8035\n",
      "11/22 16:45:22 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][1470/1563]  lr: 1.0000e-03  eta: 0:06:28  time: 0.0516  data_time: 0.0134  memory: 382  loss: 2.1066\n",
      "11/22 16:45:22 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][1480/1563]  lr: 1.0000e-03  eta: 0:06:27  time: 0.0514  data_time: 0.0134  memory: 382  loss: 1.8985\n",
      "11/22 16:45:23 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][1490/1563]  lr: 1.0000e-03  eta: 0:06:26  time: 0.0514  data_time: 0.0133  memory: 382  loss: 1.8805\n",
      "11/22 16:45:23 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][1500/1563]  lr: 1.0000e-03  eta: 0:06:25  time: 0.0519  data_time: 0.0135  memory: 382  loss: 2.0064\n",
      "11/22 16:45:24 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][1510/1563]  lr: 1.0000e-03  eta: 0:06:24  time: 0.0517  data_time: 0.0136  memory: 382  loss: 1.9251\n",
      "11/22 16:45:24 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][1520/1563]  lr: 1.0000e-03  eta: 0:06:23  time: 0.0515  data_time: 0.0134  memory: 382  loss: 1.9094\n",
      "11/22 16:45:25 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][1530/1563]  lr: 1.0000e-03  eta: 0:06:22  time: 0.0517  data_time: 0.0135  memory: 382  loss: 1.9858\n",
      "11/22 16:45:25 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][1540/1563]  lr: 1.0000e-03  eta: 0:06:21  time: 0.0519  data_time: 0.0135  memory: 382  loss: 1.9386\n",
      "11/22 16:45:26 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][1550/1563]  lr: 1.0000e-03  eta: 0:06:20  time: 0.0515  data_time: 0.0134  memory: 382  loss: 1.8874\n",
      "11/22 16:45:26 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [1][1560/1563]  lr: 1.0000e-03  eta: 0:06:19  time: 0.0518  data_time: 0.0137  memory: 382  loss: 1.9668\n",
      "11/22 16:45:27 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Exp name: 20241122_164350\n",
      "11/22 16:45:27 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Saving checkpoint at 1 epochs\n",
      "11/22 16:45:27 - mmengine - \u001b[5m\u001b[4m\u001b[33mWARNING\u001b[0m - `save_param_scheduler` is True but `self.param_schedulers` is None, so skip saving parameter schedulers\n",
      "11/22 16:45:28 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [1][ 10/313]    eta: 0:00:22  time: 0.0747  data_time: 0.0111  memory: 382  \n",
      "11/22 16:45:29 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [1][ 20/313]    eta: 0:00:13  time: 0.0198  data_time: 0.0097  memory: 225  \n",
      "11/22 16:45:29 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [1][ 30/313]    eta: 0:00:10  time: 0.0199  data_time: 0.0096  memory: 225  \n",
      "11/22 16:45:29 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [1][ 40/313]    eta: 0:00:09  time: 0.0181  data_time: 0.0089  memory: 225  \n",
      "11/22 16:45:29 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [1][ 50/313]    eta: 0:00:07  time: 0.0169  data_time: 0.0084  memory: 225  \n",
      "11/22 16:45:29 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [1][ 60/313]    eta: 0:00:07  time: 0.0170  data_time: 0.0084  memory: 225  \n",
      "11/22 16:45:29 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [1][ 70/313]    eta: 0:00:06  time: 0.0176  data_time: 0.0086  memory: 225  \n",
      "11/22 16:45:30 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [1][ 80/313]    eta: 0:00:05  time: 0.0168  data_time: 0.0083  memory: 225  \n",
      "11/22 16:45:30 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [1][ 90/313]    eta: 0:00:05  time: 0.0169  data_time: 0.0083  memory: 225  \n",
      "11/22 16:45:30 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [1][100/313]    eta: 0:00:05  time: 0.0170  data_time: 0.0083  memory: 225  \n",
      "11/22 16:45:30 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [1][110/313]    eta: 0:00:04  time: 0.0169  data_time: 0.0083  memory: 225  \n",
      "11/22 16:45:30 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [1][120/313]    eta: 0:00:04  time: 0.0168  data_time: 0.0083  memory: 225  \n",
      "11/22 16:45:30 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [1][130/313]    eta: 0:00:04  time: 0.0167  data_time: 0.0082  memory: 225  \n",
      "11/22 16:45:31 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [1][140/313]    eta: 0:00:03  time: 0.0167  data_time: 0.0082  memory: 225  \n",
      "11/22 16:45:31 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [1][150/313]    eta: 0:00:03  time: 0.0168  data_time: 0.0082  memory: 225  \n",
      "11/22 16:45:31 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [1][160/313]    eta: 0:00:03  time: 0.0171  data_time: 0.0084  memory: 225  \n",
      "11/22 16:45:31 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [1][170/313]    eta: 0:00:02  time: 0.0168  data_time: 0.0083  memory: 225  \n",
      "11/22 16:45:31 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [1][180/313]    eta: 0:00:02  time: 0.0170  data_time: 0.0084  memory: 225  \n",
      "11/22 16:45:32 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [1][190/313]    eta: 0:00:02  time: 0.0168  data_time: 0.0083  memory: 225  \n",
      "11/22 16:45:32 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [1][200/313]    eta: 0:00:02  time: 0.0168  data_time: 0.0082  memory: 225  \n",
      "11/22 16:45:32 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [1][210/313]    eta: 0:00:02  time: 0.0168  data_time: 0.0082  memory: 225  \n",
      "11/22 16:45:32 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [1][220/313]    eta: 0:00:01  time: 0.0170  data_time: 0.0084  memory: 225  \n",
      "11/22 16:45:32 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [1][230/313]    eta: 0:00:01  time: 0.0168  data_time: 0.0083  memory: 225  \n",
      "11/22 16:45:32 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [1][240/313]    eta: 0:00:01  time: 0.0168  data_time: 0.0083  memory: 225  \n",
      "11/22 16:45:33 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [1][250/313]    eta: 0:00:01  time: 0.0167  data_time: 0.0082  memory: 225  \n",
      "11/22 16:45:33 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [1][260/313]    eta: 0:00:01  time: 0.0170  data_time: 0.0083  memory: 225  \n",
      "11/22 16:45:33 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [1][270/313]    eta: 0:00:00  time: 0.0168  data_time: 0.0083  memory: 225  \n",
      "11/22 16:45:33 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [1][280/313]    eta: 0:00:00  time: 0.0170  data_time: 0.0084  memory: 225  \n",
      "11/22 16:45:33 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [1][290/313]    eta: 0:00:00  time: 0.0172  data_time: 0.0084  memory: 225  \n",
      "11/22 16:45:33 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [1][300/313]    eta: 0:00:00  time: 0.0173  data_time: 0.0086  memory: 225  \n",
      "11/22 16:45:34 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [1][310/313]    eta: 0:00:00  time: 0.0171  data_time: 0.0085  memory: 225  \n",
      "11/22 16:45:34 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [1][313/313]    accuracy: 35.3700  data_time: 0.0085  time: 0.0190\n",
      "11/22 16:45:34 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][  10/1563]  lr: 1.0000e-03  eta: 0:06:19  time: 0.0469  data_time: 0.0135  memory: 382  loss: 1.9365\n",
      "11/22 16:45:35 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][  20/1563]  lr: 1.0000e-03  eta: 0:06:18  time: 0.0506  data_time: 0.0132  memory: 382  loss: 1.8599\n",
      "11/22 16:45:35 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][  30/1563]  lr: 1.0000e-03  eta: 0:06:17  time: 0.0518  data_time: 0.0136  memory: 382  loss: 1.8692\n",
      "11/22 16:45:36 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][  40/1563]  lr: 1.0000e-03  eta: 0:06:16  time: 0.0520  data_time: 0.0137  memory: 382  loss: 1.8781\n",
      "11/22 16:45:36 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][  50/1563]  lr: 1.0000e-03  eta: 0:06:15  time: 0.0522  data_time: 0.0138  memory: 382  loss: 1.9849\n",
      "11/22 16:45:37 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][  60/1563]  lr: 1.0000e-03  eta: 0:06:14  time: 0.0520  data_time: 0.0138  memory: 382  loss: 2.0209\n",
      "11/22 16:45:37 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][  70/1563]  lr: 1.0000e-03  eta: 0:06:13  time: 0.0534  data_time: 0.0143  memory: 382  loss: 2.0264\n",
      "11/22 16:45:38 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][  80/1563]  lr: 1.0000e-03  eta: 0:06:13  time: 0.0516  data_time: 0.0136  memory: 382  loss: 1.7989\n",
      "11/22 16:45:38 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][  90/1563]  lr: 1.0000e-03  eta: 0:06:12  time: 0.0516  data_time: 0.0135  memory: 382  loss: 1.8950\n",
      "11/22 16:45:39 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 100/1563]  lr: 1.0000e-03  eta: 0:06:11  time: 0.0513  data_time: 0.0135  memory: 382  loss: 2.0333\n",
      "11/22 16:45:39 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 110/1563]  lr: 1.0000e-03  eta: 0:06:10  time: 0.0515  data_time: 0.0135  memory: 382  loss: 1.8740\n",
      "11/22 16:45:40 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 120/1563]  lr: 1.0000e-03  eta: 0:06:09  time: 0.0514  data_time: 0.0135  memory: 382  loss: 1.8757\n",
      "11/22 16:45:40 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 130/1563]  lr: 1.0000e-03  eta: 0:06:08  time: 0.0516  data_time: 0.0136  memory: 382  loss: 1.7964\n",
      "11/22 16:45:41 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 140/1563]  lr: 1.0000e-03  eta: 0:06:07  time: 0.0517  data_time: 0.0136  memory: 382  loss: 1.9340\n",
      "11/22 16:45:41 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 150/1563]  lr: 1.0000e-03  eta: 0:06:06  time: 0.0516  data_time: 0.0136  memory: 382  loss: 1.8404\n",
      "11/22 16:45:42 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 160/1563]  lr: 1.0000e-03  eta: 0:06:05  time: 0.0514  data_time: 0.0135  memory: 382  loss: 1.8404\n",
      "11/22 16:45:42 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 170/1563]  lr: 1.0000e-03  eta: 0:06:04  time: 0.0515  data_time: 0.0136  memory: 382  loss: 1.8419\n",
      "11/22 16:45:43 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 180/1563]  lr: 1.0000e-03  eta: 0:06:03  time: 0.0512  data_time: 0.0133  memory: 382  loss: 1.8487\n",
      "11/22 16:45:43 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 190/1563]  lr: 1.0000e-03  eta: 0:06:03  time: 0.0517  data_time: 0.0137  memory: 382  loss: 1.8069\n",
      "11/22 16:45:44 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 200/1563]  lr: 1.0000e-03  eta: 0:06:02  time: 0.0514  data_time: 0.0135  memory: 382  loss: 1.9490\n",
      "11/22 16:45:44 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 210/1563]  lr: 1.0000e-03  eta: 0:06:01  time: 0.0518  data_time: 0.0135  memory: 382  loss: 2.0255\n",
      "11/22 16:45:45 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 220/1563]  lr: 1.0000e-03  eta: 0:06:00  time: 0.0515  data_time: 0.0135  memory: 382  loss: 1.8988\n",
      "11/22 16:45:45 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 230/1563]  lr: 1.0000e-03  eta: 0:05:59  time: 0.0515  data_time: 0.0135  memory: 382  loss: 1.9589\n",
      "11/22 16:45:46 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 240/1563]  lr: 1.0000e-03  eta: 0:05:58  time: 0.0513  data_time: 0.0135  memory: 382  loss: 1.9171\n",
      "11/22 16:45:46 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 250/1563]  lr: 1.0000e-03  eta: 0:05:57  time: 0.0514  data_time: 0.0135  memory: 382  loss: 1.9336\n",
      "11/22 16:45:47 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 260/1563]  lr: 1.0000e-03  eta: 0:05:56  time: 0.0515  data_time: 0.0136  memory: 382  loss: 1.9064\n",
      "11/22 16:45:47 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 270/1563]  lr: 1.0000e-03  eta: 0:05:56  time: 0.0518  data_time: 0.0136  memory: 382  loss: 1.8528\n",
      "11/22 16:45:48 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 280/1563]  lr: 1.0000e-03  eta: 0:05:55  time: 0.0519  data_time: 0.0138  memory: 382  loss: 1.9756\n",
      "11/22 16:45:49 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 290/1563]  lr: 1.0000e-03  eta: 0:05:54  time: 0.0517  data_time: 0.0136  memory: 382  loss: 1.8577\n",
      "11/22 16:45:49 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 300/1563]  lr: 1.0000e-03  eta: 0:05:53  time: 0.0509  data_time: 0.0133  memory: 382  loss: 1.7939\n",
      "11/22 16:45:50 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 310/1563]  lr: 1.0000e-03  eta: 0:05:52  time: 0.0517  data_time: 0.0136  memory: 382  loss: 1.8862\n",
      "11/22 16:45:50 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 320/1563]  lr: 1.0000e-03  eta: 0:05:51  time: 0.0514  data_time: 0.0135  memory: 382  loss: 1.8484\n",
      "11/22 16:45:51 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 330/1563]  lr: 1.0000e-03  eta: 0:05:50  time: 0.0519  data_time: 0.0137  memory: 382  loss: 1.8681\n",
      "11/22 16:45:51 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 340/1563]  lr: 1.0000e-03  eta: 0:05:50  time: 0.0526  data_time: 0.0140  memory: 382  loss: 1.9015\n",
      "11/22 16:45:52 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 350/1563]  lr: 1.0000e-03  eta: 0:05:49  time: 0.0515  data_time: 0.0136  memory: 382  loss: 1.8918\n",
      "11/22 16:45:52 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 360/1563]  lr: 1.0000e-03  eta: 0:05:48  time: 0.0516  data_time: 0.0135  memory: 382  loss: 2.0049\n",
      "11/22 16:45:53 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 370/1563]  lr: 1.0000e-03  eta: 0:05:47  time: 0.0512  data_time: 0.0134  memory: 382  loss: 1.8901\n",
      "11/22 16:45:53 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 380/1563]  lr: 1.0000e-03  eta: 0:05:46  time: 0.0515  data_time: 0.0137  memory: 382  loss: 1.9105\n",
      "11/22 16:45:54 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 390/1563]  lr: 1.0000e-03  eta: 0:05:46  time: 0.0514  data_time: 0.0135  memory: 382  loss: 1.8478\n",
      "11/22 16:45:54 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 400/1563]  lr: 1.0000e-03  eta: 0:05:45  time: 0.0514  data_time: 0.0135  memory: 382  loss: 1.8279\n",
      "11/22 16:45:55 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 410/1563]  lr: 1.0000e-03  eta: 0:05:44  time: 0.0512  data_time: 0.0135  memory: 382  loss: 1.8644\n",
      "11/22 16:45:55 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 420/1563]  lr: 1.0000e-03  eta: 0:05:43  time: 0.0511  data_time: 0.0137  memory: 382  loss: 1.9658\n",
      "11/22 16:45:56 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 430/1563]  lr: 1.0000e-03  eta: 0:05:42  time: 0.0532  data_time: 0.0141  memory: 382  loss: 1.7715\n",
      "11/22 16:45:56 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Exp name: 20241122_164350\n",
      "11/22 16:45:56 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 440/1563]  lr: 1.0000e-03  eta: 0:05:42  time: 0.0521  data_time: 0.0140  memory: 382  loss: 2.0089\n",
      "11/22 16:45:57 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 450/1563]  lr: 1.0000e-03  eta: 0:05:41  time: 0.0515  data_time: 0.0135  memory: 382  loss: 1.7780\n",
      "11/22 16:45:57 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 460/1563]  lr: 1.0000e-03  eta: 0:05:40  time: 0.0516  data_time: 0.0136  memory: 382  loss: 1.7803\n",
      "11/22 16:45:58 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 470/1563]  lr: 1.0000e-03  eta: 0:05:39  time: 0.0519  data_time: 0.0137  memory: 382  loss: 1.8877\n",
      "11/22 16:45:58 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 480/1563]  lr: 1.0000e-03  eta: 0:05:38  time: 0.0520  data_time: 0.0137  memory: 382  loss: 1.9322\n",
      "11/22 16:45:59 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 490/1563]  lr: 1.0000e-03  eta: 0:05:38  time: 0.0518  data_time: 0.0137  memory: 382  loss: 1.8556\n",
      "11/22 16:45:59 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 500/1563]  lr: 1.0000e-03  eta: 0:05:37  time: 0.0523  data_time: 0.0140  memory: 382  loss: 1.7696\n",
      "11/22 16:46:00 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 510/1563]  lr: 1.0000e-03  eta: 0:05:36  time: 0.0543  data_time: 0.0145  memory: 382  loss: 1.7981\n",
      "11/22 16:46:00 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 520/1563]  lr: 1.0000e-03  eta: 0:05:35  time: 0.0560  data_time: 0.0145  memory: 382  loss: 1.7619\n",
      "11/22 16:46:01 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 530/1563]  lr: 1.0000e-03  eta: 0:05:35  time: 0.0561  data_time: 0.0145  memory: 382  loss: 1.9445\n",
      "11/22 16:46:02 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 540/1563]  lr: 1.0000e-03  eta: 0:05:34  time: 0.0560  data_time: 0.0144  memory: 382  loss: 1.9609\n",
      "11/22 16:46:02 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 550/1563]  lr: 1.0000e-03  eta: 0:05:34  time: 0.0556  data_time: 0.0145  memory: 382  loss: 1.8829\n",
      "11/22 16:46:03 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 560/1563]  lr: 1.0000e-03  eta: 0:05:33  time: 0.0556  data_time: 0.0144  memory: 382  loss: 1.7553\n",
      "11/22 16:46:03 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 570/1563]  lr: 1.0000e-03  eta: 0:05:32  time: 0.0546  data_time: 0.0140  memory: 382  loss: 1.8695\n",
      "11/22 16:46:04 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 580/1563]  lr: 1.0000e-03  eta: 0:05:31  time: 0.0535  data_time: 0.0136  memory: 382  loss: 1.9100\n",
      "11/22 16:46:04 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 590/1563]  lr: 1.0000e-03  eta: 0:05:31  time: 0.0526  data_time: 0.0136  memory: 382  loss: 1.8179\n",
      "11/22 16:46:05 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 600/1563]  lr: 1.0000e-03  eta: 0:05:30  time: 0.0518  data_time: 0.0137  memory: 382  loss: 1.7467\n",
      "11/22 16:46:05 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 610/1563]  lr: 1.0000e-03  eta: 0:05:29  time: 0.0517  data_time: 0.0137  memory: 382  loss: 1.9133\n",
      "11/22 16:46:06 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 620/1563]  lr: 1.0000e-03  eta: 0:05:28  time: 0.0524  data_time: 0.0140  memory: 382  loss: 1.8832\n",
      "11/22 16:46:06 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 630/1563]  lr: 1.0000e-03  eta: 0:05:28  time: 0.0518  data_time: 0.0136  memory: 382  loss: 1.8295\n",
      "11/22 16:46:07 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 640/1563]  lr: 1.0000e-03  eta: 0:05:27  time: 0.0514  data_time: 0.0135  memory: 382  loss: 1.7728\n",
      "11/22 16:46:07 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 650/1563]  lr: 1.0000e-03  eta: 0:05:26  time: 0.0516  data_time: 0.0136  memory: 382  loss: 1.8678\n",
      "11/22 16:46:08 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 660/1563]  lr: 1.0000e-03  eta: 0:05:25  time: 0.0514  data_time: 0.0134  memory: 382  loss: 1.7402\n",
      "11/22 16:46:08 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 670/1563]  lr: 1.0000e-03  eta: 0:05:25  time: 0.0513  data_time: 0.0134  memory: 382  loss: 1.8371\n",
      "11/22 16:46:09 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 680/1563]  lr: 1.0000e-03  eta: 0:05:24  time: 0.0529  data_time: 0.0141  memory: 382  loss: 1.8069\n",
      "11/22 16:46:10 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 690/1563]  lr: 1.0000e-03  eta: 0:05:23  time: 0.0518  data_time: 0.0133  memory: 382  loss: 1.8423\n",
      "11/22 16:46:10 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 700/1563]  lr: 1.0000e-03  eta: 0:05:22  time: 0.0518  data_time: 0.0137  memory: 382  loss: 1.7003\n",
      "11/22 16:46:11 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 710/1563]  lr: 1.0000e-03  eta: 0:05:22  time: 0.0513  data_time: 0.0138  memory: 382  loss: 1.7592\n",
      "11/22 16:46:11 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 720/1563]  lr: 1.0000e-03  eta: 0:05:21  time: 0.0513  data_time: 0.0136  memory: 382  loss: 1.7464\n",
      "11/22 16:46:12 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 730/1563]  lr: 1.0000e-03  eta: 0:05:20  time: 0.0511  data_time: 0.0134  memory: 382  loss: 1.7989\n",
      "11/22 16:46:12 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 740/1563]  lr: 1.0000e-03  eta: 0:05:19  time: 0.0509  data_time: 0.0135  memory: 382  loss: 1.8442\n",
      "11/22 16:46:13 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 750/1563]  lr: 1.0000e-03  eta: 0:05:19  time: 0.0508  data_time: 0.0135  memory: 382  loss: 1.7362\n",
      "11/22 16:46:13 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 760/1563]  lr: 1.0000e-03  eta: 0:05:18  time: 0.0522  data_time: 0.0135  memory: 382  loss: 1.8073\n",
      "11/22 16:46:14 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 770/1563]  lr: 1.0000e-03  eta: 0:05:17  time: 0.0522  data_time: 0.0135  memory: 382  loss: 1.7809\n",
      "11/22 16:46:14 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 780/1563]  lr: 1.0000e-03  eta: 0:05:17  time: 0.0523  data_time: 0.0136  memory: 382  loss: 1.7341\n",
      "11/22 16:46:15 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 790/1563]  lr: 1.0000e-03  eta: 0:05:16  time: 0.0533  data_time: 0.0138  memory: 382  loss: 1.7854\n",
      "11/22 16:46:15 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 800/1563]  lr: 1.0000e-03  eta: 0:05:15  time: 0.0528  data_time: 0.0137  memory: 382  loss: 1.8100\n",
      "11/22 16:46:16 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 810/1563]  lr: 1.0000e-03  eta: 0:05:14  time: 0.0531  data_time: 0.0137  memory: 382  loss: 1.9313\n",
      "11/22 16:46:16 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 820/1563]  lr: 1.0000e-03  eta: 0:05:14  time: 0.0531  data_time: 0.0138  memory: 382  loss: 1.8791\n",
      "11/22 16:46:17 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 830/1563]  lr: 1.0000e-03  eta: 0:05:13  time: 0.0528  data_time: 0.0138  memory: 382  loss: 1.7162\n",
      "11/22 16:46:17 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 840/1563]  lr: 1.0000e-03  eta: 0:05:12  time: 0.0526  data_time: 0.0135  memory: 382  loss: 1.9569\n",
      "11/22 16:46:18 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 850/1563]  lr: 1.0000e-03  eta: 0:05:12  time: 0.0526  data_time: 0.0135  memory: 382  loss: 1.8267\n",
      "11/22 16:46:18 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 860/1563]  lr: 1.0000e-03  eta: 0:05:11  time: 0.0527  data_time: 0.0135  memory: 382  loss: 1.7703\n",
      "11/22 16:46:19 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 870/1563]  lr: 1.0000e-03  eta: 0:05:10  time: 0.0525  data_time: 0.0135  memory: 382  loss: 1.8052\n",
      "11/22 16:46:19 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 880/1563]  lr: 1.0000e-03  eta: 0:05:10  time: 0.0490  data_time: 0.0138  memory: 382  loss: 1.8631\n",
      "11/22 16:46:20 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 890/1563]  lr: 1.0000e-03  eta: 0:05:09  time: 0.0516  data_time: 0.0138  memory: 382  loss: 1.8815\n",
      "11/22 16:46:20 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 900/1563]  lr: 1.0000e-03  eta: 0:05:08  time: 0.0465  data_time: 0.0137  memory: 382  loss: 1.8250\n",
      "11/22 16:46:21 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 910/1563]  lr: 1.0000e-03  eta: 0:05:07  time: 0.0518  data_time: 0.0138  memory: 382  loss: 1.7385\n",
      "11/22 16:46:21 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 920/1563]  lr: 1.0000e-03  eta: 0:05:07  time: 0.0515  data_time: 0.0137  memory: 382  loss: 1.8195\n",
      "11/22 16:46:22 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 930/1563]  lr: 1.0000e-03  eta: 0:05:06  time: 0.0518  data_time: 0.0137  memory: 382  loss: 1.7355\n",
      "11/22 16:46:22 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 940/1563]  lr: 1.0000e-03  eta: 0:05:05  time: 0.0512  data_time: 0.0135  memory: 382  loss: 1.8352\n",
      "11/22 16:46:23 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 950/1563]  lr: 1.0000e-03  eta: 0:05:04  time: 0.0513  data_time: 0.0136  memory: 382  loss: 1.9294\n",
      "11/22 16:46:23 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 960/1563]  lr: 1.0000e-03  eta: 0:05:04  time: 0.0523  data_time: 0.0138  memory: 382  loss: 1.6733\n",
      "11/22 16:46:24 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 970/1563]  lr: 1.0000e-03  eta: 0:05:03  time: 0.0518  data_time: 0.0138  memory: 382  loss: 1.7458\n",
      "11/22 16:46:25 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 980/1563]  lr: 1.0000e-03  eta: 0:05:02  time: 0.0512  data_time: 0.0135  memory: 382  loss: 1.7601\n",
      "11/22 16:46:25 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][ 990/1563]  lr: 1.0000e-03  eta: 0:05:02  time: 0.0514  data_time: 0.0136  memory: 382  loss: 1.8750\n",
      "11/22 16:46:26 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][1000/1563]  lr: 1.0000e-03  eta: 0:05:01  time: 0.0515  data_time: 0.0135  memory: 382  loss: 1.7647\n",
      "11/22 16:46:26 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][1010/1563]  lr: 1.0000e-03  eta: 0:05:00  time: 0.0531  data_time: 0.0145  memory: 382  loss: 1.7641\n",
      "11/22 16:46:27 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][1020/1563]  lr: 1.0000e-03  eta: 0:05:00  time: 0.0512  data_time: 0.0135  memory: 382  loss: 1.6066\n",
      "11/22 16:46:27 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][1030/1563]  lr: 1.0000e-03  eta: 0:04:59  time: 0.0514  data_time: 0.0136  memory: 382  loss: 1.8534\n",
      "11/22 16:46:28 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][1040/1563]  lr: 1.0000e-03  eta: 0:04:58  time: 0.0514  data_time: 0.0135  memory: 382  loss: 1.7043\n",
      "11/22 16:46:28 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][1050/1563]  lr: 1.0000e-03  eta: 0:04:58  time: 0.0514  data_time: 0.0136  memory: 382  loss: 1.6900\n",
      "11/22 16:46:29 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][1060/1563]  lr: 1.0000e-03  eta: 0:04:57  time: 0.0512  data_time: 0.0134  memory: 382  loss: 1.7221\n",
      "11/22 16:46:29 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][1070/1563]  lr: 1.0000e-03  eta: 0:04:56  time: 0.0516  data_time: 0.0137  memory: 382  loss: 1.6914\n",
      "11/22 16:46:30 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][1080/1563]  lr: 1.0000e-03  eta: 0:04:56  time: 0.0516  data_time: 0.0135  memory: 382  loss: 1.7516\n",
      "11/22 16:46:30 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][1090/1563]  lr: 1.0000e-03  eta: 0:04:55  time: 0.0518  data_time: 0.0137  memory: 382  loss: 1.7626\n",
      "11/22 16:46:31 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][1100/1563]  lr: 1.0000e-03  eta: 0:04:54  time: 0.0520  data_time: 0.0137  memory: 382  loss: 1.6875\n",
      "11/22 16:46:31 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][1110/1563]  lr: 1.0000e-03  eta: 0:04:54  time: 0.0556  data_time: 0.0146  memory: 382  loss: 1.8314\n",
      "11/22 16:46:32 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][1120/1563]  lr: 1.0000e-03  eta: 0:04:53  time: 0.0554  data_time: 0.0143  memory: 382  loss: 1.7458\n",
      "11/22 16:46:32 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][1130/1563]  lr: 1.0000e-03  eta: 0:04:52  time: 0.0555  data_time: 0.0144  memory: 382  loss: 1.7342\n",
      "11/22 16:46:33 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][1140/1563]  lr: 1.0000e-03  eta: 0:04:52  time: 0.0558  data_time: 0.0145  memory: 382  loss: 1.8697\n",
      "11/22 16:46:34 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][1150/1563]  lr: 1.0000e-03  eta: 0:04:51  time: 0.0594  data_time: 0.0162  memory: 382  loss: 1.8513\n",
      "11/22 16:46:34 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][1160/1563]  lr: 1.0000e-03  eta: 0:04:51  time: 0.0596  data_time: 0.0161  memory: 382  loss: 1.7320\n",
      "11/22 16:46:35 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][1170/1563]  lr: 1.0000e-03  eta: 0:04:50  time: 0.0583  data_time: 0.0160  memory: 382  loss: 1.7382\n",
      "11/22 16:46:35 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][1180/1563]  lr: 1.0000e-03  eta: 0:04:50  time: 0.0582  data_time: 0.0160  memory: 382  loss: 1.6267\n",
      "11/22 16:46:36 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][1190/1563]  lr: 1.0000e-03  eta: 0:04:49  time: 0.0580  data_time: 0.0158  memory: 382  loss: 1.8052\n",
      "11/22 16:46:36 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][1200/1563]  lr: 1.0000e-03  eta: 0:04:48  time: 0.0580  data_time: 0.0158  memory: 382  loss: 1.8120\n",
      "11/22 16:46:37 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][1210/1563]  lr: 1.0000e-03  eta: 0:04:48  time: 0.0561  data_time: 0.0159  memory: 382  loss: 1.7501\n",
      "11/22 16:46:38 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][1220/1563]  lr: 1.0000e-03  eta: 0:04:47  time: 0.0559  data_time: 0.0158  memory: 382  loss: 1.8753\n",
      "11/22 16:46:38 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][1230/1563]  lr: 1.0000e-03  eta: 0:04:47  time: 0.0580  data_time: 0.0159  memory: 382  loss: 1.8064\n",
      "11/22 16:46:39 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][1240/1563]  lr: 1.0000e-03  eta: 0:04:46  time: 0.0582  data_time: 0.0159  memory: 382  loss: 1.7679\n",
      "11/22 16:46:39 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][1250/1563]  lr: 1.0000e-03  eta: 0:04:46  time: 0.0569  data_time: 0.0159  memory: 382  loss: 1.7150\n",
      "11/22 16:46:40 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][1260/1563]  lr: 1.0000e-03  eta: 0:04:45  time: 0.0585  data_time: 0.0160  memory: 382  loss: 1.7895\n",
      "11/22 16:46:40 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][1270/1563]  lr: 1.0000e-03  eta: 0:04:44  time: 0.0580  data_time: 0.0158  memory: 382  loss: 1.7520\n",
      "11/22 16:46:41 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][1280/1563]  lr: 1.0000e-03  eta: 0:04:44  time: 0.0582  data_time: 0.0160  memory: 382  loss: 1.6606\n",
      "11/22 16:46:42 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][1290/1563]  lr: 1.0000e-03  eta: 0:04:43  time: 0.0580  data_time: 0.0158  memory: 382  loss: 1.6303\n",
      "11/22 16:46:42 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][1300/1563]  lr: 1.0000e-03  eta: 0:04:43  time: 0.0580  data_time: 0.0158  memory: 382  loss: 1.8094\n",
      "11/22 16:46:43 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][1310/1563]  lr: 1.0000e-03  eta: 0:04:42  time: 0.0582  data_time: 0.0160  memory: 382  loss: 1.7696\n",
      "11/22 16:46:43 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][1320/1563]  lr: 1.0000e-03  eta: 0:04:42  time: 0.0581  data_time: 0.0159  memory: 382  loss: 1.8476\n",
      "11/22 16:46:44 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][1330/1563]  lr: 1.0000e-03  eta: 0:04:41  time: 0.0581  data_time: 0.0159  memory: 382  loss: 1.7991\n",
      "11/22 16:46:45 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][1340/1563]  lr: 1.0000e-03  eta: 0:04:41  time: 0.0581  data_time: 0.0159  memory: 382  loss: 1.7261\n",
      "11/22 16:46:45 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][1350/1563]  lr: 1.0000e-03  eta: 0:04:40  time: 0.0580  data_time: 0.0158  memory: 382  loss: 1.7103\n",
      "11/22 16:46:46 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][1360/1563]  lr: 1.0000e-03  eta: 0:04:39  time: 0.0580  data_time: 0.0159  memory: 382  loss: 1.7356\n",
      "11/22 16:46:46 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][1370/1563]  lr: 1.0000e-03  eta: 0:04:39  time: 0.0581  data_time: 0.0158  memory: 382  loss: 1.8153\n",
      "11/22 16:46:47 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][1380/1563]  lr: 1.0000e-03  eta: 0:04:38  time: 0.0580  data_time: 0.0158  memory: 382  loss: 1.7560\n",
      "11/22 16:46:47 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][1390/1563]  lr: 1.0000e-03  eta: 0:04:38  time: 0.0580  data_time: 0.0158  memory: 382  loss: 1.6897\n",
      "11/22 16:46:48 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][1400/1563]  lr: 1.0000e-03  eta: 0:04:37  time: 0.0570  data_time: 0.0158  memory: 382  loss: 1.7431\n",
      "11/22 16:46:49 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][1410/1563]  lr: 1.0000e-03  eta: 0:04:37  time: 0.0551  data_time: 0.0160  memory: 382  loss: 1.7052\n",
      "11/22 16:46:49 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][1420/1563]  lr: 1.0000e-03  eta: 0:04:36  time: 0.0578  data_time: 0.0159  memory: 382  loss: 1.7328\n",
      "11/22 16:46:50 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][1430/1563]  lr: 1.0000e-03  eta: 0:04:35  time: 0.0580  data_time: 0.0159  memory: 382  loss: 1.7698\n",
      "11/22 16:46:50 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Exp name: 20241122_164350\n",
      "11/22 16:46:50 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][1440/1563]  lr: 1.0000e-03  eta: 0:04:35  time: 0.0542  data_time: 0.0161  memory: 382  loss: 1.7988\n",
      "11/22 16:46:51 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][1450/1563]  lr: 1.0000e-03  eta: 0:04:34  time: 0.0565  data_time: 0.0157  memory: 382  loss: 1.8104\n",
      "11/22 16:46:51 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][1460/1563]  lr: 1.0000e-03  eta: 0:04:34  time: 0.0577  data_time: 0.0158  memory: 382  loss: 1.8345\n",
      "11/22 16:46:52 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][1470/1563]  lr: 1.0000e-03  eta: 0:04:33  time: 0.0581  data_time: 0.0160  memory: 382  loss: 1.8332\n",
      "11/22 16:46:53 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][1480/1563]  lr: 1.0000e-03  eta: 0:04:33  time: 0.0578  data_time: 0.0158  memory: 382  loss: 1.5920\n",
      "11/22 16:46:53 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][1490/1563]  lr: 1.0000e-03  eta: 0:04:32  time: 0.0579  data_time: 0.0159  memory: 382  loss: 1.8411\n",
      "11/22 16:46:54 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][1500/1563]  lr: 1.0000e-03  eta: 0:04:31  time: 0.0579  data_time: 0.0158  memory: 382  loss: 1.6966\n",
      "11/22 16:46:54 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][1510/1563]  lr: 1.0000e-03  eta: 0:04:31  time: 0.0580  data_time: 0.0159  memory: 382  loss: 1.7776\n",
      "11/22 16:46:55 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][1520/1563]  lr: 1.0000e-03  eta: 0:04:30  time: 0.0566  data_time: 0.0159  memory: 382  loss: 1.7656\n",
      "11/22 16:46:55 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][1530/1563]  lr: 1.0000e-03  eta: 0:04:30  time: 0.0554  data_time: 0.0158  memory: 382  loss: 1.7661\n",
      "11/22 16:46:56 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][1540/1563]  lr: 1.0000e-03  eta: 0:04:29  time: 0.0571  data_time: 0.0159  memory: 382  loss: 1.7557\n",
      "11/22 16:46:57 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][1550/1563]  lr: 1.0000e-03  eta: 0:04:29  time: 0.0578  data_time: 0.0159  memory: 382  loss: 1.7437\n",
      "11/22 16:46:57 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [2][1560/1563]  lr: 1.0000e-03  eta: 0:04:28  time: 0.0576  data_time: 0.0158  memory: 382  loss: 1.7960\n",
      "11/22 16:46:57 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Exp name: 20241122_164350\n",
      "11/22 16:46:57 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Saving checkpoint at 2 epochs\n",
      "11/22 16:46:58 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [2][ 10/313]    eta: 0:00:06  time: 0.0222  data_time: 0.0117  memory: 382  \n",
      "11/22 16:46:58 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [2][ 20/313]    eta: 0:00:06  time: 0.0193  data_time: 0.0095  memory: 225  \n",
      "11/22 16:46:59 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [2][ 30/313]    eta: 0:00:05  time: 0.0174  data_time: 0.0086  memory: 225  \n",
      "11/22 16:46:59 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [2][ 40/313]    eta: 0:00:05  time: 0.0175  data_time: 0.0087  memory: 225  \n",
      "11/22 16:46:59 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [2][ 50/313]    eta: 0:00:04  time: 0.0174  data_time: 0.0086  memory: 225  \n",
      "11/22 16:46:59 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [2][ 60/313]    eta: 0:00:04  time: 0.0176  data_time: 0.0087  memory: 225  \n",
      "11/22 16:46:59 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [2][ 70/313]    eta: 0:00:04  time: 0.0176  data_time: 0.0086  memory: 225  \n",
      "11/22 16:46:59 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [2][ 80/313]    eta: 0:00:04  time: 0.0175  data_time: 0.0086  memory: 225  \n",
      "11/22 16:47:00 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [2][ 90/313]    eta: 0:00:04  time: 0.0175  data_time: 0.0087  memory: 225  \n",
      "11/22 16:47:00 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [2][100/313]    eta: 0:00:03  time: 0.0175  data_time: 0.0086  memory: 225  \n",
      "11/22 16:47:00 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [2][110/313]    eta: 0:00:03  time: 0.0176  data_time: 0.0087  memory: 225  \n",
      "11/22 16:47:00 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [2][120/313]    eta: 0:00:03  time: 0.0175  data_time: 0.0086  memory: 225  \n",
      "11/22 16:47:00 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [2][130/313]    eta: 0:00:03  time: 0.0175  data_time: 0.0086  memory: 225  \n",
      "11/22 16:47:01 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [2][140/313]    eta: 0:00:03  time: 0.0175  data_time: 0.0086  memory: 225  \n",
      "11/22 16:47:01 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [2][150/313]    eta: 0:00:02  time: 0.0176  data_time: 0.0087  memory: 225  \n",
      "11/22 16:47:01 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [2][160/313]    eta: 0:00:02  time: 0.0175  data_time: 0.0086  memory: 225  \n",
      "11/22 16:47:01 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [2][170/313]    eta: 0:00:02  time: 0.0176  data_time: 0.0087  memory: 225  \n",
      "11/22 16:47:01 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [2][180/313]    eta: 0:00:02  time: 0.0175  data_time: 0.0086  memory: 225  \n",
      "11/22 16:47:01 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [2][190/313]    eta: 0:00:02  time: 0.0175  data_time: 0.0086  memory: 225  \n",
      "11/22 16:47:02 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [2][200/313]    eta: 0:00:02  time: 0.0175  data_time: 0.0086  memory: 225  \n",
      "11/22 16:47:02 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [2][210/313]    eta: 0:00:01  time: 0.0179  data_time: 0.0088  memory: 225  \n",
      "11/22 16:47:02 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [2][220/313]    eta: 0:00:01  time: 0.0175  data_time: 0.0086  memory: 225  \n",
      "11/22 16:47:02 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [2][230/313]    eta: 0:00:01  time: 0.0175  data_time: 0.0086  memory: 225  \n",
      "11/22 16:47:02 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [2][240/313]    eta: 0:00:01  time: 0.0175  data_time: 0.0086  memory: 225  \n",
      "11/22 16:47:02 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [2][250/313]    eta: 0:00:01  time: 0.0174  data_time: 0.0086  memory: 225  \n",
      "11/22 16:47:03 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [2][260/313]    eta: 0:00:00  time: 0.0174  data_time: 0.0086  memory: 225  \n",
      "11/22 16:47:03 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [2][270/313]    eta: 0:00:00  time: 0.0177  data_time: 0.0087  memory: 225  \n",
      "11/22 16:47:03 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [2][280/313]    eta: 0:00:00  time: 0.0175  data_time: 0.0087  memory: 225  \n",
      "11/22 16:47:03 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [2][290/313]    eta: 0:00:00  time: 0.0177  data_time: 0.0087  memory: 225  \n",
      "11/22 16:47:03 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [2][300/313]    eta: 0:00:00  time: 0.0176  data_time: 0.0087  memory: 225  \n",
      "11/22 16:47:04 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [2][310/313]    eta: 0:00:00  time: 0.0176  data_time: 0.0087  memory: 225  \n",
      "11/22 16:47:04 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [2][313/313]    accuracy: 43.0900  data_time: 0.0087  time: 0.0177\n",
      "11/22 16:47:04 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][  10/1563]  lr: 1.0000e-03  eta: 0:04:27  time: 0.0536  data_time: 0.0138  memory: 382  loss: 1.7544\n",
      "11/22 16:47:05 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][  20/1563]  lr: 1.0000e-03  eta: 0:04:27  time: 0.0531  data_time: 0.0136  memory: 382  loss: 1.8709\n",
      "11/22 16:47:05 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][  30/1563]  lr: 1.0000e-03  eta: 0:04:26  time: 0.0539  data_time: 0.0140  memory: 382  loss: 1.7736\n",
      "11/22 16:47:06 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][  40/1563]  lr: 1.0000e-03  eta: 0:04:25  time: 0.0540  data_time: 0.0140  memory: 382  loss: 1.7101\n",
      "11/22 16:47:06 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][  50/1563]  lr: 1.0000e-03  eta: 0:04:25  time: 0.0541  data_time: 0.0141  memory: 382  loss: 1.6691\n",
      "11/22 16:47:07 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][  60/1563]  lr: 1.0000e-03  eta: 0:04:24  time: 0.0539  data_time: 0.0138  memory: 382  loss: 1.7272\n",
      "11/22 16:47:07 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][  70/1563]  lr: 1.0000e-03  eta: 0:04:24  time: 0.0542  data_time: 0.0140  memory: 382  loss: 1.6619\n",
      "11/22 16:47:08 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][  80/1563]  lr: 1.0000e-03  eta: 0:04:23  time: 0.0538  data_time: 0.0139  memory: 382  loss: 1.6607\n",
      "11/22 16:47:08 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][  90/1563]  lr: 1.0000e-03  eta: 0:04:22  time: 0.0541  data_time: 0.0141  memory: 382  loss: 1.6077\n",
      "11/22 16:47:09 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 100/1563]  lr: 1.0000e-03  eta: 0:04:22  time: 0.0541  data_time: 0.0140  memory: 382  loss: 1.6063\n",
      "11/22 16:47:10 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 110/1563]  lr: 1.0000e-03  eta: 0:04:21  time: 0.0544  data_time: 0.0141  memory: 382  loss: 1.6782\n",
      "11/22 16:47:10 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 120/1563]  lr: 1.0000e-03  eta: 0:04:20  time: 0.0549  data_time: 0.0143  memory: 382  loss: 1.8019\n",
      "11/22 16:47:11 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 130/1563]  lr: 1.0000e-03  eta: 0:04:20  time: 0.0542  data_time: 0.0141  memory: 382  loss: 1.6718\n",
      "11/22 16:47:11 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 140/1563]  lr: 1.0000e-03  eta: 0:04:19  time: 0.0520  data_time: 0.0144  memory: 382  loss: 1.6988\n",
      "11/22 16:47:12 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 150/1563]  lr: 1.0000e-03  eta: 0:04:19  time: 0.0540  data_time: 0.0145  memory: 382  loss: 1.7076\n",
      "11/22 16:47:12 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 160/1563]  lr: 1.0000e-03  eta: 0:04:18  time: 0.0562  data_time: 0.0147  memory: 382  loss: 1.6644\n",
      "11/22 16:47:13 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 170/1563]  lr: 1.0000e-03  eta: 0:04:17  time: 0.0559  data_time: 0.0146  memory: 382  loss: 1.7423\n",
      "11/22 16:47:13 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 180/1563]  lr: 1.0000e-03  eta: 0:04:17  time: 0.0535  data_time: 0.0147  memory: 382  loss: 1.6710\n",
      "11/22 16:47:14 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 190/1563]  lr: 1.0000e-03  eta: 0:04:16  time: 0.0535  data_time: 0.0146  memory: 382  loss: 1.6126\n",
      "11/22 16:47:14 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 200/1563]  lr: 1.0000e-03  eta: 0:04:16  time: 0.0534  data_time: 0.0143  memory: 382  loss: 1.7686\n",
      "11/22 16:47:15 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 210/1563]  lr: 1.0000e-03  eta: 0:04:15  time: 0.0521  data_time: 0.0137  memory: 382  loss: 1.6462\n",
      "11/22 16:47:15 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 220/1563]  lr: 1.0000e-03  eta: 0:04:14  time: 0.0525  data_time: 0.0138  memory: 382  loss: 1.6834\n",
      "11/22 16:47:16 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 230/1563]  lr: 1.0000e-03  eta: 0:04:14  time: 0.0526  data_time: 0.0139  memory: 382  loss: 1.8183\n",
      "11/22 16:47:16 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 240/1563]  lr: 1.0000e-03  eta: 0:04:13  time: 0.0533  data_time: 0.0143  memory: 382  loss: 1.5796\n",
      "11/22 16:47:17 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 250/1563]  lr: 1.0000e-03  eta: 0:04:12  time: 0.0507  data_time: 0.0134  memory: 382  loss: 1.6061\n",
      "11/22 16:47:18 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 260/1563]  lr: 1.0000e-03  eta: 0:04:12  time: 0.0520  data_time: 0.0137  memory: 382  loss: 1.7223\n",
      "11/22 16:47:18 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 270/1563]  lr: 1.0000e-03  eta: 0:04:11  time: 0.0514  data_time: 0.0136  memory: 382  loss: 1.6142\n",
      "11/22 16:47:19 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 280/1563]  lr: 1.0000e-03  eta: 0:04:10  time: 0.0514  data_time: 0.0136  memory: 382  loss: 1.6779\n",
      "11/22 16:47:19 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 290/1563]  lr: 1.0000e-03  eta: 0:04:10  time: 0.0514  data_time: 0.0136  memory: 382  loss: 1.8518\n",
      "11/22 16:47:20 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 300/1563]  lr: 1.0000e-03  eta: 0:04:09  time: 0.0530  data_time: 0.0138  memory: 382  loss: 1.6435\n",
      "11/22 16:47:20 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 310/1563]  lr: 1.0000e-03  eta: 0:04:09  time: 0.0539  data_time: 0.0138  memory: 382  loss: 1.6019\n",
      "11/22 16:47:21 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 320/1563]  lr: 1.0000e-03  eta: 0:04:08  time: 0.0532  data_time: 0.0137  memory: 382  loss: 1.6349\n",
      "11/22 16:47:21 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 330/1563]  lr: 1.0000e-03  eta: 0:04:07  time: 0.0529  data_time: 0.0139  memory: 382  loss: 1.7829\n",
      "11/22 16:47:22 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 340/1563]  lr: 1.0000e-03  eta: 0:04:07  time: 0.0518  data_time: 0.0136  memory: 382  loss: 1.7509\n",
      "11/22 16:47:22 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 350/1563]  lr: 1.0000e-03  eta: 0:04:06  time: 0.0510  data_time: 0.0135  memory: 382  loss: 1.7433\n",
      "11/22 16:47:23 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 360/1563]  lr: 1.0000e-03  eta: 0:04:05  time: 0.0516  data_time: 0.0137  memory: 382  loss: 1.6134\n",
      "11/22 16:47:23 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 370/1563]  lr: 1.0000e-03  eta: 0:04:05  time: 0.0511  data_time: 0.0134  memory: 382  loss: 1.6078\n",
      "11/22 16:47:24 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 380/1563]  lr: 1.0000e-03  eta: 0:04:04  time: 0.0510  data_time: 0.0135  memory: 382  loss: 1.6183\n",
      "11/22 16:47:24 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 390/1563]  lr: 1.0000e-03  eta: 0:04:04  time: 0.0531  data_time: 0.0137  memory: 382  loss: 1.7506\n",
      "11/22 16:47:25 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 400/1563]  lr: 1.0000e-03  eta: 0:04:03  time: 0.0531  data_time: 0.0136  memory: 382  loss: 1.7401\n",
      "11/22 16:47:25 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 410/1563]  lr: 1.0000e-03  eta: 0:04:02  time: 0.0537  data_time: 0.0138  memory: 382  loss: 1.6120\n",
      "11/22 16:47:26 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 420/1563]  lr: 1.0000e-03  eta: 0:04:02  time: 0.0532  data_time: 0.0136  memory: 382  loss: 1.7460\n",
      "11/22 16:47:26 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 430/1563]  lr: 1.0000e-03  eta: 0:04:01  time: 0.0521  data_time: 0.0137  memory: 382  loss: 1.7638\n",
      "11/22 16:47:27 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 440/1563]  lr: 1.0000e-03  eta: 0:04:00  time: 0.0511  data_time: 0.0138  memory: 382  loss: 1.6975\n",
      "11/22 16:47:27 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 450/1563]  lr: 1.0000e-03  eta: 0:04:00  time: 0.0514  data_time: 0.0135  memory: 382  loss: 1.6568\n",
      "11/22 16:47:28 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 460/1563]  lr: 1.0000e-03  eta: 0:03:59  time: 0.0531  data_time: 0.0137  memory: 382  loss: 1.7361\n",
      "11/22 16:47:29 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 470/1563]  lr: 1.0000e-03  eta: 0:03:59  time: 0.0541  data_time: 0.0140  memory: 382  loss: 1.6191\n",
      "11/22 16:47:29 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 480/1563]  lr: 1.0000e-03  eta: 0:03:58  time: 0.0539  data_time: 0.0140  memory: 382  loss: 1.6996\n",
      "11/22 16:47:30 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 490/1563]  lr: 1.0000e-03  eta: 0:03:57  time: 0.0538  data_time: 0.0139  memory: 382  loss: 1.6323\n",
      "11/22 16:47:30 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 500/1563]  lr: 1.0000e-03  eta: 0:03:57  time: 0.0539  data_time: 0.0139  memory: 382  loss: 1.6949\n",
      "11/22 16:47:31 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 510/1563]  lr: 1.0000e-03  eta: 0:03:56  time: 0.0541  data_time: 0.0139  memory: 382  loss: 1.7518\n",
      "11/22 16:47:31 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 520/1563]  lr: 1.0000e-03  eta: 0:03:56  time: 0.0538  data_time: 0.0138  memory: 382  loss: 1.7295\n",
      "11/22 16:47:32 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 530/1563]  lr: 1.0000e-03  eta: 0:03:55  time: 0.0541  data_time: 0.0140  memory: 382  loss: 1.7763\n",
      "11/22 16:47:32 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 540/1563]  lr: 1.0000e-03  eta: 0:03:54  time: 0.0539  data_time: 0.0139  memory: 382  loss: 1.6836\n",
      "11/22 16:47:33 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 550/1563]  lr: 1.0000e-03  eta: 0:03:54  time: 0.0539  data_time: 0.0140  memory: 382  loss: 1.7488\n",
      "11/22 16:47:33 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 560/1563]  lr: 1.0000e-03  eta: 0:03:53  time: 0.0538  data_time: 0.0139  memory: 382  loss: 1.6240\n",
      "11/22 16:47:34 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 570/1563]  lr: 1.0000e-03  eta: 0:03:53  time: 0.0537  data_time: 0.0138  memory: 382  loss: 1.6455\n",
      "11/22 16:47:34 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 580/1563]  lr: 1.0000e-03  eta: 0:03:52  time: 0.0538  data_time: 0.0139  memory: 382  loss: 1.8316\n",
      "11/22 16:47:35 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 590/1563]  lr: 1.0000e-03  eta: 0:03:51  time: 0.0540  data_time: 0.0139  memory: 382  loss: 1.5671\n",
      "11/22 16:47:36 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 600/1563]  lr: 1.0000e-03  eta: 0:03:51  time: 0.0538  data_time: 0.0138  memory: 382  loss: 1.7360\n",
      "11/22 16:47:36 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 610/1563]  lr: 1.0000e-03  eta: 0:03:50  time: 0.0539  data_time: 0.0139  memory: 382  loss: 1.7328\n",
      "11/22 16:47:37 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 620/1563]  lr: 1.0000e-03  eta: 0:03:50  time: 0.0539  data_time: 0.0140  memory: 382  loss: 1.6618\n",
      "11/22 16:47:37 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 630/1563]  lr: 1.0000e-03  eta: 0:03:49  time: 0.0537  data_time: 0.0137  memory: 382  loss: 1.6549\n",
      "11/22 16:47:38 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 640/1563]  lr: 1.0000e-03  eta: 0:03:48  time: 0.0536  data_time: 0.0138  memory: 382  loss: 1.7133\n",
      "11/22 16:47:38 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 650/1563]  lr: 1.0000e-03  eta: 0:03:48  time: 0.0540  data_time: 0.0140  memory: 382  loss: 1.7738\n",
      "11/22 16:47:39 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 660/1563]  lr: 1.0000e-03  eta: 0:03:47  time: 0.0546  data_time: 0.0141  memory: 382  loss: 1.7275\n",
      "11/22 16:47:39 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 670/1563]  lr: 1.0000e-03  eta: 0:03:47  time: 0.0539  data_time: 0.0139  memory: 382  loss: 1.7047\n",
      "11/22 16:47:40 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 680/1563]  lr: 1.0000e-03  eta: 0:03:46  time: 0.0532  data_time: 0.0140  memory: 382  loss: 1.6989\n",
      "11/22 16:47:40 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 690/1563]  lr: 1.0000e-03  eta: 0:03:46  time: 0.0537  data_time: 0.0140  memory: 382  loss: 1.7081\n",
      "11/22 16:47:41 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 700/1563]  lr: 1.0000e-03  eta: 0:03:45  time: 0.0541  data_time: 0.0139  memory: 382  loss: 1.5826\n",
      "11/22 16:47:41 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 710/1563]  lr: 1.0000e-03  eta: 0:03:44  time: 0.0541  data_time: 0.0141  memory: 382  loss: 1.6385\n",
      "11/22 16:47:42 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 720/1563]  lr: 1.0000e-03  eta: 0:03:44  time: 0.0538  data_time: 0.0139  memory: 382  loss: 1.6755\n",
      "11/22 16:47:43 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 730/1563]  lr: 1.0000e-03  eta: 0:03:43  time: 0.0541  data_time: 0.0141  memory: 382  loss: 1.6512\n",
      "11/22 16:47:43 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 740/1563]  lr: 1.0000e-03  eta: 0:03:43  time: 0.0540  data_time: 0.0140  memory: 382  loss: 1.7752\n",
      "11/22 16:47:44 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 750/1563]  lr: 1.0000e-03  eta: 0:03:42  time: 0.0538  data_time: 0.0138  memory: 382  loss: 1.6108\n",
      "11/22 16:47:44 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 760/1563]  lr: 1.0000e-03  eta: 0:03:41  time: 0.0538  data_time: 0.0139  memory: 382  loss: 1.7641\n",
      "11/22 16:47:45 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 770/1563]  lr: 1.0000e-03  eta: 0:03:41  time: 0.0539  data_time: 0.0139  memory: 382  loss: 1.7119\n",
      "11/22 16:47:45 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 780/1563]  lr: 1.0000e-03  eta: 0:03:40  time: 0.0538  data_time: 0.0139  memory: 382  loss: 1.6977\n",
      "11/22 16:47:46 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 790/1563]  lr: 1.0000e-03  eta: 0:03:40  time: 0.0540  data_time: 0.0139  memory: 382  loss: 1.7686\n",
      "11/22 16:47:46 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 800/1563]  lr: 1.0000e-03  eta: 0:03:39  time: 0.0542  data_time: 0.0142  memory: 382  loss: 1.6454\n",
      "11/22 16:47:47 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 810/1563]  lr: 1.0000e-03  eta: 0:03:38  time: 0.0512  data_time: 0.0137  memory: 382  loss: 1.5920\n",
      "11/22 16:47:47 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 820/1563]  lr: 1.0000e-03  eta: 0:03:38  time: 0.0519  data_time: 0.0137  memory: 382  loss: 1.7565\n",
      "11/22 16:47:48 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 830/1563]  lr: 1.0000e-03  eta: 0:03:37  time: 0.0521  data_time: 0.0140  memory: 382  loss: 1.6128\n",
      "11/22 16:47:48 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 840/1563]  lr: 1.0000e-03  eta: 0:03:37  time: 0.0538  data_time: 0.0140  memory: 382  loss: 1.6129\n",
      "11/22 16:47:49 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 850/1563]  lr: 1.0000e-03  eta: 0:03:36  time: 0.0539  data_time: 0.0141  memory: 382  loss: 1.6814\n",
      "11/22 16:47:49 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 860/1563]  lr: 1.0000e-03  eta: 0:03:35  time: 0.0543  data_time: 0.0141  memory: 382  loss: 1.6300\n",
      "11/22 16:47:50 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 870/1563]  lr: 1.0000e-03  eta: 0:03:35  time: 0.0531  data_time: 0.0139  memory: 382  loss: 1.8181\n",
      "11/22 16:47:50 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Exp name: 20241122_164350\n",
      "11/22 16:47:51 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 880/1563]  lr: 1.0000e-03  eta: 0:03:34  time: 0.0543  data_time: 0.0141  memory: 382  loss: 1.7343\n",
      "11/22 16:47:51 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 890/1563]  lr: 1.0000e-03  eta: 0:03:34  time: 0.0538  data_time: 0.0139  memory: 382  loss: 1.5847\n",
      "11/22 16:47:52 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 900/1563]  lr: 1.0000e-03  eta: 0:03:33  time: 0.0522  data_time: 0.0139  memory: 382  loss: 1.6588\n",
      "11/22 16:47:52 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 910/1563]  lr: 1.0000e-03  eta: 0:03:32  time: 0.0536  data_time: 0.0139  memory: 382  loss: 1.5980\n",
      "11/22 16:47:53 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 920/1563]  lr: 1.0000e-03  eta: 0:03:32  time: 0.0548  data_time: 0.0143  memory: 382  loss: 1.6948\n",
      "11/22 16:47:53 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 930/1563]  lr: 1.0000e-03  eta: 0:03:31  time: 0.0539  data_time: 0.0139  memory: 382  loss: 1.7071\n",
      "11/22 16:47:54 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 940/1563]  lr: 1.0000e-03  eta: 0:03:31  time: 0.0541  data_time: 0.0139  memory: 382  loss: 1.7188\n",
      "11/22 16:47:54 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 950/1563]  lr: 1.0000e-03  eta: 0:03:30  time: 0.0540  data_time: 0.0139  memory: 382  loss: 1.6856\n",
      "11/22 16:47:55 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 960/1563]  lr: 1.0000e-03  eta: 0:03:30  time: 0.0541  data_time: 0.0140  memory: 382  loss: 1.5540\n",
      "11/22 16:47:55 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 970/1563]  lr: 1.0000e-03  eta: 0:03:29  time: 0.0544  data_time: 0.0140  memory: 382  loss: 1.6686\n",
      "11/22 16:47:56 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 980/1563]  lr: 1.0000e-03  eta: 0:03:28  time: 0.0546  data_time: 0.0144  memory: 382  loss: 1.6318\n",
      "11/22 16:47:56 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][ 990/1563]  lr: 1.0000e-03  eta: 0:03:28  time: 0.0522  data_time: 0.0140  memory: 382  loss: 1.6669\n",
      "11/22 16:47:57 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][1000/1563]  lr: 1.0000e-03  eta: 0:03:27  time: 0.0516  data_time: 0.0139  memory: 382  loss: 1.7148\n",
      "11/22 16:47:57 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][1010/1563]  lr: 1.0000e-03  eta: 0:03:27  time: 0.0517  data_time: 0.0137  memory: 382  loss: 1.6002\n",
      "11/22 16:47:58 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][1020/1563]  lr: 1.0000e-03  eta: 0:03:26  time: 0.0538  data_time: 0.0140  memory: 382  loss: 1.6180\n",
      "11/22 16:47:59 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][1030/1563]  lr: 1.0000e-03  eta: 0:03:25  time: 0.0537  data_time: 0.0139  memory: 382  loss: 1.6952\n",
      "11/22 16:47:59 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][1040/1563]  lr: 1.0000e-03  eta: 0:03:25  time: 0.0540  data_time: 0.0140  memory: 382  loss: 1.5350\n",
      "11/22 16:48:00 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][1050/1563]  lr: 1.0000e-03  eta: 0:03:24  time: 0.0539  data_time: 0.0140  memory: 382  loss: 1.6214\n",
      "11/22 16:48:00 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][1060/1563]  lr: 1.0000e-03  eta: 0:03:24  time: 0.0584  data_time: 0.0166  memory: 382  loss: 1.6768\n",
      "11/22 16:48:01 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][1070/1563]  lr: 1.0000e-03  eta: 0:03:23  time: 0.0563  data_time: 0.0163  memory: 382  loss: 1.6510\n",
      "11/22 16:48:01 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][1080/1563]  lr: 1.0000e-03  eta: 0:03:23  time: 0.0530  data_time: 0.0142  memory: 382  loss: 1.6150\n",
      "11/22 16:48:02 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][1090/1563]  lr: 1.0000e-03  eta: 0:03:22  time: 0.0580  data_time: 0.0170  memory: 382  loss: 1.5842\n",
      "11/22 16:48:02 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][1100/1563]  lr: 1.0000e-03  eta: 0:03:21  time: 0.0567  data_time: 0.0164  memory: 382  loss: 1.8733\n",
      "11/22 16:48:03 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][1110/1563]  lr: 1.0000e-03  eta: 0:03:21  time: 0.0530  data_time: 0.0143  memory: 382  loss: 1.6146\n",
      "11/22 16:48:04 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][1120/1563]  lr: 1.0000e-03  eta: 0:03:20  time: 0.0529  data_time: 0.0141  memory: 382  loss: 1.5651\n",
      "11/22 16:48:04 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][1130/1563]  lr: 1.0000e-03  eta: 0:03:20  time: 0.0705  data_time: 0.0228  memory: 382  loss: 1.6882\n",
      "11/22 16:48:05 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][1140/1563]  lr: 1.0000e-03  eta: 0:03:19  time: 0.0755  data_time: 0.0258  memory: 382  loss: 1.5309\n",
      "11/22 16:48:06 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][1150/1563]  lr: 1.0000e-03  eta: 0:03:19  time: 0.0540  data_time: 0.0171  memory: 382  loss: 1.7008\n",
      "11/22 16:48:06 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][1160/1563]  lr: 1.0000e-03  eta: 0:03:18  time: 0.0561  data_time: 0.0183  memory: 382  loss: 1.6935\n",
      "11/22 16:48:07 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][1170/1563]  lr: 1.0000e-03  eta: 0:03:18  time: 0.0485  data_time: 0.0138  memory: 382  loss: 1.5953\n",
      "11/22 16:48:07 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][1180/1563]  lr: 1.0000e-03  eta: 0:03:17  time: 0.0553  data_time: 0.0184  memory: 382  loss: 1.7106\n",
      "11/22 16:48:08 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][1190/1563]  lr: 1.0000e-03  eta: 0:03:16  time: 0.0507  data_time: 0.0132  memory: 382  loss: 1.6371\n",
      "11/22 16:48:08 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][1200/1563]  lr: 1.0000e-03  eta: 0:03:16  time: 0.0531  data_time: 0.0167  memory: 382  loss: 1.6515\n",
      "11/22 16:48:09 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][1210/1563]  lr: 1.0000e-03  eta: 0:03:15  time: 0.0476  data_time: 0.0132  memory: 382  loss: 1.5957\n",
      "11/22 16:48:09 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][1220/1563]  lr: 1.0000e-03  eta: 0:03:15  time: 0.0533  data_time: 0.0165  memory: 382  loss: 1.7322\n",
      "11/22 16:48:10 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][1230/1563]  lr: 1.0000e-03  eta: 0:03:14  time: 0.0526  data_time: 0.0139  memory: 382  loss: 1.7070\n",
      "11/22 16:48:10 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][1240/1563]  lr: 1.0000e-03  eta: 0:03:14  time: 0.0570  data_time: 0.0153  memory: 382  loss: 1.6752\n",
      "11/22 16:48:11 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][1250/1563]  lr: 1.0000e-03  eta: 0:03:13  time: 0.0903  data_time: 0.0324  memory: 382  loss: 1.5140\n",
      "11/22 16:48:12 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][1260/1563]  lr: 1.0000e-03  eta: 0:03:13  time: 0.0774  data_time: 0.0272  memory: 382  loss: 1.6021\n",
      "11/22 16:48:13 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][1270/1563]  lr: 1.0000e-03  eta: 0:03:12  time: 0.0670  data_time: 0.0222  memory: 382  loss: 1.7170\n",
      "11/22 16:48:13 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][1280/1563]  lr: 1.0000e-03  eta: 0:03:12  time: 0.0597  data_time: 0.0172  memory: 382  loss: 1.6965\n",
      "11/22 16:48:14 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][1290/1563]  lr: 1.0000e-03  eta: 0:03:11  time: 0.0571  data_time: 0.0169  memory: 382  loss: 1.5570\n",
      "11/22 16:48:14 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][1300/1563]  lr: 1.0000e-03  eta: 0:03:11  time: 0.0573  data_time: 0.0152  memory: 382  loss: 1.7423\n",
      "11/22 16:48:15 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][1310/1563]  lr: 1.0000e-03  eta: 0:03:10  time: 0.0559  data_time: 0.0145  memory: 382  loss: 1.6773\n",
      "11/22 16:48:15 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][1320/1563]  lr: 1.0000e-03  eta: 0:03:10  time: 0.0553  data_time: 0.0144  memory: 382  loss: 1.6053\n",
      "11/22 16:48:16 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][1330/1563]  lr: 1.0000e-03  eta: 0:03:09  time: 0.0540  data_time: 0.0138  memory: 382  loss: 1.7449\n",
      "11/22 16:48:17 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][1340/1563]  lr: 1.0000e-03  eta: 0:03:08  time: 0.0538  data_time: 0.0140  memory: 382  loss: 1.7399\n",
      "11/22 16:48:17 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][1350/1563]  lr: 1.0000e-03  eta: 0:03:08  time: 0.0524  data_time: 0.0139  memory: 382  loss: 1.5348\n",
      "11/22 16:48:18 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][1360/1563]  lr: 1.0000e-03  eta: 0:03:07  time: 0.0526  data_time: 0.0140  memory: 382  loss: 1.5117\n",
      "11/22 16:48:18 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][1370/1563]  lr: 1.0000e-03  eta: 0:03:07  time: 0.0524  data_time: 0.0138  memory: 382  loss: 1.6947\n",
      "11/22 16:48:19 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][1380/1563]  lr: 1.0000e-03  eta: 0:03:06  time: 0.0522  data_time: 0.0139  memory: 382  loss: 1.6303\n",
      "11/22 16:48:19 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][1390/1563]  lr: 1.0000e-03  eta: 0:03:05  time: 0.0522  data_time: 0.0139  memory: 382  loss: 1.6375\n",
      "11/22 16:48:20 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][1400/1563]  lr: 1.0000e-03  eta: 0:03:05  time: 0.0523  data_time: 0.0137  memory: 382  loss: 1.6429\n",
      "11/22 16:48:20 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][1410/1563]  lr: 1.0000e-03  eta: 0:03:04  time: 0.0525  data_time: 0.0139  memory: 382  loss: 1.6803\n",
      "11/22 16:48:21 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][1420/1563]  lr: 1.0000e-03  eta: 0:03:04  time: 0.0517  data_time: 0.0136  memory: 382  loss: 1.5705\n",
      "11/22 16:48:21 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][1430/1563]  lr: 1.0000e-03  eta: 0:03:03  time: 0.0539  data_time: 0.0139  memory: 382  loss: 1.6145\n",
      "11/22 16:48:22 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][1440/1563]  lr: 1.0000e-03  eta: 0:03:02  time: 0.0527  data_time: 0.0137  memory: 382  loss: 1.6834\n",
      "11/22 16:48:22 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][1450/1563]  lr: 1.0000e-03  eta: 0:03:02  time: 0.0523  data_time: 0.0139  memory: 382  loss: 1.6103\n",
      "11/22 16:48:23 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][1460/1563]  lr: 1.0000e-03  eta: 0:03:01  time: 0.0528  data_time: 0.0139  memory: 382  loss: 1.6688\n",
      "11/22 16:48:23 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][1470/1563]  lr: 1.0000e-03  eta: 0:03:01  time: 0.0523  data_time: 0.0138  memory: 382  loss: 1.6066\n",
      "11/22 16:48:24 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][1480/1563]  lr: 1.0000e-03  eta: 0:03:00  time: 0.0523  data_time: 0.0138  memory: 382  loss: 1.4817\n",
      "11/22 16:48:24 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][1490/1563]  lr: 1.0000e-03  eta: 0:03:00  time: 0.0525  data_time: 0.0138  memory: 382  loss: 1.5851\n",
      "11/22 16:48:25 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][1500/1563]  lr: 1.0000e-03  eta: 0:02:59  time: 0.0518  data_time: 0.0137  memory: 382  loss: 1.6215\n",
      "11/22 16:48:25 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][1510/1563]  lr: 1.0000e-03  eta: 0:02:58  time: 0.0522  data_time: 0.0138  memory: 382  loss: 1.7130\n",
      "11/22 16:48:26 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][1520/1563]  lr: 1.0000e-03  eta: 0:02:58  time: 0.0520  data_time: 0.0137  memory: 382  loss: 1.6338\n",
      "11/22 16:48:27 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][1530/1563]  lr: 1.0000e-03  eta: 0:02:57  time: 0.0528  data_time: 0.0141  memory: 382  loss: 1.6627\n",
      "11/22 16:48:27 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][1540/1563]  lr: 1.0000e-03  eta: 0:02:57  time: 0.0520  data_time: 0.0137  memory: 382  loss: 1.6814\n",
      "11/22 16:48:28 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][1550/1563]  lr: 1.0000e-03  eta: 0:02:56  time: 0.0524  data_time: 0.0139  memory: 382  loss: 1.7130\n",
      "11/22 16:48:28 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [3][1560/1563]  lr: 1.0000e-03  eta: 0:02:55  time: 0.0519  data_time: 0.0137  memory: 382  loss: 1.5962\n",
      "11/22 16:48:28 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Exp name: 20241122_164350\n",
      "11/22 16:48:28 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Saving checkpoint at 3 epochs\n",
      "11/22 16:48:29 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [3][ 10/313]    eta: 0:00:06  time: 0.0219  data_time: 0.0116  memory: 382  \n",
      "11/22 16:48:29 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [3][ 20/313]    eta: 0:00:05  time: 0.0181  data_time: 0.0089  memory: 225  \n",
      "11/22 16:48:29 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [3][ 30/313]    eta: 0:00:05  time: 0.0169  data_time: 0.0083  memory: 225  \n",
      "11/22 16:48:30 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [3][ 40/313]    eta: 0:00:05  time: 0.0169  data_time: 0.0083  memory: 225  \n",
      "11/22 16:48:30 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [3][ 50/313]    eta: 0:00:04  time: 0.0170  data_time: 0.0084  memory: 225  \n",
      "11/22 16:48:30 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [3][ 60/313]    eta: 0:00:04  time: 0.0168  data_time: 0.0083  memory: 225  \n",
      "11/22 16:48:30 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [3][ 70/313]    eta: 0:00:04  time: 0.0169  data_time: 0.0084  memory: 225  \n",
      "11/22 16:48:30 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [3][ 80/313]    eta: 0:00:04  time: 0.0171  data_time: 0.0084  memory: 225  \n",
      "11/22 16:48:30 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [3][ 90/313]    eta: 0:00:03  time: 0.0168  data_time: 0.0083  memory: 225  \n",
      "11/22 16:48:31 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [3][100/313]    eta: 0:00:03  time: 0.0169  data_time: 0.0083  memory: 225  \n",
      "11/22 16:48:31 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [3][110/313]    eta: 0:00:03  time: 0.0170  data_time: 0.0083  memory: 225  \n",
      "11/22 16:48:31 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [3][120/313]    eta: 0:00:03  time: 0.0169  data_time: 0.0083  memory: 225  \n",
      "11/22 16:48:31 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [3][130/313]    eta: 0:00:03  time: 0.0169  data_time: 0.0083  memory: 225  \n",
      "11/22 16:48:31 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [3][140/313]    eta: 0:00:03  time: 0.0169  data_time: 0.0083  memory: 225  \n",
      "11/22 16:48:31 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [3][150/313]    eta: 0:00:02  time: 0.0169  data_time: 0.0084  memory: 225  \n",
      "11/22 16:48:32 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [3][160/313]    eta: 0:00:02  time: 0.0169  data_time: 0.0083  memory: 225  \n",
      "11/22 16:48:32 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [3][170/313]    eta: 0:00:02  time: 0.0169  data_time: 0.0083  memory: 225  \n",
      "11/22 16:48:32 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [3][180/313]    eta: 0:00:02  time: 0.0168  data_time: 0.0083  memory: 225  \n",
      "11/22 16:48:32 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [3][190/313]    eta: 0:00:02  time: 0.0170  data_time: 0.0083  memory: 225  \n",
      "11/22 16:48:32 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [3][200/313]    eta: 0:00:01  time: 0.0169  data_time: 0.0083  memory: 225  \n",
      "11/22 16:48:32 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [3][210/313]    eta: 0:00:01  time: 0.0168  data_time: 0.0083  memory: 225  \n",
      "11/22 16:48:33 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [3][220/313]    eta: 0:00:01  time: 0.0169  data_time: 0.0083  memory: 225  \n",
      "11/22 16:48:33 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [3][230/313]    eta: 0:00:01  time: 0.0168  data_time: 0.0083  memory: 225  \n",
      "11/22 16:48:33 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [3][240/313]    eta: 0:00:01  time: 0.0168  data_time: 0.0082  memory: 225  \n",
      "11/22 16:48:33 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [3][250/313]    eta: 0:00:01  time: 0.0169  data_time: 0.0083  memory: 225  \n",
      "11/22 16:48:33 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [3][260/313]    eta: 0:00:00  time: 0.0168  data_time: 0.0082  memory: 225  \n",
      "11/22 16:48:33 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [3][270/313]    eta: 0:00:00  time: 0.0168  data_time: 0.0083  memory: 225  \n",
      "11/22 16:48:34 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [3][280/313]    eta: 0:00:00  time: 0.0168  data_time: 0.0083  memory: 225  \n",
      "11/22 16:48:34 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [3][290/313]    eta: 0:00:00  time: 0.0169  data_time: 0.0083  memory: 225  \n",
      "11/22 16:48:34 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [3][300/313]    eta: 0:00:00  time: 0.0169  data_time: 0.0084  memory: 225  \n",
      "11/22 16:48:34 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [3][310/313]    eta: 0:00:00  time: 0.0171  data_time: 0.0085  memory: 225  \n",
      "11/22 16:48:34 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [3][313/313]    accuracy: 46.4500  data_time: 0.0084  time: 0.0171\n",
      "11/22 16:48:35 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][  10/1563]  lr: 1.0000e-03  eta: 0:02:55  time: 0.0518  data_time: 0.0133  memory: 382  loss: 1.4827\n",
      "11/22 16:48:35 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][  20/1563]  lr: 1.0000e-03  eta: 0:02:54  time: 0.0510  data_time: 0.0132  memory: 382  loss: 1.6613\n",
      "11/22 16:48:36 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][  30/1563]  lr: 1.0000e-03  eta: 0:02:53  time: 0.0515  data_time: 0.0135  memory: 382  loss: 1.5464\n",
      "11/22 16:48:36 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][  40/1563]  lr: 1.0000e-03  eta: 0:02:53  time: 0.0510  data_time: 0.0132  memory: 382  loss: 1.5757\n",
      "11/22 16:48:37 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][  50/1563]  lr: 1.0000e-03  eta: 0:02:52  time: 0.0514  data_time: 0.0135  memory: 382  loss: 1.6691\n",
      "11/22 16:48:37 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][  60/1563]  lr: 1.0000e-03  eta: 0:02:52  time: 0.0513  data_time: 0.0133  memory: 382  loss: 1.6151\n",
      "11/22 16:48:38 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][  70/1563]  lr: 1.0000e-03  eta: 0:02:51  time: 0.0513  data_time: 0.0133  memory: 382  loss: 1.6309\n",
      "11/22 16:48:38 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][  80/1563]  lr: 1.0000e-03  eta: 0:02:50  time: 0.0514  data_time: 0.0133  memory: 382  loss: 1.5857\n",
      "11/22 16:48:39 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][  90/1563]  lr: 1.0000e-03  eta: 0:02:50  time: 0.0516  data_time: 0.0134  memory: 382  loss: 1.7167\n",
      "11/22 16:48:39 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 100/1563]  lr: 1.0000e-03  eta: 0:02:49  time: 0.0520  data_time: 0.0136  memory: 382  loss: 1.6490\n",
      "11/22 16:48:40 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 110/1563]  lr: 1.0000e-03  eta: 0:02:49  time: 0.0514  data_time: 0.0133  memory: 382  loss: 1.4848\n",
      "11/22 16:48:40 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 120/1563]  lr: 1.0000e-03  eta: 0:02:48  time: 0.0516  data_time: 0.0133  memory: 382  loss: 1.6159\n",
      "11/22 16:48:41 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 130/1563]  lr: 1.0000e-03  eta: 0:02:48  time: 0.0513  data_time: 0.0133  memory: 382  loss: 1.7069\n",
      "11/22 16:48:41 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 140/1563]  lr: 1.0000e-03  eta: 0:02:47  time: 0.0514  data_time: 0.0135  memory: 382  loss: 1.6253\n",
      "11/22 16:48:42 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 150/1563]  lr: 1.0000e-03  eta: 0:02:46  time: 0.0515  data_time: 0.0134  memory: 382  loss: 1.6000\n",
      "11/22 16:48:42 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 160/1563]  lr: 1.0000e-03  eta: 0:02:46  time: 0.0516  data_time: 0.0135  memory: 382  loss: 1.5325\n",
      "11/22 16:48:43 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 170/1563]  lr: 1.0000e-03  eta: 0:02:45  time: 0.0512  data_time: 0.0133  memory: 382  loss: 1.5598\n",
      "11/22 16:48:43 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 180/1563]  lr: 1.0000e-03  eta: 0:02:45  time: 0.0514  data_time: 0.0134  memory: 382  loss: 1.5560\n",
      "11/22 16:48:44 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 190/1563]  lr: 1.0000e-03  eta: 0:02:44  time: 0.0514  data_time: 0.0133  memory: 382  loss: 1.4787\n",
      "11/22 16:48:44 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 200/1563]  lr: 1.0000e-03  eta: 0:02:43  time: 0.0513  data_time: 0.0134  memory: 382  loss: 1.6953\n",
      "11/22 16:48:45 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 210/1563]  lr: 1.0000e-03  eta: 0:02:43  time: 0.0514  data_time: 0.0133  memory: 382  loss: 1.5108\n",
      "11/22 16:48:46 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 220/1563]  lr: 1.0000e-03  eta: 0:02:42  time: 0.0513  data_time: 0.0134  memory: 382  loss: 1.5402\n",
      "11/22 16:48:46 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 230/1563]  lr: 1.0000e-03  eta: 0:02:42  time: 0.0517  data_time: 0.0135  memory: 382  loss: 1.7756\n",
      "11/22 16:48:47 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 240/1563]  lr: 1.0000e-03  eta: 0:02:41  time: 0.0531  data_time: 0.0144  memory: 382  loss: 1.6098\n",
      "11/22 16:48:47 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 250/1563]  lr: 1.0000e-03  eta: 0:02:41  time: 0.0585  data_time: 0.0159  memory: 382  loss: 1.7508\n",
      "11/22 16:48:48 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 260/1563]  lr: 1.0000e-03  eta: 0:02:40  time: 0.0577  data_time: 0.0156  memory: 382  loss: 1.5077\n",
      "11/22 16:48:48 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 270/1563]  lr: 1.0000e-03  eta: 0:02:39  time: 0.0580  data_time: 0.0156  memory: 382  loss: 1.7236\n",
      "11/22 16:48:49 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 280/1563]  lr: 1.0000e-03  eta: 0:02:39  time: 0.0582  data_time: 0.0156  memory: 382  loss: 1.5900\n",
      "11/22 16:48:49 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 290/1563]  lr: 1.0000e-03  eta: 0:02:38  time: 0.0583  data_time: 0.0159  memory: 382  loss: 1.6442\n",
      "11/22 16:48:50 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 300/1563]  lr: 1.0000e-03  eta: 0:02:38  time: 0.0582  data_time: 0.0157  memory: 382  loss: 1.4944\n",
      "11/22 16:48:51 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 310/1563]  lr: 1.0000e-03  eta: 0:02:37  time: 0.0580  data_time: 0.0156  memory: 382  loss: 1.6391\n",
      "11/22 16:48:51 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Exp name: 20241122_164350\n",
      "11/22 16:48:51 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 320/1563]  lr: 1.0000e-03  eta: 0:02:37  time: 0.0585  data_time: 0.0161  memory: 382  loss: 1.6686\n",
      "11/22 16:48:52 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 330/1563]  lr: 1.0000e-03  eta: 0:02:36  time: 0.0580  data_time: 0.0156  memory: 382  loss: 1.6061\n",
      "11/22 16:48:52 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 340/1563]  lr: 1.0000e-03  eta: 0:02:36  time: 0.0579  data_time: 0.0156  memory: 382  loss: 1.5049\n",
      "11/22 16:48:53 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 350/1563]  lr: 1.0000e-03  eta: 0:02:35  time: 0.0579  data_time: 0.0156  memory: 382  loss: 1.7170\n",
      "11/22 16:48:54 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 360/1563]  lr: 1.0000e-03  eta: 0:02:34  time: 0.0584  data_time: 0.0160  memory: 382  loss: 1.5866\n",
      "11/22 16:48:54 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 370/1563]  lr: 1.0000e-03  eta: 0:02:34  time: 0.0579  data_time: 0.0156  memory: 382  loss: 1.5168\n",
      "11/22 16:48:55 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 380/1563]  lr: 1.0000e-03  eta: 0:02:33  time: 0.0583  data_time: 0.0159  memory: 382  loss: 1.5840\n",
      "11/22 16:48:55 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 390/1563]  lr: 1.0000e-03  eta: 0:02:33  time: 0.0548  data_time: 0.0157  memory: 382  loss: 1.6690\n",
      "11/22 16:48:56 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 400/1563]  lr: 1.0000e-03  eta: 0:02:32  time: 0.0570  data_time: 0.0160  memory: 382  loss: 1.5442\n",
      "11/22 16:48:56 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 410/1563]  lr: 1.0000e-03  eta: 0:02:32  time: 0.0585  data_time: 0.0159  memory: 382  loss: 1.6225\n",
      "11/22 16:48:57 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 420/1563]  lr: 1.0000e-03  eta: 0:02:31  time: 0.0587  data_time: 0.0161  memory: 382  loss: 1.6509\n",
      "11/22 16:48:58 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 430/1563]  lr: 1.0000e-03  eta: 0:02:31  time: 0.0580  data_time: 0.0156  memory: 382  loss: 1.5399\n",
      "11/22 16:48:58 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 440/1563]  lr: 1.0000e-03  eta: 0:02:30  time: 0.0584  data_time: 0.0160  memory: 382  loss: 1.7360\n",
      "11/22 16:48:59 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 450/1563]  lr: 1.0000e-03  eta: 0:02:30  time: 0.0562  data_time: 0.0156  memory: 382  loss: 1.6366\n",
      "11/22 16:48:59 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 460/1563]  lr: 1.0000e-03  eta: 0:02:29  time: 0.0579  data_time: 0.0156  memory: 382  loss: 1.5633\n",
      "11/22 16:49:00 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 470/1563]  lr: 1.0000e-03  eta: 0:02:28  time: 0.0580  data_time: 0.0156  memory: 382  loss: 1.7030\n",
      "11/22 16:49:00 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 480/1563]  lr: 1.0000e-03  eta: 0:02:28  time: 0.0586  data_time: 0.0161  memory: 382  loss: 1.6098\n",
      "11/22 16:49:01 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 490/1563]  lr: 1.0000e-03  eta: 0:02:27  time: 0.0583  data_time: 0.0157  memory: 382  loss: 1.5978\n",
      "11/22 16:49:02 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 500/1563]  lr: 1.0000e-03  eta: 0:02:27  time: 0.0584  data_time: 0.0159  memory: 382  loss: 1.5659\n",
      "11/22 16:49:02 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 510/1563]  lr: 1.0000e-03  eta: 0:02:26  time: 0.0581  data_time: 0.0158  memory: 382  loss: 1.6597\n",
      "11/22 16:49:03 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 520/1563]  lr: 1.0000e-03  eta: 0:02:26  time: 0.0579  data_time: 0.0156  memory: 382  loss: 1.4810\n",
      "11/22 16:49:03 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 530/1563]  lr: 1.0000e-03  eta: 0:02:25  time: 0.0584  data_time: 0.0159  memory: 382  loss: 1.5026\n",
      "11/22 16:49:04 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 540/1563]  lr: 1.0000e-03  eta: 0:02:25  time: 0.0584  data_time: 0.0160  memory: 382  loss: 1.5160\n",
      "11/22 16:49:05 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 550/1563]  lr: 1.0000e-03  eta: 0:02:24  time: 0.0581  data_time: 0.0156  memory: 382  loss: 1.7005\n",
      "11/22 16:49:05 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 560/1563]  lr: 1.0000e-03  eta: 0:02:23  time: 0.0579  data_time: 0.0157  memory: 382  loss: 1.5502\n",
      "11/22 16:49:06 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 570/1563]  lr: 1.0000e-03  eta: 0:02:23  time: 0.0580  data_time: 0.0156  memory: 382  loss: 1.5649\n",
      "11/22 16:49:06 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 580/1563]  lr: 1.0000e-03  eta: 0:02:22  time: 0.0584  data_time: 0.0159  memory: 382  loss: 1.5219\n",
      "11/22 16:49:07 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 590/1563]  lr: 1.0000e-03  eta: 0:02:22  time: 0.0578  data_time: 0.0156  memory: 382  loss: 1.6810\n",
      "11/22 16:49:07 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 600/1563]  lr: 1.0000e-03  eta: 0:02:21  time: 0.0580  data_time: 0.0155  memory: 382  loss: 1.4635\n",
      "11/22 16:49:08 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 610/1563]  lr: 1.0000e-03  eta: 0:02:21  time: 0.0584  data_time: 0.0160  memory: 382  loss: 1.6882\n",
      "11/22 16:49:09 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 620/1563]  lr: 1.0000e-03  eta: 0:02:20  time: 0.0579  data_time: 0.0156  memory: 382  loss: 1.4945\n",
      "11/22 16:49:09 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 630/1563]  lr: 1.0000e-03  eta: 0:02:20  time: 0.0582  data_time: 0.0156  memory: 382  loss: 1.6907\n",
      "11/22 16:49:10 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 640/1563]  lr: 1.0000e-03  eta: 0:02:19  time: 0.0580  data_time: 0.0156  memory: 382  loss: 1.6535\n",
      "11/22 16:49:10 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 650/1563]  lr: 1.0000e-03  eta: 0:02:18  time: 0.0578  data_time: 0.0155  memory: 382  loss: 1.6673\n",
      "11/22 16:49:11 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 660/1563]  lr: 1.0000e-03  eta: 0:02:18  time: 0.0579  data_time: 0.0156  memory: 382  loss: 1.5819\n",
      "11/22 16:49:12 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 670/1563]  lr: 1.0000e-03  eta: 0:02:17  time: 0.0590  data_time: 0.0165  memory: 382  loss: 1.5481\n",
      "11/22 16:49:12 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 680/1563]  lr: 1.0000e-03  eta: 0:02:17  time: 0.0579  data_time: 0.0156  memory: 382  loss: 1.5307\n",
      "11/22 16:49:13 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 690/1563]  lr: 1.0000e-03  eta: 0:02:16  time: 0.0580  data_time: 0.0156  memory: 382  loss: 1.5848\n",
      "11/22 16:49:13 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 700/1563]  lr: 1.0000e-03  eta: 0:02:16  time: 0.0584  data_time: 0.0159  memory: 382  loss: 1.6722\n",
      "11/22 16:49:14 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 710/1563]  lr: 1.0000e-03  eta: 0:02:15  time: 0.0582  data_time: 0.0159  memory: 382  loss: 1.6036\n",
      "11/22 16:49:14 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 720/1563]  lr: 1.0000e-03  eta: 0:02:15  time: 0.0581  data_time: 0.0156  memory: 382  loss: 1.6059\n",
      "11/22 16:49:15 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 730/1563]  lr: 1.0000e-03  eta: 0:02:14  time: 0.0579  data_time: 0.0156  memory: 382  loss: 1.6429\n",
      "11/22 16:49:16 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 740/1563]  lr: 1.0000e-03  eta: 0:02:14  time: 0.0584  data_time: 0.0159  memory: 382  loss: 1.6281\n",
      "11/22 16:49:16 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 750/1563]  lr: 1.0000e-03  eta: 0:02:13  time: 0.0584  data_time: 0.0156  memory: 382  loss: 1.5211\n",
      "11/22 16:49:17 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 760/1563]  lr: 1.0000e-03  eta: 0:02:12  time: 0.0582  data_time: 0.0158  memory: 382  loss: 1.5727\n",
      "11/22 16:49:17 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 770/1563]  lr: 1.0000e-03  eta: 0:02:12  time: 0.0580  data_time: 0.0156  memory: 382  loss: 1.6995\n",
      "11/22 16:49:18 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 780/1563]  lr: 1.0000e-03  eta: 0:02:11  time: 0.0581  data_time: 0.0156  memory: 382  loss: 1.5949\n",
      "11/22 16:49:19 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 790/1563]  lr: 1.0000e-03  eta: 0:02:11  time: 0.0581  data_time: 0.0155  memory: 382  loss: 1.5910\n",
      "11/22 16:49:19 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 800/1563]  lr: 1.0000e-03  eta: 0:02:10  time: 0.0582  data_time: 0.0156  memory: 382  loss: 1.6577\n",
      "11/22 16:49:20 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 810/1563]  lr: 1.0000e-03  eta: 0:02:10  time: 0.0581  data_time: 0.0156  memory: 382  loss: 1.5431\n",
      "11/22 16:49:20 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 820/1563]  lr: 1.0000e-03  eta: 0:02:09  time: 0.0579  data_time: 0.0156  memory: 382  loss: 1.6076\n",
      "11/22 16:49:21 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 830/1563]  lr: 1.0000e-03  eta: 0:02:09  time: 0.0578  data_time: 0.0156  memory: 382  loss: 1.6482\n",
      "11/22 16:49:21 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 840/1563]  lr: 1.0000e-03  eta: 0:02:08  time: 0.0584  data_time: 0.0160  memory: 382  loss: 1.6101\n",
      "11/22 16:49:22 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 850/1563]  lr: 1.0000e-03  eta: 0:02:07  time: 0.0583  data_time: 0.0160  memory: 382  loss: 1.6150\n",
      "11/22 16:49:23 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 860/1563]  lr: 1.0000e-03  eta: 0:02:07  time: 0.0580  data_time: 0.0156  memory: 382  loss: 1.5988\n",
      "11/22 16:49:23 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 870/1563]  lr: 1.0000e-03  eta: 0:02:06  time: 0.0579  data_time: 0.0155  memory: 382  loss: 1.5681\n",
      "11/22 16:49:24 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 880/1563]  lr: 1.0000e-03  eta: 0:02:06  time: 0.0578  data_time: 0.0156  memory: 382  loss: 1.5544\n",
      "11/22 16:49:24 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 890/1563]  lr: 1.0000e-03  eta: 0:02:05  time: 0.0580  data_time: 0.0156  memory: 382  loss: 1.5334\n",
      "11/22 16:49:25 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 900/1563]  lr: 1.0000e-03  eta: 0:02:05  time: 0.0580  data_time: 0.0156  memory: 382  loss: 1.5827\n",
      "11/22 16:49:25 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 910/1563]  lr: 1.0000e-03  eta: 0:02:04  time: 0.0580  data_time: 0.0156  memory: 382  loss: 1.6359\n",
      "11/22 16:49:26 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 920/1563]  lr: 1.0000e-03  eta: 0:02:04  time: 0.0588  data_time: 0.0159  memory: 382  loss: 1.6748\n",
      "11/22 16:49:27 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 930/1563]  lr: 1.0000e-03  eta: 0:02:03  time: 0.0582  data_time: 0.0157  memory: 382  loss: 1.5071\n",
      "11/22 16:49:27 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 940/1563]  lr: 1.0000e-03  eta: 0:02:02  time: 0.0582  data_time: 0.0157  memory: 382  loss: 1.5332\n",
      "11/22 16:49:28 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 950/1563]  lr: 1.0000e-03  eta: 0:02:02  time: 0.0584  data_time: 0.0160  memory: 382  loss: 1.6278\n",
      "11/22 16:49:28 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 960/1563]  lr: 1.0000e-03  eta: 0:02:01  time: 0.0581  data_time: 0.0157  memory: 382  loss: 1.4036\n",
      "11/22 16:49:29 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 970/1563]  lr: 1.0000e-03  eta: 0:02:01  time: 0.0580  data_time: 0.0156  memory: 382  loss: 1.4834\n",
      "11/22 16:49:30 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 980/1563]  lr: 1.0000e-03  eta: 0:02:00  time: 0.0581  data_time: 0.0156  memory: 382  loss: 1.5523\n",
      "11/22 16:49:30 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][ 990/1563]  lr: 1.0000e-03  eta: 0:02:00  time: 0.0584  data_time: 0.0160  memory: 382  loss: 1.5490\n",
      "11/22 16:49:31 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][1000/1563]  lr: 1.0000e-03  eta: 0:01:59  time: 0.0581  data_time: 0.0156  memory: 382  loss: 1.4718\n",
      "11/22 16:49:31 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][1010/1563]  lr: 1.0000e-03  eta: 0:01:59  time: 0.0585  data_time: 0.0160  memory: 382  loss: 1.7312\n",
      "11/22 16:49:32 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][1020/1563]  lr: 1.0000e-03  eta: 0:01:58  time: 0.0579  data_time: 0.0156  memory: 382  loss: 1.5452\n",
      "11/22 16:49:32 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][1030/1563]  lr: 1.0000e-03  eta: 0:01:57  time: 0.0580  data_time: 0.0156  memory: 382  loss: 1.6344\n",
      "11/22 16:49:33 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][1040/1563]  lr: 1.0000e-03  eta: 0:01:57  time: 0.0585  data_time: 0.0159  memory: 382  loss: 1.4563\n",
      "11/22 16:49:34 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][1050/1563]  lr: 1.0000e-03  eta: 0:01:56  time: 0.0587  data_time: 0.0160  memory: 382  loss: 1.6368\n",
      "11/22 16:49:34 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][1060/1563]  lr: 1.0000e-03  eta: 0:01:56  time: 0.0584  data_time: 0.0159  memory: 382  loss: 1.5848\n",
      "11/22 16:49:35 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][1070/1563]  lr: 1.0000e-03  eta: 0:01:55  time: 0.0585  data_time: 0.0158  memory: 382  loss: 1.7266\n",
      "11/22 16:49:35 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][1080/1563]  lr: 1.0000e-03  eta: 0:01:55  time: 0.0581  data_time: 0.0156  memory: 382  loss: 1.5943\n",
      "11/22 16:49:36 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][1090/1563]  lr: 1.0000e-03  eta: 0:01:54  time: 0.0580  data_time: 0.0156  memory: 382  loss: 1.5624\n",
      "11/22 16:49:37 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][1100/1563]  lr: 1.0000e-03  eta: 0:01:54  time: 0.0582  data_time: 0.0156  memory: 382  loss: 1.7034\n",
      "11/22 16:49:37 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][1110/1563]  lr: 1.0000e-03  eta: 0:01:53  time: 0.0580  data_time: 0.0156  memory: 382  loss: 1.6762\n",
      "11/22 16:49:38 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][1120/1563]  lr: 1.0000e-03  eta: 0:01:52  time: 0.0580  data_time: 0.0156  memory: 382  loss: 1.6385\n",
      "11/22 16:49:38 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][1130/1563]  lr: 1.0000e-03  eta: 0:01:52  time: 0.0584  data_time: 0.0159  memory: 382  loss: 1.6235\n",
      "11/22 16:49:39 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][1140/1563]  lr: 1.0000e-03  eta: 0:01:51  time: 0.0579  data_time: 0.0156  memory: 382  loss: 1.5350\n",
      "11/22 16:49:39 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][1150/1563]  lr: 1.0000e-03  eta: 0:01:51  time: 0.0582  data_time: 0.0156  memory: 382  loss: 1.7931\n",
      "11/22 16:49:40 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][1160/1563]  lr: 1.0000e-03  eta: 0:01:50  time: 0.0579  data_time: 0.0155  memory: 382  loss: 1.6556\n",
      "11/22 16:49:41 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][1170/1563]  lr: 1.0000e-03  eta: 0:01:50  time: 0.0580  data_time: 0.0157  memory: 382  loss: 1.5397\n",
      "11/22 16:49:41 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][1180/1563]  lr: 1.0000e-03  eta: 0:01:49  time: 0.0579  data_time: 0.0155  memory: 382  loss: 1.6626\n",
      "11/22 16:49:42 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][1190/1563]  lr: 1.0000e-03  eta: 0:01:49  time: 0.0581  data_time: 0.0156  memory: 382  loss: 1.4917\n",
      "11/22 16:49:42 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][1200/1563]  lr: 1.0000e-03  eta: 0:01:48  time: 0.0581  data_time: 0.0156  memory: 382  loss: 1.4882\n",
      "11/22 16:49:43 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][1210/1563]  lr: 1.0000e-03  eta: 0:01:47  time: 0.0579  data_time: 0.0155  memory: 382  loss: 1.6437\n",
      "11/22 16:49:44 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][1220/1563]  lr: 1.0000e-03  eta: 0:01:47  time: 0.0586  data_time: 0.0160  memory: 382  loss: 1.5235\n",
      "11/22 16:49:44 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][1230/1563]  lr: 1.0000e-03  eta: 0:01:46  time: 0.0582  data_time: 0.0156  memory: 382  loss: 1.5863\n",
      "11/22 16:49:45 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][1240/1563]  lr: 1.0000e-03  eta: 0:01:46  time: 0.0579  data_time: 0.0157  memory: 382  loss: 1.5557\n",
      "11/22 16:49:45 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][1250/1563]  lr: 1.0000e-03  eta: 0:01:45  time: 0.0554  data_time: 0.0157  memory: 382  loss: 1.5434\n",
      "11/22 16:49:46 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][1260/1563]  lr: 1.0000e-03  eta: 0:01:45  time: 0.0578  data_time: 0.0154  memory: 382  loss: 1.5289\n",
      "11/22 16:49:46 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][1270/1563]  lr: 1.0000e-03  eta: 0:01:44  time: 0.0577  data_time: 0.0155  memory: 382  loss: 1.5152\n",
      "11/22 16:49:47 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][1280/1563]  lr: 1.0000e-03  eta: 0:01:44  time: 0.0578  data_time: 0.0156  memory: 382  loss: 1.5708\n",
      "11/22 16:49:48 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][1290/1563]  lr: 1.0000e-03  eta: 0:01:43  time: 0.0576  data_time: 0.0155  memory: 382  loss: 1.5456\n",
      "11/22 16:49:48 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][1300/1563]  lr: 1.0000e-03  eta: 0:01:42  time: 0.0577  data_time: 0.0155  memory: 382  loss: 1.5222\n",
      "11/22 16:49:49 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][1310/1563]  lr: 1.0000e-03  eta: 0:01:42  time: 0.0581  data_time: 0.0157  memory: 382  loss: 1.5920\n",
      "11/22 16:49:49 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Exp name: 20241122_164350\n",
      "11/22 16:49:49 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][1320/1563]  lr: 1.0000e-03  eta: 0:01:41  time: 0.0586  data_time: 0.0160  memory: 382  loss: 1.6577\n",
      "11/22 16:49:50 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][1330/1563]  lr: 1.0000e-03  eta: 0:01:41  time: 0.0578  data_time: 0.0155  memory: 382  loss: 1.5433\n",
      "11/22 16:49:50 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][1340/1563]  lr: 1.0000e-03  eta: 0:01:40  time: 0.0576  data_time: 0.0155  memory: 382  loss: 1.6406\n",
      "11/22 16:49:51 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][1350/1563]  lr: 1.0000e-03  eta: 0:01:40  time: 0.0581  data_time: 0.0155  memory: 382  loss: 1.4883\n",
      "11/22 16:49:52 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][1360/1563]  lr: 1.0000e-03  eta: 0:01:39  time: 0.0578  data_time: 0.0156  memory: 382  loss: 1.5228\n",
      "11/22 16:49:52 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][1370/1563]  lr: 1.0000e-03  eta: 0:01:38  time: 0.0577  data_time: 0.0155  memory: 382  loss: 1.5995\n",
      "11/22 16:49:53 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][1380/1563]  lr: 1.0000e-03  eta: 0:01:38  time: 0.0578  data_time: 0.0156  memory: 382  loss: 1.5131\n",
      "11/22 16:49:53 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][1390/1563]  lr: 1.0000e-03  eta: 0:01:37  time: 0.0579  data_time: 0.0156  memory: 382  loss: 1.5755\n",
      "11/22 16:49:54 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][1400/1563]  lr: 1.0000e-03  eta: 0:01:37  time: 0.0579  data_time: 0.0156  memory: 382  loss: 1.5492\n",
      "11/22 16:49:54 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][1410/1563]  lr: 1.0000e-03  eta: 0:01:36  time: 0.0578  data_time: 0.0155  memory: 382  loss: 1.5689\n",
      "11/22 16:49:55 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][1420/1563]  lr: 1.0000e-03  eta: 0:01:36  time: 0.0578  data_time: 0.0156  memory: 382  loss: 1.5505\n",
      "11/22 16:49:56 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][1430/1563]  lr: 1.0000e-03  eta: 0:01:35  time: 0.0578  data_time: 0.0156  memory: 382  loss: 1.6146\n",
      "11/22 16:49:56 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][1440/1563]  lr: 1.0000e-03  eta: 0:01:35  time: 0.0582  data_time: 0.0158  memory: 382  loss: 1.5625\n",
      "11/22 16:49:57 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][1450/1563]  lr: 1.0000e-03  eta: 0:01:34  time: 0.0527  data_time: 0.0155  memory: 382  loss: 1.6290\n",
      "11/22 16:49:57 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][1460/1563]  lr: 1.0000e-03  eta: 0:01:33  time: 0.0570  data_time: 0.0155  memory: 382  loss: 1.6265\n",
      "11/22 16:49:58 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][1470/1563]  lr: 1.0000e-03  eta: 0:01:33  time: 0.0578  data_time: 0.0155  memory: 382  loss: 1.5794\n",
      "11/22 16:49:58 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][1480/1563]  lr: 1.0000e-03  eta: 0:01:32  time: 0.0579  data_time: 0.0156  memory: 382  loss: 1.4858\n",
      "11/22 16:49:59 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][1490/1563]  lr: 1.0000e-03  eta: 0:01:32  time: 0.0578  data_time: 0.0156  memory: 382  loss: 1.5724\n",
      "11/22 16:50:00 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][1500/1563]  lr: 1.0000e-03  eta: 0:01:31  time: 0.0581  data_time: 0.0158  memory: 382  loss: 1.5253\n",
      "11/22 16:50:00 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][1510/1563]  lr: 1.0000e-03  eta: 0:01:31  time: 0.0575  data_time: 0.0154  memory: 382  loss: 1.5984\n",
      "11/22 16:50:01 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][1520/1563]  lr: 1.0000e-03  eta: 0:01:30  time: 0.0578  data_time: 0.0156  memory: 382  loss: 1.4768\n",
      "11/22 16:50:01 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][1530/1563]  lr: 1.0000e-03  eta: 0:01:30  time: 0.0579  data_time: 0.0156  memory: 382  loss: 1.6302\n",
      "11/22 16:50:02 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][1540/1563]  lr: 1.0000e-03  eta: 0:01:29  time: 0.0579  data_time: 0.0156  memory: 382  loss: 1.4214\n",
      "11/22 16:50:03 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][1550/1563]  lr: 1.0000e-03  eta: 0:01:28  time: 0.0578  data_time: 0.0155  memory: 382  loss: 1.5100\n",
      "11/22 16:50:03 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [4][1560/1563]  lr: 1.0000e-03  eta: 0:01:28  time: 0.0578  data_time: 0.0156  memory: 382  loss: 1.5353\n",
      "11/22 16:50:03 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Exp name: 20241122_164350\n",
      "11/22 16:50:03 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Saving checkpoint at 4 epochs\n",
      "11/22 16:50:04 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [4][ 10/313]    eta: 0:00:06  time: 0.0201  data_time: 0.0098  memory: 382  \n",
      "11/22 16:50:04 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [4][ 20/313]    eta: 0:00:05  time: 0.0190  data_time: 0.0093  memory: 225  \n",
      "11/22 16:50:05 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [4][ 30/313]    eta: 0:00:05  time: 0.0169  data_time: 0.0083  memory: 225  \n",
      "11/22 16:50:05 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [4][ 40/313]    eta: 0:00:04  time: 0.0168  data_time: 0.0083  memory: 225  \n",
      "11/22 16:50:05 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [4][ 50/313]    eta: 0:00:04  time: 0.0171  data_time: 0.0085  memory: 225  \n",
      "11/22 16:50:05 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [4][ 60/313]    eta: 0:00:04  time: 0.0169  data_time: 0.0084  memory: 225  \n",
      "11/22 16:50:05 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [4][ 70/313]    eta: 0:00:04  time: 0.0170  data_time: 0.0084  memory: 225  \n",
      "11/22 16:50:05 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [4][ 80/313]    eta: 0:00:04  time: 0.0169  data_time: 0.0083  memory: 225  \n",
      "11/22 16:50:06 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [4][ 90/313]    eta: 0:00:03  time: 0.0169  data_time: 0.0083  memory: 225  \n",
      "11/22 16:50:06 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [4][100/313]    eta: 0:00:03  time: 0.0170  data_time: 0.0084  memory: 225  \n",
      "11/22 16:50:06 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [4][110/313]    eta: 0:00:03  time: 0.0169  data_time: 0.0084  memory: 225  \n",
      "11/22 16:50:06 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [4][120/313]    eta: 0:00:03  time: 0.0170  data_time: 0.0084  memory: 225  \n",
      "11/22 16:50:06 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [4][130/313]    eta: 0:00:03  time: 0.0169  data_time: 0.0083  memory: 225  \n",
      "11/22 16:50:06 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [4][140/313]    eta: 0:00:02  time: 0.0170  data_time: 0.0084  memory: 225  \n",
      "11/22 16:50:07 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [4][150/313]    eta: 0:00:02  time: 0.0170  data_time: 0.0084  memory: 225  \n",
      "11/22 16:50:07 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [4][160/313]    eta: 0:00:02  time: 0.0169  data_time: 0.0084  memory: 225  \n",
      "11/22 16:50:07 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [4][170/313]    eta: 0:00:02  time: 0.0168  data_time: 0.0083  memory: 225  \n",
      "11/22 16:50:07 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [4][180/313]    eta: 0:00:02  time: 0.0169  data_time: 0.0084  memory: 225  \n",
      "11/22 16:50:07 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [4][190/313]    eta: 0:00:02  time: 0.0171  data_time: 0.0085  memory: 225  \n",
      "11/22 16:50:07 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [4][200/313]    eta: 0:00:01  time: 0.0169  data_time: 0.0083  memory: 225  \n",
      "11/22 16:50:08 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [4][210/313]    eta: 0:00:01  time: 0.0169  data_time: 0.0083  memory: 225  \n",
      "11/22 16:50:08 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [4][220/313]    eta: 0:00:01  time: 0.0169  data_time: 0.0083  memory: 225  \n",
      "11/22 16:50:08 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [4][230/313]    eta: 0:00:01  time: 0.0168  data_time: 0.0083  memory: 225  \n",
      "11/22 16:50:08 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [4][240/313]    eta: 0:00:01  time: 0.0170  data_time: 0.0084  memory: 225  \n",
      "11/22 16:50:08 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [4][250/313]    eta: 0:00:01  time: 0.0169  data_time: 0.0083  memory: 225  \n",
      "11/22 16:50:08 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [4][260/313]    eta: 0:00:00  time: 0.0169  data_time: 0.0084  memory: 225  \n",
      "11/22 16:50:09 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [4][270/313]    eta: 0:00:00  time: 0.0169  data_time: 0.0083  memory: 225  \n",
      "11/22 16:50:09 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [4][280/313]    eta: 0:00:00  time: 0.0169  data_time: 0.0083  memory: 225  \n",
      "11/22 16:50:09 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [4][290/313]    eta: 0:00:00  time: 0.0170  data_time: 0.0084  memory: 225  \n",
      "11/22 16:50:09 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [4][300/313]    eta: 0:00:00  time: 0.0171  data_time: 0.0085  memory: 225  \n",
      "11/22 16:50:09 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [4][310/313]    eta: 0:00:00  time: 0.0171  data_time: 0.0084  memory: 225  \n",
      "11/22 16:50:09 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [4][313/313]    accuracy: 48.9200  data_time: 0.0084  time: 0.0171\n",
      "11/22 16:50:10 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][  10/1563]  lr: 1.0000e-03  eta: 0:01:27  time: 0.0519  data_time: 0.0133  memory: 382  loss: 1.5881\n",
      "11/22 16:50:10 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][  20/1563]  lr: 1.0000e-03  eta: 0:01:26  time: 0.0510  data_time: 0.0132  memory: 382  loss: 1.5953\n",
      "11/22 16:50:11 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][  30/1563]  lr: 1.0000e-03  eta: 0:01:26  time: 0.0514  data_time: 0.0135  memory: 382  loss: 1.6398\n",
      "11/22 16:50:11 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][  40/1563]  lr: 1.0000e-03  eta: 0:01:25  time: 0.0520  data_time: 0.0136  memory: 382  loss: 1.6299\n",
      "11/22 16:50:12 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][  50/1563]  lr: 1.0000e-03  eta: 0:01:25  time: 0.0514  data_time: 0.0135  memory: 382  loss: 1.4690\n",
      "11/22 16:50:12 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][  60/1563]  lr: 1.0000e-03  eta: 0:01:24  time: 0.0514  data_time: 0.0134  memory: 382  loss: 1.5009\n",
      "11/22 16:50:13 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][  70/1563]  lr: 1.0000e-03  eta: 0:01:24  time: 0.0512  data_time: 0.0133  memory: 382  loss: 1.6991\n",
      "11/22 16:50:13 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][  80/1563]  lr: 1.0000e-03  eta: 0:01:23  time: 0.0511  data_time: 0.0132  memory: 382  loss: 1.5897\n",
      "11/22 16:50:14 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][  90/1563]  lr: 1.0000e-03  eta: 0:01:22  time: 0.0515  data_time: 0.0134  memory: 382  loss: 1.4838\n",
      "11/22 16:50:15 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 100/1563]  lr: 1.0000e-03  eta: 0:01:22  time: 0.0515  data_time: 0.0135  memory: 382  loss: 1.5367\n",
      "11/22 16:50:15 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 110/1563]  lr: 1.0000e-03  eta: 0:01:21  time: 0.0512  data_time: 0.0134  memory: 382  loss: 1.5360\n",
      "11/22 16:50:16 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 120/1563]  lr: 1.0000e-03  eta: 0:01:21  time: 0.0515  data_time: 0.0135  memory: 382  loss: 1.4626\n",
      "11/22 16:50:16 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 130/1563]  lr: 1.0000e-03  eta: 0:01:20  time: 0.0512  data_time: 0.0134  memory: 382  loss: 1.6532\n",
      "11/22 16:50:17 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 140/1563]  lr: 1.0000e-03  eta: 0:01:20  time: 0.0514  data_time: 0.0134  memory: 382  loss: 1.5336\n",
      "11/22 16:50:17 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 150/1563]  lr: 1.0000e-03  eta: 0:01:19  time: 0.0515  data_time: 0.0136  memory: 382  loss: 1.5675\n",
      "11/22 16:50:18 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 160/1563]  lr: 1.0000e-03  eta: 0:01:18  time: 0.0516  data_time: 0.0135  memory: 382  loss: 1.5454\n",
      "11/22 16:50:18 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 170/1563]  lr: 1.0000e-03  eta: 0:01:18  time: 0.0522  data_time: 0.0136  memory: 382  loss: 1.6156\n",
      "11/22 16:50:19 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 180/1563]  lr: 1.0000e-03  eta: 0:01:17  time: 0.0514  data_time: 0.0135  memory: 382  loss: 1.5434\n",
      "11/22 16:50:19 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 190/1563]  lr: 1.0000e-03  eta: 0:01:17  time: 0.0514  data_time: 0.0134  memory: 382  loss: 1.5017\n",
      "11/22 16:50:20 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 200/1563]  lr: 1.0000e-03  eta: 0:01:16  time: 0.0518  data_time: 0.0134  memory: 382  loss: 1.5192\n",
      "11/22 16:50:20 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 210/1563]  lr: 1.0000e-03  eta: 0:01:16  time: 0.0515  data_time: 0.0135  memory: 382  loss: 1.6853\n",
      "11/22 16:50:21 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 220/1563]  lr: 1.0000e-03  eta: 0:01:15  time: 0.0518  data_time: 0.0135  memory: 382  loss: 1.5970\n",
      "11/22 16:50:21 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 230/1563]  lr: 1.0000e-03  eta: 0:01:14  time: 0.0515  data_time: 0.0135  memory: 382  loss: 1.4325\n",
      "11/22 16:50:22 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 240/1563]  lr: 1.0000e-03  eta: 0:01:14  time: 0.0517  data_time: 0.0136  memory: 382  loss: 1.5267\n",
      "11/22 16:50:22 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 250/1563]  lr: 1.0000e-03  eta: 0:01:13  time: 0.0516  data_time: 0.0136  memory: 382  loss: 1.6820\n",
      "11/22 16:50:23 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 260/1563]  lr: 1.0000e-03  eta: 0:01:13  time: 0.0513  data_time: 0.0133  memory: 382  loss: 1.6840\n",
      "11/22 16:50:23 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 270/1563]  lr: 1.0000e-03  eta: 0:01:12  time: 0.0516  data_time: 0.0134  memory: 382  loss: 1.5562\n",
      "11/22 16:50:24 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 280/1563]  lr: 1.0000e-03  eta: 0:01:12  time: 0.0516  data_time: 0.0134  memory: 382  loss: 1.4979\n",
      "11/22 16:50:24 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 290/1563]  lr: 1.0000e-03  eta: 0:01:11  time: 0.0513  data_time: 0.0134  memory: 382  loss: 1.7433\n",
      "11/22 16:50:25 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 300/1563]  lr: 1.0000e-03  eta: 0:01:10  time: 0.0513  data_time: 0.0134  memory: 382  loss: 1.4537\n",
      "11/22 16:50:25 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 310/1563]  lr: 1.0000e-03  eta: 0:01:10  time: 0.0518  data_time: 0.0136  memory: 382  loss: 1.5039\n",
      "11/22 16:50:26 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 320/1563]  lr: 1.0000e-03  eta: 0:01:09  time: 0.0515  data_time: 0.0136  memory: 382  loss: 1.6451\n",
      "11/22 16:50:26 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 330/1563]  lr: 1.0000e-03  eta: 0:01:09  time: 0.0517  data_time: 0.0134  memory: 382  loss: 1.5821\n",
      "11/22 16:50:27 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 340/1563]  lr: 1.0000e-03  eta: 0:01:08  time: 0.0509  data_time: 0.0137  memory: 382  loss: 1.6438\n",
      "11/22 16:50:27 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 350/1563]  lr: 1.0000e-03  eta: 0:01:08  time: 0.0509  data_time: 0.0134  memory: 382  loss: 1.5743\n",
      "11/22 16:50:28 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 360/1563]  lr: 1.0000e-03  eta: 0:01:07  time: 0.0512  data_time: 0.0134  memory: 382  loss: 1.5997\n",
      "11/22 16:50:28 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 370/1563]  lr: 1.0000e-03  eta: 0:01:06  time: 0.0514  data_time: 0.0134  memory: 382  loss: 1.5345\n",
      "11/22 16:50:29 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 380/1563]  lr: 1.0000e-03  eta: 0:01:06  time: 0.0514  data_time: 0.0135  memory: 382  loss: 1.3340\n",
      "11/22 16:50:29 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 390/1563]  lr: 1.0000e-03  eta: 0:01:05  time: 0.0518  data_time: 0.0135  memory: 382  loss: 1.5397\n",
      "11/22 16:50:30 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 400/1563]  lr: 1.0000e-03  eta: 0:01:05  time: 0.0514  data_time: 0.0134  memory: 382  loss: 1.5086\n",
      "11/22 16:50:30 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 410/1563]  lr: 1.0000e-03  eta: 0:01:04  time: 0.0518  data_time: 0.0135  memory: 382  loss: 1.5779\n",
      "11/22 16:50:31 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 420/1563]  lr: 1.0000e-03  eta: 0:01:04  time: 0.0516  data_time: 0.0135  memory: 382  loss: 1.5474\n",
      "11/22 16:50:32 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 430/1563]  lr: 1.0000e-03  eta: 0:01:03  time: 0.0516  data_time: 0.0135  memory: 382  loss: 1.3913\n",
      "11/22 16:50:32 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 440/1563]  lr: 1.0000e-03  eta: 0:01:02  time: 0.0516  data_time: 0.0135  memory: 382  loss: 1.5450\n",
      "11/22 16:50:33 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 450/1563]  lr: 1.0000e-03  eta: 0:01:02  time: 0.0515  data_time: 0.0135  memory: 382  loss: 1.6198\n",
      "11/22 16:50:33 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 460/1563]  lr: 1.0000e-03  eta: 0:01:01  time: 0.0514  data_time: 0.0134  memory: 382  loss: 1.5160\n",
      "11/22 16:50:34 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 470/1563]  lr: 1.0000e-03  eta: 0:01:01  time: 0.0516  data_time: 0.0134  memory: 382  loss: 1.5863\n",
      "11/22 16:50:34 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 480/1563]  lr: 1.0000e-03  eta: 0:01:00  time: 0.0517  data_time: 0.0134  memory: 382  loss: 1.4299\n",
      "11/22 16:50:35 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 490/1563]  lr: 1.0000e-03  eta: 0:01:00  time: 0.0518  data_time: 0.0136  memory: 382  loss: 1.5563\n",
      "11/22 16:50:35 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 500/1563]  lr: 1.0000e-03  eta: 0:00:59  time: 0.0520  data_time: 0.0136  memory: 382  loss: 1.6120\n",
      "11/22 16:50:36 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 510/1563]  lr: 1.0000e-03  eta: 0:00:58  time: 0.0517  data_time: 0.0134  memory: 382  loss: 1.4608\n",
      "11/22 16:50:36 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 520/1563]  lr: 1.0000e-03  eta: 0:00:58  time: 0.0516  data_time: 0.0135  memory: 382  loss: 1.4410\n",
      "11/22 16:50:37 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 530/1563]  lr: 1.0000e-03  eta: 0:00:57  time: 0.0515  data_time: 0.0133  memory: 382  loss: 1.5759\n",
      "11/22 16:50:37 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 540/1563]  lr: 1.0000e-03  eta: 0:00:57  time: 0.0515  data_time: 0.0135  memory: 382  loss: 1.5766\n",
      "11/22 16:50:38 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 550/1563]  lr: 1.0000e-03  eta: 0:00:56  time: 0.0512  data_time: 0.0134  memory: 382  loss: 1.4889\n",
      "11/22 16:50:38 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 560/1563]  lr: 1.0000e-03  eta: 0:00:56  time: 0.0515  data_time: 0.0134  memory: 382  loss: 1.4940\n",
      "11/22 16:50:39 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 570/1563]  lr: 1.0000e-03  eta: 0:00:55  time: 0.0521  data_time: 0.0136  memory: 382  loss: 1.4498\n",
      "11/22 16:50:39 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 580/1563]  lr: 1.0000e-03  eta: 0:00:55  time: 0.0514  data_time: 0.0135  memory: 382  loss: 1.5106\n",
      "11/22 16:50:40 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 590/1563]  lr: 1.0000e-03  eta: 0:00:54  time: 0.0517  data_time: 0.0136  memory: 382  loss: 1.5412\n",
      "11/22 16:50:40 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 600/1563]  lr: 1.0000e-03  eta: 0:00:53  time: 0.0514  data_time: 0.0133  memory: 382  loss: 1.4269\n",
      "11/22 16:50:41 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 610/1563]  lr: 1.0000e-03  eta: 0:00:53  time: 0.0514  data_time: 0.0134  memory: 382  loss: 1.4413\n",
      "11/22 16:50:41 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 620/1563]  lr: 1.0000e-03  eta: 0:00:52  time: 0.0515  data_time: 0.0134  memory: 382  loss: 1.5007\n",
      "11/22 16:50:42 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 630/1563]  lr: 1.0000e-03  eta: 0:00:52  time: 0.0515  data_time: 0.0134  memory: 382  loss: 1.6053\n",
      "11/22 16:50:42 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 640/1563]  lr: 1.0000e-03  eta: 0:00:51  time: 0.0514  data_time: 0.0133  memory: 382  loss: 1.4454\n",
      "11/22 16:50:43 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 650/1563]  lr: 1.0000e-03  eta: 0:00:51  time: 0.0513  data_time: 0.0133  memory: 382  loss: 1.4828\n",
      "11/22 16:50:43 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 660/1563]  lr: 1.0000e-03  eta: 0:00:50  time: 0.0516  data_time: 0.0135  memory: 382  loss: 1.6222\n",
      "11/22 16:50:44 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 670/1563]  lr: 1.0000e-03  eta: 0:00:49  time: 0.0516  data_time: 0.0135  memory: 382  loss: 1.5357\n",
      "11/22 16:50:44 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 680/1563]  lr: 1.0000e-03  eta: 0:00:49  time: 0.0515  data_time: 0.0133  memory: 382  loss: 1.6462\n",
      "11/22 16:50:45 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 690/1563]  lr: 1.0000e-03  eta: 0:00:48  time: 0.0514  data_time: 0.0135  memory: 382  loss: 1.4879\n",
      "11/22 16:50:45 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 700/1563]  lr: 1.0000e-03  eta: 0:00:48  time: 0.0497  data_time: 0.0138  memory: 382  loss: 1.5146\n",
      "11/22 16:50:46 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 710/1563]  lr: 1.0000e-03  eta: 0:00:47  time: 0.0501  data_time: 0.0134  memory: 382  loss: 1.5513\n",
      "11/22 16:50:46 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 720/1563]  lr: 1.0000e-03  eta: 0:00:47  time: 0.0516  data_time: 0.0134  memory: 382  loss: 1.5761\n",
      "11/22 16:50:47 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 730/1563]  lr: 1.0000e-03  eta: 0:00:46  time: 0.0516  data_time: 0.0134  memory: 382  loss: 1.5548\n",
      "11/22 16:50:47 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 740/1563]  lr: 1.0000e-03  eta: 0:00:45  time: 0.0518  data_time: 0.0136  memory: 382  loss: 1.5272\n",
      "11/22 16:50:48 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Exp name: 20241122_164350\n",
      "11/22 16:50:48 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 750/1563]  lr: 1.0000e-03  eta: 0:00:45  time: 0.0520  data_time: 0.0137  memory: 382  loss: 1.5802\n",
      "11/22 16:50:48 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 760/1563]  lr: 1.0000e-03  eta: 0:00:44  time: 0.0515  data_time: 0.0134  memory: 382  loss: 1.5568\n",
      "11/22 16:50:49 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 770/1563]  lr: 1.0000e-03  eta: 0:00:44  time: 0.0516  data_time: 0.0135  memory: 382  loss: 1.4462\n",
      "11/22 16:50:50 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 780/1563]  lr: 1.0000e-03  eta: 0:00:43  time: 0.0516  data_time: 0.0134  memory: 382  loss: 1.5174\n",
      "11/22 16:50:50 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 790/1563]  lr: 1.0000e-03  eta: 0:00:43  time: 0.0516  data_time: 0.0134  memory: 382  loss: 1.5304\n",
      "11/22 16:50:51 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 800/1563]  lr: 1.0000e-03  eta: 0:00:42  time: 0.0513  data_time: 0.0134  memory: 382  loss: 1.3804\n",
      "11/22 16:50:51 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 810/1563]  lr: 1.0000e-03  eta: 0:00:42  time: 0.0515  data_time: 0.0134  memory: 382  loss: 1.5559\n",
      "11/22 16:50:52 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 820/1563]  lr: 1.0000e-03  eta: 0:00:41  time: 0.0518  data_time: 0.0136  memory: 382  loss: 1.5324\n",
      "11/22 16:50:52 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 830/1563]  lr: 1.0000e-03  eta: 0:00:40  time: 0.0514  data_time: 0.0135  memory: 382  loss: 1.6753\n",
      "11/22 16:50:53 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 840/1563]  lr: 1.0000e-03  eta: 0:00:40  time: 0.0523  data_time: 0.0139  memory: 382  loss: 1.4945\n",
      "11/22 16:50:53 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 850/1563]  lr: 1.0000e-03  eta: 0:00:39  time: 0.0512  data_time: 0.0132  memory: 382  loss: 1.5660\n",
      "11/22 16:50:54 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 860/1563]  lr: 1.0000e-03  eta: 0:00:39  time: 0.0519  data_time: 0.0136  memory: 382  loss: 1.5264\n",
      "11/22 16:50:54 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 870/1563]  lr: 1.0000e-03  eta: 0:00:38  time: 0.0514  data_time: 0.0133  memory: 382  loss: 1.3853\n",
      "11/22 16:50:55 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 880/1563]  lr: 1.0000e-03  eta: 0:00:38  time: 0.0514  data_time: 0.0133  memory: 382  loss: 1.5576\n",
      "11/22 16:50:55 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 890/1563]  lr: 1.0000e-03  eta: 0:00:37  time: 0.0517  data_time: 0.0135  memory: 382  loss: 1.5043\n",
      "11/22 16:50:56 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 900/1563]  lr: 1.0000e-03  eta: 0:00:36  time: 0.0527  data_time: 0.0141  memory: 382  loss: 1.5948\n",
      "11/22 16:50:56 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 910/1563]  lr: 1.0000e-03  eta: 0:00:36  time: 0.0523  data_time: 0.0138  memory: 382  loss: 1.5114\n",
      "11/22 16:50:57 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 920/1563]  lr: 1.0000e-03  eta: 0:00:35  time: 0.0522  data_time: 0.0136  memory: 382  loss: 1.5999\n",
      "11/22 16:50:57 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 930/1563]  lr: 1.0000e-03  eta: 0:00:35  time: 0.0518  data_time: 0.0136  memory: 382  loss: 1.4599\n",
      "11/22 16:50:58 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 940/1563]  lr: 1.0000e-03  eta: 0:00:34  time: 0.0514  data_time: 0.0134  memory: 382  loss: 1.4754\n",
      "11/22 16:50:58 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 950/1563]  lr: 1.0000e-03  eta: 0:00:34  time: 0.0514  data_time: 0.0135  memory: 382  loss: 1.5212\n",
      "11/22 16:50:59 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 960/1563]  lr: 1.0000e-03  eta: 0:00:33  time: 0.0515  data_time: 0.0134  memory: 382  loss: 1.4693\n",
      "11/22 16:50:59 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 970/1563]  lr: 1.0000e-03  eta: 0:00:33  time: 0.0516  data_time: 0.0134  memory: 382  loss: 1.4739\n",
      "11/22 16:51:00 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 980/1563]  lr: 1.0000e-03  eta: 0:00:32  time: 0.0518  data_time: 0.0136  memory: 382  loss: 1.5810\n",
      "11/22 16:51:00 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][ 990/1563]  lr: 1.0000e-03  eta: 0:00:31  time: 0.0518  data_time: 0.0136  memory: 382  loss: 1.4858\n",
      "11/22 16:51:01 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][1000/1563]  lr: 1.0000e-03  eta: 0:00:31  time: 0.0545  data_time: 0.0174  memory: 382  loss: 1.5966\n",
      "11/22 16:51:01 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][1010/1563]  lr: 1.0000e-03  eta: 0:00:30  time: 0.0508  data_time: 0.0148  memory: 382  loss: 1.4623\n",
      "11/22 16:51:02 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][1020/1563]  lr: 1.0000e-03  eta: 0:00:30  time: 0.0517  data_time: 0.0136  memory: 382  loss: 1.6233\n",
      "11/22 16:51:03 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][1030/1563]  lr: 1.0000e-03  eta: 0:00:29  time: 0.0599  data_time: 0.0184  memory: 382  loss: 1.5946\n",
      "11/22 16:51:03 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][1040/1563]  lr: 1.0000e-03  eta: 0:00:29  time: 0.0505  data_time: 0.0137  memory: 382  loss: 1.4944\n",
      "11/22 16:51:04 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][1050/1563]  lr: 1.0000e-03  eta: 0:00:28  time: 0.0520  data_time: 0.0138  memory: 382  loss: 1.4998\n",
      "11/22 16:51:04 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][1060/1563]  lr: 1.0000e-03  eta: 0:00:28  time: 0.0516  data_time: 0.0137  memory: 382  loss: 1.5143\n",
      "11/22 16:51:05 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][1070/1563]  lr: 1.0000e-03  eta: 0:00:27  time: 0.0759  data_time: 0.0253  memory: 382  loss: 1.4463\n",
      "11/22 16:51:06 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][1080/1563]  lr: 1.0000e-03  eta: 0:00:26  time: 0.0761  data_time: 0.0264  memory: 382  loss: 1.4758\n",
      "11/22 16:51:06 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][1090/1563]  lr: 1.0000e-03  eta: 0:00:26  time: 0.0593  data_time: 0.0199  memory: 382  loss: 1.3308\n",
      "11/22 16:51:07 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][1100/1563]  lr: 1.0000e-03  eta: 0:00:25  time: 0.0473  data_time: 0.0135  memory: 382  loss: 1.6007\n",
      "11/22 16:51:07 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][1110/1563]  lr: 1.0000e-03  eta: 0:00:25  time: 0.0497  data_time: 0.0154  memory: 382  loss: 1.4717\n",
      "11/22 16:51:08 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][1120/1563]  lr: 1.0000e-03  eta: 0:00:24  time: 0.0545  data_time: 0.0158  memory: 382  loss: 1.4900\n",
      "11/22 16:51:08 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][1130/1563]  lr: 1.0000e-03  eta: 0:00:24  time: 0.0515  data_time: 0.0135  memory: 382  loss: 1.5029\n",
      "11/22 16:51:09 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][1140/1563]  lr: 1.0000e-03  eta: 0:00:23  time: 0.0518  data_time: 0.0153  memory: 382  loss: 1.4895\n",
      "11/22 16:51:09 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][1150/1563]  lr: 1.0000e-03  eta: 0:00:23  time: 0.0547  data_time: 0.0166  memory: 382  loss: 1.5550\n",
      "11/22 16:51:10 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][1160/1563]  lr: 1.0000e-03  eta: 0:00:22  time: 0.0597  data_time: 0.0169  memory: 382  loss: 1.4044\n",
      "11/22 16:51:10 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][1170/1563]  lr: 1.0000e-03  eta: 0:00:21  time: 0.0580  data_time: 0.0159  memory: 382  loss: 1.4789\n",
      "11/22 16:51:11 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][1180/1563]  lr: 1.0000e-03  eta: 0:00:21  time: 0.0858  data_time: 0.0300  memory: 382  loss: 1.4462\n",
      "11/22 16:51:12 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][1190/1563]  lr: 1.0000e-03  eta: 0:00:20  time: 0.0787  data_time: 0.0282  memory: 382  loss: 1.5601\n",
      "11/22 16:51:13 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][1200/1563]  lr: 1.0000e-03  eta: 0:00:20  time: 0.0636  data_time: 0.0207  memory: 382  loss: 1.5417\n",
      "11/22 16:51:13 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][1210/1563]  lr: 1.0000e-03  eta: 0:00:19  time: 0.0525  data_time: 0.0158  memory: 382  loss: 1.5232\n",
      "11/22 16:51:14 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][1220/1563]  lr: 1.0000e-03  eta: 0:00:19  time: 0.0571  data_time: 0.0158  memory: 382  loss: 1.4043\n",
      "11/22 16:51:14 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][1230/1563]  lr: 1.0000e-03  eta: 0:00:18  time: 0.0576  data_time: 0.0157  memory: 382  loss: 1.5698\n",
      "11/22 16:51:15 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][1240/1563]  lr: 1.0000e-03  eta: 0:00:18  time: 0.0575  data_time: 0.0156  memory: 382  loss: 1.4904\n",
      "11/22 16:51:16 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][1250/1563]  lr: 1.0000e-03  eta: 0:00:17  time: 0.0579  data_time: 0.0156  memory: 382  loss: 1.5992\n",
      "11/22 16:51:16 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][1260/1563]  lr: 1.0000e-03  eta: 0:00:16  time: 0.0581  data_time: 0.0157  memory: 382  loss: 1.4858\n",
      "11/22 16:51:17 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][1270/1563]  lr: 1.0000e-03  eta: 0:00:16  time: 0.0580  data_time: 0.0157  memory: 382  loss: 1.3606\n",
      "11/22 16:51:17 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][1280/1563]  lr: 1.0000e-03  eta: 0:00:15  time: 0.0582  data_time: 0.0157  memory: 382  loss: 1.6510\n",
      "11/22 16:51:18 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][1290/1563]  lr: 1.0000e-03  eta: 0:00:15  time: 0.0582  data_time: 0.0157  memory: 382  loss: 1.5346\n",
      "11/22 16:51:19 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][1300/1563]  lr: 1.0000e-03  eta: 0:00:14  time: 0.0582  data_time: 0.0158  memory: 382  loss: 1.3520\n",
      "11/22 16:51:19 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][1310/1563]  lr: 1.0000e-03  eta: 0:00:14  time: 0.0581  data_time: 0.0156  memory: 382  loss: 1.5014\n",
      "11/22 16:51:20 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][1320/1563]  lr: 1.0000e-03  eta: 0:00:13  time: 0.0580  data_time: 0.0156  memory: 382  loss: 1.4836\n",
      "11/22 16:51:20 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][1330/1563]  lr: 1.0000e-03  eta: 0:00:13  time: 0.0581  data_time: 0.0156  memory: 382  loss: 1.3875\n",
      "11/22 16:51:21 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][1340/1563]  lr: 1.0000e-03  eta: 0:00:12  time: 0.0582  data_time: 0.0156  memory: 382  loss: 1.4849\n",
      "11/22 16:51:21 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][1350/1563]  lr: 1.0000e-03  eta: 0:00:11  time: 0.0582  data_time: 0.0158  memory: 382  loss: 1.5298\n",
      "11/22 16:51:22 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][1360/1563]  lr: 1.0000e-03  eta: 0:00:11  time: 0.0583  data_time: 0.0159  memory: 382  loss: 1.4389\n",
      "11/22 16:51:23 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][1370/1563]  lr: 1.0000e-03  eta: 0:00:10  time: 0.0580  data_time: 0.0156  memory: 382  loss: 1.4141\n",
      "11/22 16:51:23 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][1380/1563]  lr: 1.0000e-03  eta: 0:00:10  time: 0.0581  data_time: 0.0157  memory: 382  loss: 1.4422\n",
      "11/22 16:51:24 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][1390/1563]  lr: 1.0000e-03  eta: 0:00:09  time: 0.0582  data_time: 0.0157  memory: 382  loss: 1.4260\n",
      "11/22 16:51:24 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][1400/1563]  lr: 1.0000e-03  eta: 0:00:09  time: 0.0585  data_time: 0.0161  memory: 382  loss: 1.3820\n",
      "11/22 16:51:25 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][1410/1563]  lr: 1.0000e-03  eta: 0:00:08  time: 0.0579  data_time: 0.0156  memory: 382  loss: 1.4658\n",
      "11/22 16:51:25 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][1420/1563]  lr: 1.0000e-03  eta: 0:00:07  time: 0.0583  data_time: 0.0159  memory: 382  loss: 1.4120\n",
      "11/22 16:51:26 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][1430/1563]  lr: 1.0000e-03  eta: 0:00:07  time: 0.0576  data_time: 0.0157  memory: 382  loss: 1.5193\n",
      "11/22 16:51:27 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][1440/1563]  lr: 1.0000e-03  eta: 0:00:06  time: 0.0585  data_time: 0.0159  memory: 382  loss: 1.5316\n",
      "11/22 16:51:27 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][1450/1563]  lr: 1.0000e-03  eta: 0:00:06  time: 0.0582  data_time: 0.0158  memory: 382  loss: 1.4528\n",
      "11/22 16:51:28 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][1460/1563]  lr: 1.0000e-03  eta: 0:00:05  time: 0.0584  data_time: 0.0160  memory: 382  loss: 1.5557\n",
      "11/22 16:51:28 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][1470/1563]  lr: 1.0000e-03  eta: 0:00:05  time: 0.0579  data_time: 0.0156  memory: 382  loss: 1.4487\n",
      "11/22 16:51:29 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][1480/1563]  lr: 1.0000e-03  eta: 0:00:04  time: 0.0581  data_time: 0.0156  memory: 382  loss: 1.4470\n",
      "11/22 16:51:30 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][1490/1563]  lr: 1.0000e-03  eta: 0:00:04  time: 0.0581  data_time: 0.0157  memory: 382  loss: 1.4924\n",
      "11/22 16:51:30 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][1500/1563]  lr: 1.0000e-03  eta: 0:00:03  time: 0.0580  data_time: 0.0156  memory: 382  loss: 1.5511\n",
      "11/22 16:51:31 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][1510/1563]  lr: 1.0000e-03  eta: 0:00:02  time: 0.0580  data_time: 0.0156  memory: 382  loss: 1.4933\n",
      "11/22 16:51:31 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][1520/1563]  lr: 1.0000e-03  eta: 0:00:02  time: 0.0578  data_time: 0.0156  memory: 382  loss: 1.6460\n",
      "11/22 16:51:32 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][1530/1563]  lr: 1.0000e-03  eta: 0:00:01  time: 0.0579  data_time: 0.0157  memory: 382  loss: 1.4602\n",
      "11/22 16:51:32 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][1540/1563]  lr: 1.0000e-03  eta: 0:00:01  time: 0.0584  data_time: 0.0159  memory: 382  loss: 1.4839\n",
      "11/22 16:51:33 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][1550/1563]  lr: 1.0000e-03  eta: 0:00:00  time: 0.0579  data_time: 0.0156  memory: 382  loss: 1.4155\n",
      "11/22 16:51:34 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(train) [5][1560/1563]  lr: 1.0000e-03  eta: 0:00:00  time: 0.0581  data_time: 0.0157  memory: 382  loss: 1.4509\n",
      "11/22 16:51:34 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Exp name: 20241122_164350\n",
      "11/22 16:51:34 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Saving checkpoint at 5 epochs\n",
      "11/22 16:51:35 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [5][ 10/313]    eta: 0:00:06  time: 0.0206  data_time: 0.0100  memory: 382  \n",
      "11/22 16:51:35 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [5][ 20/313]    eta: 0:00:06  time: 0.0204  data_time: 0.0100  memory: 225  \n",
      "11/22 16:51:35 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [5][ 30/313]    eta: 0:00:05  time: 0.0208  data_time: 0.0102  memory: 225  \n",
      "11/22 16:51:35 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [5][ 40/313]    eta: 0:00:05  time: 0.0205  data_time: 0.0100  memory: 225  \n",
      "11/22 16:51:35 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [5][ 50/313]    eta: 0:00:05  time: 0.0206  data_time: 0.0100  memory: 225  \n",
      "11/22 16:51:36 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [5][ 60/313]    eta: 0:00:05  time: 0.0203  data_time: 0.0099  memory: 225  \n",
      "11/22 16:51:36 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [5][ 70/313]    eta: 0:00:04  time: 0.0205  data_time: 0.0100  memory: 225  \n",
      "11/22 16:51:36 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [5][ 80/313]    eta: 0:00:04  time: 0.0204  data_time: 0.0099  memory: 225  \n",
      "11/22 16:51:36 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [5][ 90/313]    eta: 0:00:04  time: 0.0203  data_time: 0.0099  memory: 225  \n",
      "11/22 16:51:36 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [5][100/313]    eta: 0:00:04  time: 0.0205  data_time: 0.0100  memory: 225  \n",
      "11/22 16:51:37 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [5][110/313]    eta: 0:00:04  time: 0.0204  data_time: 0.0099  memory: 225  \n",
      "11/22 16:51:37 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [5][120/313]    eta: 0:00:03  time: 0.0204  data_time: 0.0099  memory: 225  \n",
      "11/22 16:51:37 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [5][130/313]    eta: 0:00:03  time: 0.0265  data_time: 0.0132  memory: 225  \n",
      "11/22 16:51:37 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [5][140/313]    eta: 0:00:03  time: 0.0226  data_time: 0.0110  memory: 225  \n",
      "11/22 16:51:38 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [5][150/313]    eta: 0:00:03  time: 0.0210  data_time: 0.0102  memory: 225  \n",
      "11/22 16:51:38 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [5][160/313]    eta: 0:00:03  time: 0.0204  data_time: 0.0099  memory: 225  \n",
      "11/22 16:51:38 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [5][170/313]    eta: 0:00:03  time: 0.0205  data_time: 0.0099  memory: 225  \n",
      "11/22 16:51:38 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [5][180/313]    eta: 0:00:02  time: 0.0206  data_time: 0.0100  memory: 225  \n",
      "11/22 16:51:38 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [5][190/313]    eta: 0:00:02  time: 0.0205  data_time: 0.0100  memory: 225  \n",
      "11/22 16:51:39 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [5][200/313]    eta: 0:00:02  time: 0.0260  data_time: 0.0125  memory: 225  \n",
      "11/22 16:51:39 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [5][210/313]    eta: 0:00:02  time: 0.0223  data_time: 0.0108  memory: 225  \n",
      "11/22 16:51:39 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [5][220/313]    eta: 0:00:01  time: 0.0217  data_time: 0.0105  memory: 225  \n",
      "11/22 16:51:39 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [5][230/313]    eta: 0:00:01  time: 0.0186  data_time: 0.0091  memory: 225  \n",
      "11/22 16:51:39 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [5][240/313]    eta: 0:00:01  time: 0.0180  data_time: 0.0089  memory: 225  \n",
      "11/22 16:51:40 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [5][250/313]    eta: 0:00:01  time: 0.0180  data_time: 0.0089  memory: 225  \n",
      "11/22 16:51:40 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [5][260/313]    eta: 0:00:01  time: 0.0179  data_time: 0.0088  memory: 225  \n",
      "11/22 16:51:40 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [5][270/313]    eta: 0:00:00  time: 0.0180  data_time: 0.0089  memory: 225  \n",
      "11/22 16:51:40 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [5][280/313]    eta: 0:00:00  time: 0.0181  data_time: 0.0089  memory: 225  \n",
      "11/22 16:51:40 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [5][290/313]    eta: 0:00:00  time: 0.0179  data_time: 0.0088  memory: 225  \n",
      "11/22 16:51:41 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [5][300/313]    eta: 0:00:00  time: 0.0180  data_time: 0.0089  memory: 225  \n",
      "11/22 16:51:41 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [5][310/313]    eta: 0:00:00  time: 0.0312  data_time: 0.0154  memory: 225  \n",
      "11/22 16:51:41 - mmengine - \u001b[4m\u001b[97mINFO\u001b[0m - Epoch(val) [5][313/313]    accuracy: 49.1500  data_time: 0.0102  time: 0.0208\n"
     ]
    },
    {
     "data": {
      "text/plain": [
       "MMResNet50(\n",
       "  (data_preprocessor): BaseDataPreprocessor()\n",
       "  (resnet): ResNet(\n",
       "    (conv1): Conv2d(3, 64, kernel_size=(7, 7), stride=(2, 2), padding=(3, 3), bias=False)\n",
       "    (bn1): BatchNorm2d(64, eps=1e-05, momentum=0.1, affine=True, track_running_stats=True)\n",
       "    (relu): ReLU(inplace=True)\n",
       "    (maxpool): MaxPool2d(kernel_size=3, stride=2, padding=1, dilation=1, ceil_mode=False)\n",
       "    (layer1): Sequential(\n",
       "      (0): Bottleneck(\n",
       "        (conv1): Conv2d(64, 64, kernel_size=(1, 1), stride=(1, 1), bias=False)\n",
       "        (bn1): BatchNorm2d(64, eps=1e-05, momentum=0.1, affine=True, track_running_stats=True)\n",
       "        (conv2): Conv2d(64, 64, kernel_size=(3, 3), stride=(1, 1), padding=(1, 1), bias=False)\n",
       "        (bn2): BatchNorm2d(64, eps=1e-05, momentum=0.1, affine=True, track_running_stats=True)\n",
       "        (conv3): Conv2d(64, 256, kernel_size=(1, 1), stride=(1, 1), bias=False)\n",
       "        (bn3): BatchNorm2d(256, eps=1e-05, momentum=0.1, affine=True, track_running_stats=True)\n",
       "        (relu): ReLU(inplace=True)\n",
       "        (downsample): Sequential(\n",
       "          (0): Conv2d(64, 256, kernel_size=(1, 1), stride=(1, 1), bias=False)\n",
       "          (1): BatchNorm2d(256, eps=1e-05, momentum=0.1, affine=True, track_running_stats=True)\n",
       "        )\n",
       "      )\n",
       "      (1): Bottleneck(\n",
       "        (conv1): Conv2d(256, 64, kernel_size=(1, 1), stride=(1, 1), bias=False)\n",
       "        (bn1): BatchNorm2d(64, eps=1e-05, momentum=0.1, affine=True, track_running_stats=True)\n",
       "        (conv2): Conv2d(64, 64, kernel_size=(3, 3), stride=(1, 1), padding=(1, 1), bias=False)\n",
       "        (bn2): BatchNorm2d(64, eps=1e-05, momentum=0.1, affine=True, track_running_stats=True)\n",
       "        (conv3): Conv2d(64, 256, kernel_size=(1, 1), stride=(1, 1), bias=False)\n",
       "        (bn3): BatchNorm2d(256, eps=1e-05, momentum=0.1, affine=True, track_running_stats=True)\n",
       "        (relu): ReLU(inplace=True)\n",
       "      )\n",
       "      (2): Bottleneck(\n",
       "        (conv1): Conv2d(256, 64, kernel_size=(1, 1), stride=(1, 1), bias=False)\n",
       "        (bn1): BatchNorm2d(64, eps=1e-05, momentum=0.1, affine=True, track_running_stats=True)\n",
       "        (conv2): Conv2d(64, 64, kernel_size=(3, 3), stride=(1, 1), padding=(1, 1), bias=False)\n",
       "        (bn2): BatchNorm2d(64, eps=1e-05, momentum=0.1, affine=True, track_running_stats=True)\n",
       "        (conv3): Conv2d(64, 256, kernel_size=(1, 1), stride=(1, 1), bias=False)\n",
       "        (bn3): BatchNorm2d(256, eps=1e-05, momentum=0.1, affine=True, track_running_stats=True)\n",
       "        (relu): ReLU(inplace=True)\n",
       "      )\n",
       "    )\n",
       "    (layer2): Sequential(\n",
       "      (0): Bottleneck(\n",
       "        (conv1): Conv2d(256, 128, kernel_size=(1, 1), stride=(1, 1), bias=False)\n",
       "        (bn1): BatchNorm2d(128, eps=1e-05, momentum=0.1, affine=True, track_running_stats=True)\n",
       "        (conv2): Conv2d(128, 128, kernel_size=(3, 3), stride=(2, 2), padding=(1, 1), bias=False)\n",
       "        (bn2): BatchNorm2d(128, eps=1e-05, momentum=0.1, affine=True, track_running_stats=True)\n",
       "        (conv3): Conv2d(128, 512, kernel_size=(1, 1), stride=(1, 1), bias=False)\n",
       "        (bn3): BatchNorm2d(512, eps=1e-05, momentum=0.1, affine=True, track_running_stats=True)\n",
       "        (relu): ReLU(inplace=True)\n",
       "        (downsample): Sequential(\n",
       "          (0): Conv2d(256, 512, kernel_size=(1, 1), stride=(2, 2), bias=False)\n",
       "          (1): BatchNorm2d(512, eps=1e-05, momentum=0.1, affine=True, track_running_stats=True)\n",
       "        )\n",
       "      )\n",
       "      (1): Bottleneck(\n",
       "        (conv1): Conv2d(512, 128, kernel_size=(1, 1), stride=(1, 1), bias=False)\n",
       "        (bn1): BatchNorm2d(128, eps=1e-05, momentum=0.1, affine=True, track_running_stats=True)\n",
       "        (conv2): Conv2d(128, 128, kernel_size=(3, 3), stride=(1, 1), padding=(1, 1), bias=False)\n",
       "        (bn2): BatchNorm2d(128, eps=1e-05, momentum=0.1, affine=True, track_running_stats=True)\n",
       "        (conv3): Conv2d(128, 512, kernel_size=(1, 1), stride=(1, 1), bias=False)\n",
       "        (bn3): BatchNorm2d(512, eps=1e-05, momentum=0.1, affine=True, track_running_stats=True)\n",
       "        (relu): ReLU(inplace=True)\n",
       "      )\n",
       "      (2): Bottleneck(\n",
       "        (conv1): Conv2d(512, 128, kernel_size=(1, 1), stride=(1, 1), bias=False)\n",
       "        (bn1): BatchNorm2d(128, eps=1e-05, momentum=0.1, affine=True, track_running_stats=True)\n",
       "        (conv2): Conv2d(128, 128, kernel_size=(3, 3), stride=(1, 1), padding=(1, 1), bias=False)\n",
       "        (bn2): BatchNorm2d(128, eps=1e-05, momentum=0.1, affine=True, track_running_stats=True)\n",
       "        (conv3): Conv2d(128, 512, kernel_size=(1, 1), stride=(1, 1), bias=False)\n",
       "        (bn3): BatchNorm2d(512, eps=1e-05, momentum=0.1, affine=True, track_running_stats=True)\n",
       "        (relu): ReLU(inplace=True)\n",
       "      )\n",
       "      (3): Bottleneck(\n",
       "        (conv1): Conv2d(512, 128, kernel_size=(1, 1), stride=(1, 1), bias=False)\n",
       "        (bn1): BatchNorm2d(128, eps=1e-05, momentum=0.1, affine=True, track_running_stats=True)\n",
       "        (conv2): Conv2d(128, 128, kernel_size=(3, 3), stride=(1, 1), padding=(1, 1), bias=False)\n",
       "        (bn2): BatchNorm2d(128, eps=1e-05, momentum=0.1, affine=True, track_running_stats=True)\n",
       "        (conv3): Conv2d(128, 512, kernel_size=(1, 1), stride=(1, 1), bias=False)\n",
       "        (bn3): BatchNorm2d(512, eps=1e-05, momentum=0.1, affine=True, track_running_stats=True)\n",
       "        (relu): ReLU(inplace=True)\n",
       "      )\n",
       "    )\n",
       "    (layer3): Sequential(\n",
       "      (0): Bottleneck(\n",
       "        (conv1): Conv2d(512, 256, kernel_size=(1, 1), stride=(1, 1), bias=False)\n",
       "        (bn1): BatchNorm2d(256, eps=1e-05, momentum=0.1, affine=True, track_running_stats=True)\n",
       "        (conv2): Conv2d(256, 256, kernel_size=(3, 3), stride=(2, 2), padding=(1, 1), bias=False)\n",
       "        (bn2): BatchNorm2d(256, eps=1e-05, momentum=0.1, affine=True, track_running_stats=True)\n",
       "        (conv3): Conv2d(256, 1024, kernel_size=(1, 1), stride=(1, 1), bias=False)\n",
       "        (bn3): BatchNorm2d(1024, eps=1e-05, momentum=0.1, affine=True, track_running_stats=True)\n",
       "        (relu): ReLU(inplace=True)\n",
       "        (downsample): Sequential(\n",
       "          (0): Conv2d(512, 1024, kernel_size=(1, 1), stride=(2, 2), bias=False)\n",
       "          (1): BatchNorm2d(1024, eps=1e-05, momentum=0.1, affine=True, track_running_stats=True)\n",
       "        )\n",
       "      )\n",
       "      (1): Bottleneck(\n",
       "        (conv1): Conv2d(1024, 256, kernel_size=(1, 1), stride=(1, 1), bias=False)\n",
       "        (bn1): BatchNorm2d(256, eps=1e-05, momentum=0.1, affine=True, track_running_stats=True)\n",
       "        (conv2): Conv2d(256, 256, kernel_size=(3, 3), stride=(1, 1), padding=(1, 1), bias=False)\n",
       "        (bn2): BatchNorm2d(256, eps=1e-05, momentum=0.1, affine=True, track_running_stats=True)\n",
       "        (conv3): Conv2d(256, 1024, kernel_size=(1, 1), stride=(1, 1), bias=False)\n",
       "        (bn3): BatchNorm2d(1024, eps=1e-05, momentum=0.1, affine=True, track_running_stats=True)\n",
       "        (relu): ReLU(inplace=True)\n",
       "      )\n",
       "      (2): Bottleneck(\n",
       "        (conv1): Conv2d(1024, 256, kernel_size=(1, 1), stride=(1, 1), bias=False)\n",
       "        (bn1): BatchNorm2d(256, eps=1e-05, momentum=0.1, affine=True, track_running_stats=True)\n",
       "        (conv2): Conv2d(256, 256, kernel_size=(3, 3), stride=(1, 1), padding=(1, 1), bias=False)\n",
       "        (bn2): BatchNorm2d(256, eps=1e-05, momentum=0.1, affine=True, track_running_stats=True)\n",
       "        (conv3): Conv2d(256, 1024, kernel_size=(1, 1), stride=(1, 1), bias=False)\n",
       "        (bn3): BatchNorm2d(1024, eps=1e-05, momentum=0.1, affine=True, track_running_stats=True)\n",
       "        (relu): ReLU(inplace=True)\n",
       "      )\n",
       "      (3): Bottleneck(\n",
       "        (conv1): Conv2d(1024, 256, kernel_size=(1, 1), stride=(1, 1), bias=False)\n",
       "        (bn1): BatchNorm2d(256, eps=1e-05, momentum=0.1, affine=True, track_running_stats=True)\n",
       "        (conv2): Conv2d(256, 256, kernel_size=(3, 3), stride=(1, 1), padding=(1, 1), bias=False)\n",
       "        (bn2): BatchNorm2d(256, eps=1e-05, momentum=0.1, affine=True, track_running_stats=True)\n",
       "        (conv3): Conv2d(256, 1024, kernel_size=(1, 1), stride=(1, 1), bias=False)\n",
       "        (bn3): BatchNorm2d(1024, eps=1e-05, momentum=0.1, affine=True, track_running_stats=True)\n",
       "        (relu): ReLU(inplace=True)\n",
       "      )\n",
       "      (4): Bottleneck(\n",
       "        (conv1): Conv2d(1024, 256, kernel_size=(1, 1), stride=(1, 1), bias=False)\n",
       "        (bn1): BatchNorm2d(256, eps=1e-05, momentum=0.1, affine=True, track_running_stats=True)\n",
       "        (conv2): Conv2d(256, 256, kernel_size=(3, 3), stride=(1, 1), padding=(1, 1), bias=False)\n",
       "        (bn2): BatchNorm2d(256, eps=1e-05, momentum=0.1, affine=True, track_running_stats=True)\n",
       "        (conv3): Conv2d(256, 1024, kernel_size=(1, 1), stride=(1, 1), bias=False)\n",
       "        (bn3): BatchNorm2d(1024, eps=1e-05, momentum=0.1, affine=True, track_running_stats=True)\n",
       "        (relu): ReLU(inplace=True)\n",
       "      )\n",
       "      (5): Bottleneck(\n",
       "        (conv1): Conv2d(1024, 256, kernel_size=(1, 1), stride=(1, 1), bias=False)\n",
       "        (bn1): BatchNorm2d(256, eps=1e-05, momentum=0.1, affine=True, track_running_stats=True)\n",
       "        (conv2): Conv2d(256, 256, kernel_size=(3, 3), stride=(1, 1), padding=(1, 1), bias=False)\n",
       "        (bn2): BatchNorm2d(256, eps=1e-05, momentum=0.1, affine=True, track_running_stats=True)\n",
       "        (conv3): Conv2d(256, 1024, kernel_size=(1, 1), stride=(1, 1), bias=False)\n",
       "        (bn3): BatchNorm2d(1024, eps=1e-05, momentum=0.1, affine=True, track_running_stats=True)\n",
       "        (relu): ReLU(inplace=True)\n",
       "      )\n",
       "    )\n",
       "    (layer4): Sequential(\n",
       "      (0): Bottleneck(\n",
       "        (conv1): Conv2d(1024, 512, kernel_size=(1, 1), stride=(1, 1), bias=False)\n",
       "        (bn1): BatchNorm2d(512, eps=1e-05, momentum=0.1, affine=True, track_running_stats=True)\n",
       "        (conv2): Conv2d(512, 512, kernel_size=(3, 3), stride=(2, 2), padding=(1, 1), bias=False)\n",
       "        (bn2): BatchNorm2d(512, eps=1e-05, momentum=0.1, affine=True, track_running_stats=True)\n",
       "        (conv3): Conv2d(512, 2048, kernel_size=(1, 1), stride=(1, 1), bias=False)\n",
       "        (bn3): BatchNorm2d(2048, eps=1e-05, momentum=0.1, affine=True, track_running_stats=True)\n",
       "        (relu): ReLU(inplace=True)\n",
       "        (downsample): Sequential(\n",
       "          (0): Conv2d(1024, 2048, kernel_size=(1, 1), stride=(2, 2), bias=False)\n",
       "          (1): BatchNorm2d(2048, eps=1e-05, momentum=0.1, affine=True, track_running_stats=True)\n",
       "        )\n",
       "      )\n",
       "      (1): Bottleneck(\n",
       "        (conv1): Conv2d(2048, 512, kernel_size=(1, 1), stride=(1, 1), bias=False)\n",
       "        (bn1): BatchNorm2d(512, eps=1e-05, momentum=0.1, affine=True, track_running_stats=True)\n",
       "        (conv2): Conv2d(512, 512, kernel_size=(3, 3), stride=(1, 1), padding=(1, 1), bias=False)\n",
       "        (bn2): BatchNorm2d(512, eps=1e-05, momentum=0.1, affine=True, track_running_stats=True)\n",
       "        (conv3): Conv2d(512, 2048, kernel_size=(1, 1), stride=(1, 1), bias=False)\n",
       "        (bn3): BatchNorm2d(2048, eps=1e-05, momentum=0.1, affine=True, track_running_stats=True)\n",
       "        (relu): ReLU(inplace=True)\n",
       "      )\n",
       "      (2): Bottleneck(\n",
       "        (conv1): Conv2d(2048, 512, kernel_size=(1, 1), stride=(1, 1), bias=False)\n",
       "        (bn1): BatchNorm2d(512, eps=1e-05, momentum=0.1, affine=True, track_running_stats=True)\n",
       "        (conv2): Conv2d(512, 512, kernel_size=(3, 3), stride=(1, 1), padding=(1, 1), bias=False)\n",
       "        (bn2): BatchNorm2d(512, eps=1e-05, momentum=0.1, affine=True, track_running_stats=True)\n",
       "        (conv3): Conv2d(512, 2048, kernel_size=(1, 1), stride=(1, 1), bias=False)\n",
       "        (bn3): BatchNorm2d(2048, eps=1e-05, momentum=0.1, affine=True, track_running_stats=True)\n",
       "        (relu): ReLU(inplace=True)\n",
       "      )\n",
       "    )\n",
       "    (avgpool): AdaptiveAvgPool2d(output_size=(1, 1))\n",
       "    (fc): Linear(in_features=2048, out_features=1000, bias=True)\n",
       "  )\n",
       ")"
      ]
     },
     "execution_count": 6,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "from torch.optim import SGD\n",
    "from mmengine.runner import Runner\n",
    "\n",
    "runner = Runner(\n",
    "    # 用以训练和验证的模型，需要满足特定的接口需求\n",
    "    model=MMResNet50(),\n",
    "    # 工作路径，用以保存训练日志、权重文件信息\n",
    "    work_dir=temp_dir/'./work_dir',\n",
    "    # 训练数据加载器，需要满足 PyTorch 数据加载器协议\n",
    "    train_dataloader=train_dataloader,\n",
    "    # 优化器包装，用于模型优化，并提供 AMP、梯度累积等附加功能\n",
    "    optim_wrapper=dict(optimizer=dict(type=SGD, lr=0.001, momentum=0.9)),\n",
    "    # 训练配置，用于指定训练周期、验证间隔等信息\n",
    "    train_cfg=dict(by_epoch=True, max_epochs=5, val_interval=1),\n",
    "    # 验证数据加载器，需要满足 PyTorch 数据加载器协议\n",
    "    val_dataloader=val_dataloader,\n",
    "    # 验证配置，用于指定验证所需要的额外参数\n",
    "    val_cfg=dict(),\n",
    "    # 用于验证的评测器，这里使用默认评测器，并评测指标\n",
    "    val_evaluator=dict(type=Accuracy),\n",
    ")\n",
    "\n",
    "runner.train()"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": null,
   "metadata": {},
   "outputs": [],
   "source": []
  }
 ],
 "metadata": {
  "kernelspec": {
   "display_name": "Python 3",
   "language": "python",
   "name": "python3"
  },
  "language_info": {
   "codemirror_mode": {
    "name": "ipython",
    "version": 3
   },
   "file_extension": ".py",
   "mimetype": "text/x-python",
   "name": "python",
   "nbconvert_exporter": "python",
   "pygments_lexer": "ipython3",
   "version": "3.12.2"
  }
 },
 "nbformat": 4,
 "nbformat_minor": 2
}
